﻿
--<<<<<<<<<<<<<<<<<<<<< Create Federations Root Database >>>>>>>>>>>>>>>>>>>>>
CREATE DATABASE MyFedDB --(EDITION='Web', MAXSIZE=1GB) 
GO

--<<<<<<<<<<<<<<<<<<<<< Connect directly to Root Database >>>>>>>>>>>>>>>>>>>>

--<<<<<<<<<<<<<<<<<<<<< Create Federation Scheme >>>>>>>>>>>>>>>>>>>>>
-- Create scheme
CREATE FEDERATION CustomerFederation(cid BIGINT RANGE)
GO

--<<<<<<<<<<<<<<<<<<<<< View Federations Metadata >>>>>>>>>>>>>>>>>>>>>
-- Route connection to the Federation Root
USE FEDERATION ROOT WITH RESET
GO
SELECT db_name() [db_name], db_id() [db_id]
SELECT * FROM sys.federations
SELECT * FROM sys.federation_distributions
SELECT * FROM sys.federation_member_distributions ORDER BY federation_id, range_low;
SELECT * FROM sys.databases;
GO

-- Route connection to the 1 Federation Member (aka shard)
USE FEDERATION CustomerFederation(cid=100) WITH RESET, FILTERING=OFF
GO
SELECT db_name() [db_name], db_id() [db_id]
SELECT * FROM sys.federations
SELECT * FROM sys.federation_distributions
SELECT * FROM sys.federation_member_distributions

-- Federatation ranges
SELECT f.name, fmc.federation_id, fmc.member_id, fmc.range_low, fmc.range_high 
FROM sys.federations f
JOIN sys.federation_member_distributions fmc
ON f.federation_id=fmc.federation_id
ORDER BY fmc.federation_id, fmc.range_low;
GO

--<<<<<<<<<<<<<<<<<<<<< Create Federated Tables >>>>>>>>>>>>>>>>>>>>>
-- Route connection to the 1 Federation Member (aka shard)
USE FEDERATION CustomerFederation(cid = 0) WITH RESET, FILTERING=OFF
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[Customer](
	[CustomerID] [bigint] NOT NULL,
	[Title] [nvarchar](8) NULL,
	[FirstName] [nvarchar](50) NOT NULL,
	[MiddleName] [nvarchar](50) NULL,
	[LastName] [nvarchar](50) NOT NULL,
	[Suffix] [nvarchar](10) NULL,
	[CompanyName] [nvarchar](128) NULL,
	[SalesPerson] [nvarchar](256) NULL,
	[EmailAddress] [nvarchar](50) NULL,
	[Phone] [nvarchar](25) NULL,
 CONSTRAINT [PK_Customer] PRIMARY KEY CLUSTERED 
(
	[CustomerID] ASC
) 
)FEDERATED ON (cid = CustomerID)
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[CustomerAddress](
	[AddressID] [int] NOT NULL,
	[CustomerID] [bigint] NOT NULL,
	[AddressType] [nvarchar](50) NULL,
	[AddressLine1] [nvarchar](60) NOT NULL,
	[AddressLine2] [nvarchar](60) NULL,
	[City] [nvarchar](30) NOT NULL,
	[StateProvince] [nvarchar](30) NOT NULL,
	[CountryRegion] [nvarchar](30) NOT NULL,
	[PostalCode] [nvarchar](15) NOT NULL,
 CONSTRAINT [PK_CustomerAddress] PRIMARY KEY CLUSTERED 
(
	[CustomerID],[AddressID] ASC
)
)FEDERATED ON (cid = CustomerID)
GO

SET NOCOUNT ON
GO
Print 'Insert into Customer table...'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(1, N'Mr.', N'Orlando', N'N.', N'Gee', NULL, N'A Bike Store', N'adventure-works\pamela0', N'orlando0@adventure-works.com', N'245-555-0173')
,(2, N'Mr.', N'Keith', NULL, N'Harris', NULL, N'Progressive Sports', N'adventure-works\david8', N'keith0@adventure-works.com', N'170-555-0127')
,(3, N'Ms.', N'Donna', N'F.', N'Carreras', NULL, N'Advanced Bike Components', N'adventure-works\jillian0', N'donna0@adventure-works.com', N'279-555-0130')
,(4, N'Ms.', N'Janet', N'M.', N'Gates', NULL, N'Modular Cycle Systems', N'adventure-works\jillian0', N'janet1@adventure-works.com', N'710-555-0173')
,(5, N'Mr.', N'Lucy', NULL, N'Harrington', NULL, N'Metropolitan Sports Supply', N'adventure-works\shu0', N'lucy0@adventure-works.com', N'828-555-0186')
,(6, N'Ms.', N'Rosmarie', N'J.', N'Carroll', NULL, N'Aerobic Exercise Company', N'adventure-works\linda3', N'rosmarie0@adventure-works.com', N'244-555-0112')
,(7, N'Mr.', N'Dominic', N'P.', N'Gash', NULL, N'Associated Bikes', N'adventure-works\shu0', N'dominic0@adventure-works.com', N'192-555-0173')
,(10, N'Ms.', N'Kathleen', N'M.', N'Garza', NULL, N'Rural Cycle Emporium', N'adventure-works\jos�1', N'kathleen0@adventure-works.com', N'150-555-0127')
,(11, N'Ms.', N'Katherine', NULL, N'Harding', NULL, N'Sharp Bikes', N'adventure-works\jos�1', N'katherine0@adventure-works.com', N'926-555-0159')
,(12, N'Mr.', N'Johnny', N'A.', N'Caprio', N'Jr.', N'Bikes and Motorbikes', N'adventure-works\garrett1', N'johnny0@adventure-works.com', N'112-555-0191')
,(16, N'Mr.', N'Christopher', N'R.', N'Beck', N'Jr.', N'Bulk Discount Store', N'adventure-works\jae0', N'christopher1@adventure-works.com', N'1 (11) 500 555-0132')
,(18, N'Mr.', N'David', N'J.', N'Liu', NULL, N'Catalog Store', N'adventure-works\michael9', N'david20@adventure-works.com', N'440-555-0132')
,(19, N'Mr.', N'John', N'A.', N'Beaver', NULL, N'Center Cycle Shop', N'adventure-works\pamela0', N'john8@adventure-works.com', N'521-555-0195')
,(20, N'Ms.', N'Jean', N'P.', N'Handley', NULL, N'Central Discount Store', N'adventure-works\david8', N'jean1@adventure-works.com', N'582-555-0113')
,(21, NULL, N'Jinghao', NULL, N'Liu', NULL, N'Chic Department Stores', N'adventure-works\jillian0', N'jinghao1@adventure-works.com', N'928-555-0116')
,(22, N'Ms.', N'Linda', N'E.', N'Burnett', NULL, N'Travel Systems', N'adventure-works\jillian0', N'linda4@adventure-works.com', N'121-555-0121')
,(23, N'Mr.', N'Kerim', NULL, N'Hanif', NULL, N'Bike World', N'adventure-works\shu0', N'kerim0@adventure-works.com', N'216-555-0122')
,(24, N'Mr.', N'Kevin', NULL, N'Liu', NULL, N'Eastside Department Store', N'adventure-works\linda3', N'kevin5@adventure-works.com', N'926-555-0164')
,(25, N'Mr.', N'Donald', N'L.', N'Blanton', NULL, N'Coalition Bike Company', N'adventure-works\shu0', N'donald0@adventure-works.com', N'357-555-0161')
,(28, N'Ms.', N'Jackie', N'E.', N'Blackwell', NULL, N'Commuter Bicycle Store', N'adventure-works\jos�1', N'jackie0@adventure-works.com', N'972-555-0163')
,(29, N'Mr.', N'Bryan', NULL, N'Hamilton', NULL, N'Cross-Country Riding Supplies', N'adventure-works\jos�1', N'bryan2@adventure-works.com', N'344-555-0144')
,(30, N'Mr.', N'Todd', N'R.', N'Logan', NULL, N'Cycle Merchants', N'adventure-works\garrett1', N'todd0@adventure-works.com', N'783-555-0110')
,(34, N'Ms.', N'Barbara', N'J.', N'German', NULL, N'Cycles Wholesaler & Mfg.', N'adventure-works\jae0', N'barbara4@adventure-works.com', N'1 (11) 500 555-0181')
,(37, N'Mr.', N'Jim', NULL, N'Geist', NULL, N'Two Bike Shops', N'adventure-works\pamela0', N'jim1@adventure-works.com', N'724-555-0161')
,(38, N'Ms.', N'Betty', N'M.', N'Haines', NULL, N'Finer Mart', N'adventure-works\david8', N'betty0@adventure-works.com', N'867-555-0114')
,(39, N'Ms.', N'Sharon', N'J.', N'Looney', NULL, N'Fitness Hotel', N'adventure-works\jillian0', N'sharon2@adventure-works.com', N'377-555-0132')
,(40, N'Mr.', N'Darren', NULL, N'Gehring', NULL, N'Journey Sporting Goods', N'adventure-works\jillian0', N'darren0@adventure-works.com', N'417-555-0182')
,(41, N'Ms.', N'Erin', N'M.', N'Hagens', NULL, N'Distant Inn', N'adventure-works\shu0', N'erin1@adventure-works.com', N'244-555-0127')
,(42, N'Mr.', N'Jeremy', NULL, N'Los', NULL, N'Healthy Activity Store', N'adventure-works\linda3', N'jeremy0@adventure-works.com', N'911-555-0165')
,(43, N'Ms.', N'Elsa', NULL, N'Leavitt', NULL, N'Frugal Bike Shop', N'adventure-works\shu0', N'elsa0@adventure-works.com', N'482-555-0174')
,(46, N'Mr.', N'David', N'O', N'Lawrence', NULL, N'Gear-Shift Bikes Limited', N'adventure-works\jos�1', N'david19@adventure-works.com', N'653-555-0159')
,(47, N'Ms.', N'Hattie', N'J.', N'Haemon', NULL, N'Greater Bike Store', N'adventure-works\jos�1', N'hattie0@adventure-works.com', N'141-555-0172')
,(48, N'Ms.', N'Anita', N'R.', N'Lucerne', NULL, N'Grand Industries', N'adventure-works\garrett1', N'anita0@adventure-works.com', N'164-555-0118')
,(52, N'Ms.', N'Rebecca', NULL, N'Laszlo', NULL, N'Instruments and Parts Company', N'adventure-works\jae0', N'rebecca2@adventure-works.com', N'1 (11) 500 555-0155')
,(55, N'Mr.', N'Eric', NULL, N'Lang', NULL, N'Kickstands and Accessories Company', N'adventure-works\pamela0', N'eric6@adventure-works.com', N'932-555-0163')
,(56, N'Mr.', N'Brian', NULL, N'Groth', NULL, N'Latest Accessories Sales', N'adventure-works\david8', N'brian5@adventure-works.com', N'461-555-0118')
,(57, N'Ms.', N'Judy', N'R.', N'Lundahl', NULL, N'Leading Sales & Repair', N'adventure-works\jillian0', N'judy1@adventure-works.com', N'260-555-0130')
,(58, N'Mr.', N'Peter', NULL, N'Kurniawan', NULL, N'Largest Bike Store', N'adventure-works\jillian0', N'peter4@adventure-works.com', N'436-555-0160')
,(59, N'Mr.', N'Douglas', NULL, N'Groncki', NULL, N'Locks Company', N'adventure-works\shu0', N'douglas2@adventure-works.com', N'385-555-0140')
,(60, N'Mr.', N'Sean', N'J.', N'Lunt', NULL, N'Main Bicycle Services', N'adventure-works\linda3', N'sean4@adventure-works.com', N'183-555-0111')
,(61, N'Mr.', N'Jeffrey', NULL, N'Kurtz', NULL, N'Many Bikes Store', N'adventure-works\shu0', N'jeffrey3@adventure-works.com', N'452-555-0179')
,(64, N'Mr.', N'Vamsi', NULL, N'Kuppa', NULL, N'Metal Clearing House', N'adventure-works\jos�1', N'vamsi1@adventure-works.com', N'290-555-0196')
,(65, N'Ms.', N'Jane', N'P.', N'Greer', NULL, N'Metro Manufacturing', N'adventure-works\jos�1', N'jane2@adventure-works.com', N'737-555-0163')
,(66, N'Mr.', N'Alexander', N'J.', N'Deborde', NULL, N'Neighborhood Store', N'adventure-works\garrett1', N'alexander1@adventure-works.com', N'394-555-0176')
,(70, N'Mr.', N'Deepak', NULL, N'Kumar', NULL, N'Outdoor Aerobic Systems Company', N'adventure-works\jae0', N'deepak0@adventure-works.com', N'1 (11) 500 555-0122')
,(73, N'Ms.', N'Margaret', N'T.', N'Krupka', NULL, N'Outdoor Sports Supply', N'adventure-works\pamela0', N'margaret1@adventure-works.com', N'107-555-0132')
,(74, N'Mr.', N'Christopher', N'M.', N'Bright', NULL, N'Parcel Express Delivery Service', N'adventure-works\david8', N'christopher2@adventure-works.com', N'162-555-0166')
,(75, N'Ms.', N'Aidan', NULL, N'Delaney', NULL, N'Paint Supply', N'adventure-works\jillian0', N'aidan0@adventure-works.com', N'358-555-0188')
,(76, N'Mr.', N'James', N'J.', N'Krow', NULL, N'Out-of-the-Way Hotels', N'adventure-works\jillian0', N'james11@adventure-works.com', N'265-555-0190')
,(77, N'Mr.', N'Michael', NULL, N'Brundage', NULL, N'Mechanical Products Ltd.', N'adventure-works\shu0', N'michael13@adventure-works.com', N'128-555-0148')
,(78, N'Mr.', N'Stefan', NULL, N'Delmarco', NULL, N'Preferred Bikes', N'adventure-works\linda3', N'stefan0@adventure-works.com', N'819-555-0186')
,(79, N'Mr.', N'Mitch', NULL, N'Kennedy', NULL, N'Reasonable Bicycle Sales', N'adventure-works\shu0', N'mitch0@adventure-works.com', N'996-555-0192')
,(82, N'Mr.', N'James', N'D.', N'Kramer', NULL, N'Refined Department Stores', N'adventure-works\jos�1', N'james10@adventure-works.com', N'814-555-0130')
,(83, N'Mr.', N'Eric', N'J.', N'Brumfield', NULL, N'Requisite Part Supply', N'adventure-works\jos�1', N'eric3@adventure-works.com', N'644-555-0114')
,(84, N'Ms.', N'Della', N'F.', N'Demott Jr', NULL, N'Rewarding Activities Company', N'adventure-works\garrett1', N'della0@adventure-works.com', N'752-555-0185')
,(88, N'Ms.', N'Pamala', N'M.', N'Kotc', NULL, N'Closest Bicycle Store', N'adventure-works\jae0', N'pamala0@adventure-works.com', N'1 (11) 500 555-0173')
,(92, N'Ms.', N'Joy', N'R.', N'Koski', NULL, N'Scooters and Bikes Store', N'adventure-works\pamela0', N'joy0@adventure-works.com', N'810-555-0198')
,(94, N'Ms.', N'Jovita', N'A.', N'Carmody', NULL, N'Sports Commodities', N'adventure-works\david8', N'jovita0@adventure-works.com', N'646-555-0137')
,(95, N'Mr.', N'Prashanth', NULL, N'Desai', NULL, N'Stationary Bikes and Stands', N'adventure-works\jillian0', N'prashanth0@adventure-works.com', N'138-555-0156')
,(96, N'Mr.', N'Scott', NULL, N'Konersmann', NULL, N'Specialty Sports Store', N'adventure-works\jillian0', N'scott6@adventure-works.com', N'556-555-0192')
,(97, N'Ms.', N'Jane', N'N.', N'Carmichael', NULL, N'Rural Department Store', N'adventure-works\shu0', N'jane0@adventure-works.com', N'716-555-0167')
,(98, N'Ms.', N'Bonnie', N'B.', N'Lepro', NULL, N'More Bikes!', N'adventure-works\linda3', N'bonnie2@adventure-works.com', N'354-555-0130')
,(99, N'Mr.', N'Eugene', NULL, N'Kogan', NULL, N'Mountain Bike Center', N'adventure-works\shu0', N'eugene2@adventure-works.com', N'136-555-0134')
,(100, N'Mr.', N'Kirk', N'T', N'King', NULL, N'Up-To-Date Sports', N'adventure-works\jos�1', N'kirk2@adventure-works.com', N'979-555-0163')
,(101, N'Mr.', N'William', N'J.', N'Conner', NULL, N'Urban Sports Emporium', N'adventure-works\jos�1', N'william1@adventure-works.com', N'383-555-0111')
,(102, N'Ms.', N'Linda', NULL, N'Leste', NULL, N'National Manufacturing', N'adventure-works\garrett1', N'linda7@adventure-works.com', N'493-555-0134')
,(106, N'Ms.', N'Andrea', N'A.', N'Thomsen', NULL, N'West Side Mart', N'adventure-works\jae0', N'andrea1@adventure-works.com', N'1 (11) 500 555-0120')
,(109, N'Mr.', N'Daniel', N'P.', N'Thompson', NULL, N'Travel Sports', N'adventure-works\pamela0', N'daniel2@adventure-works.com', N'247-555-0197')
,(110, N'Ms.', N'Kendra', N'N.', N'Thompson', NULL, N'Vintage Sport Boutique', N'adventure-works\david8', N'kendra0@adventure-works.com', N'464-555-0188')
,(111, N'Mr.', N'Scott', N'A.', N'Colvin', NULL, N'Westside Cycle Store', N'adventure-works\jillian0', N'scott1@adventure-works.com', N'119-555-0144')
,(112, N'Ms.', N'Elsie', N'L.', N'Lewin', NULL, N'Town Industries', N'adventure-works\jillian0', N'elsie0@adventure-works.com', N'803-555-0116')
,(113, N'Mr.', N'Donald', N'M.', N'Thompson', NULL, N'Trendy Department Stores', N'adventure-works\shu0', N'donald1@adventure-works.com', N'273-555-0111')
,(114, N'Mr.', N'John', N'L.', N'Colon', NULL, N'Two Wheels Cycle Store', N'adventure-works\linda3', N'john14@adventure-works.com', N'397-555-0144')
,(115, N'Mr.', N'George', N'Z.', N'Li', NULL, N'Security Racks and Locks Wholesalers', N'adventure-works\shu0', N'george3@adventure-works.com', N'699-555-0183')
,(118, N'Mr.', N'Yale', NULL, N'Li', NULL, N'Rapid Bikes', N'adventure-works\jos�1', N'yale0@adventure-works.com', N'316-555-0138')
,(119, N'Ms.', N'Phyllis', N'A.', N'Thomas', NULL, N'Red Bicycle Company', N'adventure-works\jos�1', N'phyllis2@adventure-works.com', N'667-555-0112')
,(120, N'Mr.', N'Pat', NULL, N'Coleman', NULL, N'Machines & Cycles Store', N'adventure-works\garrett1', N'pat2@adventure-works.com', N'292-555-0128')
,(124, N'Ms.', N'Yuhong', NULL, N'Li', NULL, N'Nearby Sporting Goods', N'adventure-works\jae0', N'yuhong1@adventure-works.com', N'1 (11) 500 555-0176')
,(127, N'Mr.', N'Joseph', N'M.', N'Lique', NULL, N'Front Sporting Goods', N'adventure-works\pamela0', N'joseph2@adventure-works.com', N'119-555-0195')
,(128, N'Ms.', N'Judy', N'J.', N'Thames', NULL, N'Demand Distributors', N'adventure-works\david8', N'judy3@adventure-works.com', N'799-555-0118')
,(129, N'Ms.', N'Connie', N'L.', N'Coffman', NULL, N'Discount Bicycle Specialists', N'adventure-works\jillian0', N'connie0@adventure-works.com', N'426-555-0181')
,(130, N'Mr.', N'Paulo', N'H.', N'Lisboa', NULL, N'Elite Bikes', N'adventure-works\jillian0', N'paulo0@adventure-works.com', N'380-555-0116')
,(131, N'Ms.', N'Vanessa', N'J.', N'Tench', NULL, N'Eighth Bike Store', N'adventure-works\shu0', N'vanessa0@adventure-works.com', N'785-555-0163')
,(132, N'Ms.', N'Teanna', N'M.', N'Cobb', NULL, N'Another Sporting Goods Company', N'adventure-works\linda3', N'teanna0@adventure-works.com', N'661-555-0168')
,(133, N'Mr.', N'Michael', NULL, N'Graff', NULL, N'Commercial Sporting Goods', N'adventure-works\shu0', N'michael16@adventure-works.com', N'132-555-0150')
,(136, N'Mr.', N'Derek', NULL, N'Graham', NULL, N'Wholesale Parts', N'adventure-works\jos�1', N'derek0@adventure-works.com', N'674-555-0187')
,(137, NULL, N'Gytis', N'M', N'Barzdukas', NULL, N'Transportation Options', N'adventure-works\jos�1', N'gytis0@adventure-works.com', N'257-555-0119')
,(138, N'Ms.', N'Jane', NULL, N'Clayton', NULL, N'South Bike Company', N'adventure-works\garrett1', N'jane1@adventure-works.com', N'206-555-0195')
,(142, N'Mr.', N'Jon', NULL, N'Grande', NULL, N'Riding Cycles', N'adventure-works\jae0', N'jon1@adventure-works.com', N'1 (11) 500 555-0114')
,(145, N'Mr.', N'Ted', NULL, N'Bremer', NULL, N'Raw Materials Inc', N'adventure-works\pamela0', N'ted0@adventure-works.com', N'962-555-0166')
,(146, N'Mr.', N'Richard', NULL, N'Bready', NULL, N'Latest Sports Equipment', N'adventure-works\david8', N'richard1@adventure-works.com', N'340-555-0131')
,(147, N'Ms.', N'Alice', NULL, N'Clark', NULL, N'Local Hardware Factory', N'adventure-works\jillian0', N'alice1@adventure-works.com', N'221-555-0141')
,(148, N'Mr.', N'Alan', NULL, N'Brewer', NULL, N'Lots of Bikes Storehouse', N'adventure-works\jillian0', N'alan1@adventure-works.com', N'494-555-0134')
,(149, N'Mr.', N'Cornelius', N'L.', N'Brandon', NULL, N'Initial Bike Company', N'adventure-works\shu0', N'cornelius0@adventure-works.com', N'229-555-0114')
,(150, N'Ms.', N'Jill', N'J.', N'Christie', NULL, N'Fleet Bikes', N'adventure-works\linda3', N'jill1@adventure-works.com', N'927-555-0198')
,(151, N'Mr.', N'Walter', N'J.', N'Brian', N'IV', N'Futuristic Bikes', N'adventure-works\shu0', N'walter0@adventure-works.com', N'163-555-0155')
,(154, N'Mr.', N'Carlton', N'M.', N'Carlisle', NULL, N'Camping and Sports Store', N'adventure-works\jos�1', N'carlton0@adventure-works.com', N'193-555-0116')
,(155, N'Mr.', N'Joseph', N'N.', N'Castellucio', NULL, N'Corner Bicycle Supply', N'adventure-works\jos�1', N'joseph1@adventure-works.com', N'180-555-0114')
,(156, N'Mr.', N'Lester', N'J.', N'Bowman', N'Sr.', N'Metal Processing Company', N'adventure-works\garrett1', N'lester0@adventure-works.com', N'844-555-0112')
,(160, N'Ms.', N'Brigid', N'F.', N'Cavendish', NULL, N'Vigorous Sports Store', N'adventure-works\jae0', N'brigid0@adventure-works.com', N'1 (11) 500 555-0178')
,(163, N'Mr.', N'Andrew', NULL, N'Cencini', NULL, N'Sports Merchandise', N'adventure-works\pamela0', N'andrew2@adventure-works.com', N'644-555-0111')
GO
print 'Processed 100 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(164, N'Ms.', N'Cindy', N'M.', N'Dodd', NULL, N'Suburban Cycle Shop', N'adventure-works\david8', N'cindy0@adventure-works.com', N'706-555-0140')
,(165, N'Mr.', N'Randall', NULL, N'Boseman', NULL, N'Third Bike Store', N'adventure-works\jillian0', N'randall0@adventure-works.com', N'383-555-0117')
,(166, N'Ms.', N'Stacey', N'M.', N'Cereghino', NULL, N'Fitness Toy Store', N'adventure-works\jillian0', N'stacey0@adventure-works.com', N'351-555-0131')
,(167, N'Mr.', N'Blaine', NULL, N'Dockter', NULL, N'Farthermost Bike Shop', N'adventure-works\shu0', N'blaine0@adventure-works.com', N'156-555-0187')
,(168, N'Sr.', N'Luis', NULL, N'Bonifaz', NULL, N'Economy Bikes Company', N'adventure-works\linda3', N'luis0@adventure-works.com', N'688-555-0113')
,(169, N'Ms.', N'Brenda', NULL, N'Diaz', NULL, N'Downtown Hotel', N'adventure-works\shu0', N'brenda2@adventure-works.com', N'147-555-0192')
,(172, N'Ms.', N'Gabriele', NULL, N'Dickmann', NULL, N'Certified Sports Supply', N'adventure-works\jos�1', N'gabriele0@adventure-works.com', N'835-555-0116')
,(173, N'Mr.', N'Rudolph', N'J.', N'Dillon', N'Sr.', N'Sundry Sporting Goods', N'adventure-works\jos�1', N'rudolph0@adventure-works.com', N'722-555-0169')
,(174, N'Mr.', N'Michael', N'L.', N'Bohling', NULL, N'Toy Manufacturing Inc', N'adventure-works\garrett1', N'michael12@adventure-works.com', N'838-555-0147')
,(178, N'Mr.', N'Dick', NULL, N'Dievendorff', NULL, N'Rampart Amusement Company', N'adventure-works\jae0', N'dick1@adventure-works.com', N'1 (11) 500 555-0193')
,(180, N'Ms.', N'Nicky', N'E.', N'Chesnut', NULL, N'Full-Service Bike Store', N'adventure-works\michael9', N'nicky0@adventure-works.com', N'264-555-0164')
,(181, N'Mr.', N'Michael', N'J.', N'Lee', NULL, N'Family Entertainment Center', N'adventure-works\pamela0', N'michael18@adventure-works.com', N'396-555-0139')
,(182, N'Mr.', N'Stanley', N'A.', N'Alan', N'Jr.', N'Another Bicycle Company', N'adventure-works\david8', N'stanley0@adventure-works.com', N'156-555-0126')
,(183, N'Mr.', N'Yao-Qiang', NULL, N'Cheng', NULL, N'This Area Sporting Goods', N'adventure-works\jillian0', N'yao-qiang0@adventure-works.com', N'344-555-0181')
,(184, N'Ms.', N'Marjorie', N'M.', N'Lee', NULL, N'Go-cart and Bike Specialists', N'adventure-works\jillian0', N'marjorie0@adventure-works.com', N'306-555-0166')
,(185, N'Mr.', N'Sandeep', NULL, N'Kaliyath', NULL, N'Weekend Bike Tours', N'adventure-works\shu0', N'sandeep1@adventure-works.com', N'495-555-0113')
,(186, N'Mr.', N'Pei', NULL, N'Chow', NULL, N'Thrilling Bike Tours', N'adventure-works\linda3', N'pei0@adventure-works.com', N'789-555-0184')
,(187, N'Mr.', N'Frank', NULL, N'Campbell', NULL, N'Trailblazing Sports', N'adventure-works\shu0', N'frank4@adventure-works.com', N'491-555-0132')
,(190, N'Mr.', N'Mark', NULL, N'Lee', NULL, N'Racing Partners', N'adventure-works\jos�1', N'mark5@adventure-works.com', N'371-555-0112')
,(191, N'Ms.', N'Sandra', N'T.', N'Kitt', NULL, N'Non-Slip Pedal Company', N'adventure-works\jos�1', N'sandra2@adventure-works.com', N'303-555-0117')
,(192, N'Mr.', N'Hao', NULL, N'Chen', NULL, N'Nuts and Bolts Mfg.', N'adventure-works\garrett1', N'hao1@adventure-works.com', N'117-555-0173')
,(196, N'Ms.', N'Jolie', NULL, N'Lenehan', NULL, N'Exhibition Showroom', N'adventure-works\jae0', N'jolie0@adventure-works.com', N'1 (11) 500 555-0126')
,(197, N'Ms.', N'Diane', N'F.', N'Krane', NULL, N'Fabrikam Inc., West', N'adventure-works\michael9', N'diane4@adventure-works.com', N'224-555-0126')
,(198, N'Mr.', N'Payton', N'P.', N'Benson', NULL, N'Field Trip Inc', N'adventure-works\michael9', N'payton0@adventure-works.com', N'528-555-0183')
,(199, N'Mr.', N'Roger', NULL, N'Lengel', NULL, N'Authorized Bike Sales and Rental', N'adventure-works\pamela0', N'roger1@adventure-works.com', N'947-555-0143')
,(200, N'Ms.', N'Peggy', N'J.', N'Justice', NULL, N'Basic Bike Company', N'adventure-works\david8', N'peggy0@adventure-works.com', N'170-555-0189')
,(201, N'Ms.', N'Edna', N'J.', N'Benson', NULL, N'Unsurpassed Bikes', N'adventure-works\jillian0', N'edna0@adventure-works.com', N'789-555-0189')
,(202, NULL, N'A.', N'Francesca', N'Leonetti', NULL, N'Two-Seater Bikes', N'adventure-works\jillian0', N'a0@adventure-works.com', N'645-555-0193')
,(203, N'Ms.', N'Jean', NULL, N'Jordan', NULL, N'Separate Parts Corporation', N'adventure-works\shu0', N'jean3@adventure-works.com', N'207-555-0129')
,(204, N'Mr.', N'Ido', NULL, N'Ben-Sachar', NULL, N'Traction Tire Company', N'adventure-works\linda3', N'ido0@adventure-works.com', N'973-555-0112')
,(205, N'Mr.', N'Frank', NULL, N'Mart�nez', NULL, N'Rally Master Company Inc', N'adventure-works\shu0', N'frank5@adventure-works.com', N'171-555-0147')
,(208, N'Mr.', N'Steve', NULL, N'Masters', NULL, N'Professional Cyclists', N'adventure-works\jos�1', N'steve2@adventure-works.com', N'154-555-0115')
,(209, N'Mr.', N'Robert', N'E.', N'Jones', NULL, N'Purple Bicycle Company', N'adventure-works\jos�1', N'robert6@adventure-works.com', N'595-555-0131')
,(210, N'Mr.', N'Josh', NULL, N'Barnhill', NULL, N'Gasless Cycle Shop', N'adventure-works\garrett1', N'josh0@adventure-works.com', N'584-555-0192')
,(214, N'Ms.', N'Jennifer', N'J.', N'Maxham', NULL, N'Exclusive Bicycle Mart', N'adventure-works\jae0', N'jennifer1@adventure-works.com', N'1 (11) 500 555-0175')
,(217, N'Mr.', N'Chris', NULL, N'Maxwell', NULL, N'City Manufacturing', N'adventure-works\pamela0', N'chris6@adventure-works.com', N'642-555-0187')
,(218, N'Mr.', N'David', NULL, N'Johnson', NULL, N'Sure & Reliable Sporting Goods', N'adventure-works\david8', N'david18@adventure-works.com', N'476-555-0139')
,(219, N'Mr.', N'Brian', NULL, N'Johnson', NULL, N'Extras Sporting Goods', N'adventure-works\jillian0', N'brian6@adventure-works.com', N'320-555-0134')
,(220, N'Mr.', N'Robert', NULL, N'Brown', NULL, N'Best o'' Bikes', N'adventure-works\jillian0', N'robert5@adventure-works.com', N'575-555-0189')
,(221, N'Ms.', N'Sandra', N'B.', N'Maynard', NULL, N'Bike Dealers Association', N'adventure-works\shu0', N'sandra4@adventure-works.com', N'993-555-0179')
,(222, N'Mr.', N'Barry', NULL, N'Johnson', NULL, N'Sample Bike Store', N'adventure-works\linda3', N'barry1@adventure-works.com', N'858-555-0140')
,(223, N'Ms.', N'Joyce', NULL, N'Jarvis', NULL, N'Paints and Solvents Company', N'adventure-works\shu0', N'joyce0@adventure-works.com', N'458-555-0179')
,(226, N'Ms.', N'Vance', N'P.', N'Johns', NULL, N'Leisure Activities', N'adventure-works\jos�1', N'vance0@adventure-works.com', N'103-555-0151')
,(227, N'Ms.', N'Robin', N'M.', N'McGuigan', NULL, N'Health Spa, Limited', N'adventure-works\jos�1', N'robin0@adventure-works.com', N'431-555-0153')
,(228, N'Ms.', N'Danielle', N'B.', N'Johnson', NULL, N'Home Town Bike Store', N'adventure-works\garrett1', N'danielle1@adventure-works.com', N'356-555-0190')
,(232, N'Mr.', N'David', NULL, N'Jaffe', NULL, N'Exceptional Cycle Services', N'adventure-works\jae0', N'david17@adventure-works.com', N'1 (11) 500 555-0140')
,(235, N'Ms.', N'Mary', NULL, N'Alexander', NULL, N'Certified Bicycle Supply', N'adventure-works\pamela0', N'mary7@adventure-works.com', N'344-555-0133')
,(236, N'Ms.', N'Lola', N'M.', N'McCarthy', NULL, N'Closeout Boutique', N'adventure-works\david8', N'lola0@adventure-works.com', N'173-555-0151')
,(237, N'Ms.', N'Mary', N'K.', N'Browning', NULL, N'Client Discount Store', N'adventure-works\jillian0', N'mary5@adventure-works.com', N'658-555-0146')
,(238, N'Ms.', N'Jodan', N'M.', N'Jacobson', NULL, N'A Great Bicycle Company', N'adventure-works\jillian0', N'jodan0@adventure-works.com', N'652-555-0189')
,(239, N'Ms.', N'Jane', N'A.', N'McCarty', NULL, N'Bicycle Merchandise Warehouse', N'adventure-works\shu0', N'jane3@adventure-works.com', N'529-555-0195')
,(240, N'Mr.', N'Jessie', N'E.', N'Valerio', NULL, N'Wire Baskets and Parts', N'adventure-works\linda3', N'jessie0@adventure-works.com', N'103-555-0179')
,(241, N'Mr.', N'Eric', N'A.', N'Jacobsen', NULL, N'Vale Riding Supplies', N'adventure-works\shu0', N'eric5@adventure-works.com', N'703-555-0120')
,(244, N'Mr.', N'Bronson', N'R.', N'Jacobs', NULL, N'Retail Discount Store', N'adventure-works\jos�1', N'bronson0@adventure-works.com', N'697-555-0131')
,(245, N'Mr.', N'James', N'L.', N'McCoy', N'II', N'Leather Seat Factory', N'adventure-works\jos�1', N'james12@adventure-works.com', N'191-555-0151')
,(246, N'Ms.', N'Esther', N'K.', N'Valle', NULL, N'Large Bike Shop', N'adventure-works\garrett1', N'esther0@adventure-works.com', N'481-555-0131')
,(250, N'Ms.', N'Denean', N'J.', N'Ison', NULL, N'Express Bike Services', N'adventure-works\jae0', N'denean0@adventure-works.com', N'1 (11) 500 555-0127')
,(253, N'Mr.', N'Erik', NULL, N'Ismert', NULL, N'Roving Sports', N'adventure-works\pamela0', N'erik0@adventure-works.com', N'116-555-0163')
,(254, N'Mr.', N'Robert', N'M.', N'Bernacchi', NULL, N'Safe Cycles Shop', N'adventure-works\david8', N'robert4@adventure-works.com', N'449-555-0176')
,(255, N'Mr.', N'Sunil', NULL, N'Uppal', NULL, N'Swift Cycles', N'adventure-works\jillian0', N'sunil0@adventure-works.com', N'184-555-0187')
,(256, N'Mr.', N'Richard', N'L.', N'Irwin', NULL, N'Rental Bikes', N'adventure-works\jillian0', N'richard4@adventure-works.com', N'367-555-0124')
,(257, N'Mr.', N'Matthias', NULL, N'Berndt', NULL, N'Number 1 Supply', N'adventure-works\shu0', N'matthias1@adventure-works.com', N'384-555-0169')
,(258, N'Mr.', N'Sairaj', NULL, N'Uddin', NULL, N'Quantity Discounts', N'adventure-works\linda3', N'sairaj1@adventure-works.com', N'767-555-0193')
,(259, N'Mr.', N'Lucio', NULL, N'Iallo', NULL, N'Highway Bike Shop', N'adventure-works\shu0', N'lucio0@adventure-works.com', N'199-555-0135')
,(262, N'Ms.', N'Beth', NULL, N'Inghram', NULL, N'General Industries', N'adventure-works\jos�1', N'beth0@adventure-works.com', N'718-555-0152')
,(263, N'Mr.', N'Timothy', N'B.', N'Burnett', N'Jr.', N'Farthest Bike Store', N'adventure-works\jos�1', N'timothy0@adventure-works.com', N'251-555-0172')
,(264, N'Ms.', N'Phyllis', N'B.', N'Tuffield', NULL, N'Fasteners & Bolts Outlet', N'adventure-works\garrett1', N'phyllis3@adventure-works.com', N'277-555-0182')
,(268, N'Mr.', N'Richard', N'A.', N'Byham', NULL, N'Channel Outlet', N'adventure-works\jae0', N'richard2@adventure-works.com', N'1 (11) 500 555-0138')
,(271, N'Mr.', N'Jared', N'L.', N'Bustamante', NULL, N'Alternative Vehicles', N'adventure-works\pamela0', N'jared0@adventure-works.com', N'164-555-0147')
,(272, N'Mr.', N'Henry', N'L.', N'Campen', NULL, N'Metro Cycle Shop', N'adventure-works\david8', N'henry0@adventure-works.com', N'635-555-0126')
,(273, N'Ms.', N'Christie', N'J.', N'Trujillo', NULL, N'A Typical Bike Shop', N'adventure-works\jillian0', N'christie0@adventure-works.com', N'686-555-0180')
,(274, N'Ms.', N'Janet', N'J.', N'Gilliat', NULL, N'Active Systems', N'adventure-works\jillian0', N'janet2@adventure-works.com', N'521-555-0183')
,(275, N'Mr.', N'Chris', NULL, N'Cannon', NULL, N'Outdoor Sporting Goods', N'adventure-works\shu0', N'chris5@adventure-works.com', N'118-555-0131')
,(276, N'Mr.', N'Michael John', N'R.', N'Troyer', NULL, N'Thrifty Parts and Sales', N'adventure-works\linda3', N'michaeljohn0@adventure-works.com', N'308-555-0175')
,(277, N'Mr.', N'Guy', NULL, N'Gilbert', NULL, N'The Bicycle Accessories Company', N'adventure-works\shu0', N'guy0@adventure-works.com', N'583-555-0198')
,(280, N'Mr.', N'Frances', N'J.', N'Giglio', NULL, N'Standard Bikes', N'adventure-works\jos�1', N'frances1@adventure-works.com', N'692-555-0136')
,(281, N'Ms.', N'Suzana De Abreu', N'A.', N'Canuto', NULL, N'Petroleum Products Distributors', N'adventure-works\jos�1', N'suzanadeabreu0@adventure-works.com', N'990-555-0141')
,(282, N'Mr.', N'Billy', N'J.', N'Trent', NULL, N'Quick Parts and Service', N'adventure-works\garrett1', N'billy0@adventure-works.com', N'882-555-0115')
,(286, N'Mr.', N'Leo', NULL, N'Giakoumakis', NULL, N'Number One Bike Co.', N'adventure-works\jae0', N'leo0@adventure-works.com', N'1 (11) 500 555-0169')
,(287, N'Mr.', N'Grant', NULL, N'Culbertson', NULL, N'Handy Bike Services', N'adventure-works\michael9', N'grant1@adventure-works.com', N'859-555-0173')
,(288, N'Mr.', N'Robert', N'L.', N'Barker', NULL, N'Kickstand Sellers', N'adventure-works\michael9', N'robert3@adventure-works.com', N'241-555-0112')
,(289, N'Ms.', N'Gabriel', N'L.', N'Bockenkamp', NULL, N'Moderately-Priced Bikes Store', N'adventure-works\pamela0', N'gabriel0@adventure-works.com', N'763-555-0145')
,(290, N'Mr.', N'Scott', NULL, N'Culp', NULL, N'Friendly Bike Shop', N'adventure-works\david8', N'scott3@adventure-works.com', N'119-555-0167')
,(291, N'Mr.', N'Wayne', N'N.', N'Banack', NULL, N'Grand Bicycle Stores', N'adventure-works\jillian0', N'wayne0@adventure-works.com', N'640-555-0189')
,(292, N'Mr.', N'Michael', N'Greg', N'Blythe', NULL, N'Grease and Oil Products Company', N'adventure-works\jillian0', N'michael11@adventure-works.com', N'126-555-0172')
,(293, N'Mr.', N'Conor', NULL, N'Cunningham', NULL, N'Fashionable Bikes and Accessories', N'adventure-works\shu0', N'conor0@adventure-works.com', N'115-555-0113')
,(294, N'Mr.', N'Alberto', N'F.', N'Baltazar', NULL, N'Flawless Bike Shop', N'adventure-works\linda3', N'alberto0@adventure-works.com', N'780-555-0114')
,(295, N'Mr.', N'Joseph', N'P.', N'Mitzner', N'Jr.', N'Engineered Bike Systems', N'adventure-works\shu0', N'joseph4@adventure-works.com', N'129-555-0164')
,(298, N'Mr.', N'Robert', NULL, N'Mitosinka', NULL, N'City Cycling', N'adventure-works\jos�1', N'robert10@adventure-works.com', N'239-555-0198')
,(299, N'Mr.', N'Thierry', NULL, N'D''Hers', NULL, N'Citywide Service and Repair', N'adventure-works\jos�1', N'thierry1@adventure-works.com', N'680-555-0192')
,(300, N'Mr.', N'Daniel', NULL, N'Blanco', NULL, N'Nice Bikes', N'adventure-works\garrett1', N'daniel0@adventure-works.com', N'221-555-0167')
,(304, N'Ms.', N'Linda', NULL, N'Mitchell', NULL, N'Essential Bike Works', N'adventure-works\jae0', N'linda9@adventure-works.com', N'1 (11) 500 555-0182')
,(306, N'Mr.', N'Stephen', N'M.', N'Ayers', NULL, N'Work and Play Association', N'adventure-works\michael9', N'stephen1@adventure-works.com', N'818-555-0171')
,(307, N'Ms.', N'Neva', N'M.', N'Mitchell', NULL, N'Riding Associates', N'adventure-works\pamela0', N'neva0@adventure-works.com', N'992-555-0134')
,(308, N'Ms.', N'Megan', N'N.', N'Davis', NULL, N'Rugged Bikes', N'adventure-works\david8', N'megan1@adventure-works.com', N'839-555-0198')
,(309, N'Mr.', N'John', NULL, N'Arthur', NULL, N'The Gear Store', N'adventure-works\jillian0', N'john6@adventure-works.com', N'149-555-0113')
,(310, N'Mr.', N'Frank', NULL, N'Miller', NULL, N'Orange Bicycle Company', N'adventure-works\jillian0', N'frank6@adventure-works.com', N'118-555-0184')
,(311, N'Sr.', N'Alvaro', NULL, N'De Matos Miranda Filho', NULL, N'Principal Bike Company', N'adventure-works\shu0', N'alvaro0@adventure-works.com', N'551-555-0155')
,(312, N'Mr.', N'Thomas', N'B.', N'Armstrong', N'Jr.', N'Resale Services', N'adventure-works\linda3', N'thomas1@adventure-works.com', N'226-555-0146')
,(313, N'Mr.', N'Dylan', NULL, N'Miller', NULL, N'Metropolitan Manufacturing', N'adventure-works\shu0', N'dylan1@adventure-works.com', N'140-555-0192')
,(316, N'Mr.', N'Ben', NULL, N'Miller', NULL, N'Low Price Cycles', N'adventure-works\jos�1', N'ben1@adventure-works.com', N'207-555-0167')
GO
print 'Processed 200 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(317, N'Mr.', N'Jacob', N'N.', N'Dean', NULL, N'Finer Riding Supplies', N'adventure-works\jos�1', N'jacob0@adventure-works.com', N'767-555-0151')
,(318, N'Ms.', N'Ann', NULL, N'Beebe', NULL, N'First-Rate Outlet', N'adventure-works\garrett1', N'ann0@adventure-works.com', N'277-555-0169')
,(322, N'Mr.', N'Matthew', N'J.', N'Miller', NULL, N'Tachometers and Accessories', N'adventure-works\jae0', N'matthew5@adventure-works.com', N'1 (11) 500 555-0176')
,(323, N'Mr.', N'Jo', NULL, N'Brown', NULL, N'Metro Bike Works', N'adventure-works\michael9', N'jo2@adventure-works.com', N'689-555-0130')
,(325, N'Ms.', N'Virginia', N'L.', N'Miller', NULL, N'All Cycle Shop', N'adventure-works\pamela0', N'virginia0@adventure-works.com', N'918-555-0127')
,(326, N'Mr.', N'Scott', NULL, N'Gode', NULL, N'Year-Round Sports', N'adventure-works\david8', N'scott4@adventure-works.com', N'164-555-0145')
,(327, N'Ms.', N'Caroline', N'A.', N'Vicknair', NULL, N'World of Bikes', N'adventure-works\jillian0', N'caroline0@adventure-works.com', N'695-555-0158')
,(328, N'Mr.', N'Robert', N'R.', N'Vessa', NULL, N'Totes & Baskets Company', N'adventure-works\jillian0', N'robert13@adventure-works.com', N'560-555-0171')
,(329, NULL, N'Andreas', NULL, N'Berglund', NULL, N'Unicycles, Bicycles, and Tricycles', N'adventure-works\shu0', N'andreas1@adventure-works.com', N'795-555-0116')
,(330, N'Mr.', N'Mete', NULL, N'Goktepe', NULL, N'The New Bike Store', N'adventure-works\linda3', N'mete0@adventure-works.com', N'637-555-0120')
,(331, N'Ms.', N'Wanda', N'F.', N'Vernon', NULL, N'Technical Parts Manufacturing', N'adventure-works\shu0', N'wanda0@adventure-works.com', N'433-555-0168')
,(334, N'Ms.', N'Dora', N'P.', N'Verdad', NULL, N'Retreat Inn', N'adventure-works\jos�1', N'dora0@adventure-works.com', N'155-555-0140')
,(335, N'Mr.', N'John', N'M.', N'Berger', N'Jr.', N'Scratch-Resistant Finishes Company', N'adventure-works\jos�1', N'john10@adventure-works.com', N'156-555-0111')
,(336, N'Mr.', N'Brian', N'R', N'Goldstein', NULL, N'Primary Bike Distributors', N'adventure-works\garrett1', N'brian4@adventure-works.com', N'495-555-0161')
,(340, N'Mr.', N'Raja', N'D.', N'Venugopal', NULL, N'Nearby Cycle Shop', N'adventure-works\jae0', N'raja0@adventure-works.com', N'1 (11) 500 555-0195')
,(343, N'Ms.', N'Patricia', N'M.', N'Vasquez', NULL, N'Mail-Order Outlet', N'adventure-works\pamela0', N'patricia2@adventure-works.com', N'490-555-0132')
,(344, N'Ms.', N'Karren', N'K.', N'Burkhardt', NULL, N'Fifth Bike Store', N'adventure-works\david8', N'karren0@adventure-works.com', N'652-555-0132')
,(345, N'Ms.', N'Abigail', N'J.', N'Gonzalez', NULL, N'Genial Bike Associates', N'adventure-works\jillian0', N'abigail0@adventure-works.com', N'121-555-0139')
,(346, N'Mr.', N'Ranjit', N'Rudra', N'Varkey Chudukatil', NULL, N'Great Bicycle Supply', N'adventure-works\jillian0', N'ranjit1@adventure-works.com', N'810-555-0160')
,(347, N'Ms.', N'Ingrid', N'K.', N'Burkhardt', NULL, N'Bike Universe', N'adventure-works\shu0', N'ingrid0@adventure-works.com', N'857-555-0187')
,(348, N'Mr.', N'Oscar', N'L.', N'Alpuerto', NULL, N'Bold Bike Accessories', N'adventure-works\linda3', N'oscar0@adventure-works.com', N'855-555-0174')
,(349, N'Mr.', N'Gary', N'T', N'Vargas', NULL, N'Exercise Center', N'adventure-works\shu0', N'gary6@adventure-works.com', N'112-555-0176')
,(352, N'Mr.', N'Shane', N'S.', N'Kim', NULL, N'Twelfth Bike Store', N'adventure-works\jos�1', N'shane2@adventure-works.com', N'155-555-0149')
,(353, N'Ms.', N'Joan', N'M.', N'Campbell', NULL, N'Two-Wheeled Transit Company', N'adventure-works\jos�1', N'joan0@adventure-works.com', N'700-555-0155')
,(354, N'Mr.', N'Maxwell', N'J.', N'Amland', NULL, N'Serious Cycles', N'adventure-works\garrett1', N'maxwell0@adventure-works.com', N'614-555-0134')
,(358, N'Mr.', N'Joe', NULL, N'Kim', NULL, N'Mail Market', N'adventure-works\jae0', N'joe1@adventure-works.com', N'1 (11) 500 555-0144')
,(360, N'Ms.', N'Ramona', N'J.', N'Antrim', NULL, N'Novelty Bikes', N'adventure-works\michael9', N'ramona0@adventure-works.com', N'327-555-0148')
,(361, N'Ms.', N'Karan', NULL, N'Khanna', NULL, N'Fitness Supplies', N'adventure-works\pamela0', N'karan1@adventure-works.com', N'390-555-0150')
,(362, N'Ms.', N'Sharon', N'A.', N'Crow', NULL, N'Grand Cycle Store', N'adventure-works\david8', N'sharon1@adventure-works.com', N'889-555-0176')
,(363, N'Mr.', N'Chris', NULL, N'Ashton', NULL, N'Immense Manufacturing Company', N'adventure-works\jillian0', N'chris3@adventure-works.com', N'556-555-0145')
,(364, N'Mr.', N'Imtiaz', NULL, N'Khan', NULL, N'District Mall', N'adventure-works\jillian0', N'imtiaz0@adventure-works.com', N'249-555-0179')
,(365, N'Mr.', N'Jack', NULL, N'Creasey', NULL, N'Distinctive Store', N'adventure-works\shu0', N'jack2@adventure-works.com', N'539-555-0182')
,(366, N'Ms.', N'Teresa', NULL, N'Atkinson', NULL, N'Extended Bike Sales', N'adventure-works\linda3', N'teresa0@adventure-works.com', N'129-555-0110')
,(367, N'Ms.', N'Tammy', N'J.', N'Khan', NULL, N'Brown Bicycle Company', N'adventure-works\shu0', N'tammy0@adventure-works.com', N'145-555-0166')
,(370, N'Ms.', N'Elizabeth', NULL, N'Keyser', NULL, N'Acceptable Sales & Service', N'adventure-works\jos�1', N'elizabeth2@adventure-works.com', N'656-555-0173')
,(371, N'Mr.', N'Bruno', NULL, N'Costa Da Silva', NULL, N'Custom Sales and Service', N'adventure-works\jos�1', N'bruno0@adventure-works.com', N'140-555-0143')
,(372, N'Ms.', N'Katherine', N'K.', N'Swan', NULL, N'Top Bike Market', N'adventure-works\garrett1', N'katherine1@adventure-works.com', N'421-555-0192')
,(376, N'Ms.', N'Mary', N'R.', N'Kesslep', NULL, N'Commerce Bicycle Specialists', N'adventure-works\jae0', N'mary8@adventure-works.com', N'1 (11) 500 555-0146')
,(377, N'Mr.', N'Marlin', N'M.', N'Coriell', NULL, N'Grand Sport Boutique', N'adventure-works\michael9', N'marlin0@adventure-works.com', N'941-555-0155')
,(379, N'Mr.', N'Kevin', NULL, N'Kennedy', NULL, N'Fad Outlet', N'adventure-works\pamela0', N'kevin4@adventure-works.com', N'275-555-0179')
,(380, N'Ms.', N'Eva', NULL, N'Corets', NULL, N'First Department Stores', N'adventure-works\david8', N'eva0@adventure-works.com', N'542-555-0164')
,(381, N'Ms.', N'Julie', NULL, N'Taft-Rider', NULL, N'Bicycle Lines Distributors', N'adventure-works\jillian0', N'julie1@adventure-works.com', N'145-555-0194')
,(382, N'Mr.', N'Robert', NULL, N'Kelly', NULL, N'Beneficial Exercises and Activities', N'adventure-works\jillian0', N'robert7@adventure-works.com', N'510-555-0123')
,(383, N'Mr.', N'Scott', NULL, N'Cooper', NULL, N'Vehicle Shop', N'adventure-works\shu0', N'scott2@adventure-works.com', N'773-555-0182')
,(384, N'Mr.', N'Clarence', N'R.', N'Tatman', NULL, N'Sparkling Paint and Finishes', N'adventure-works\linda3', N'clarence0@adventure-works.com', N'787-555-0128')
,(385, N'Mr.', N'John', NULL, N'Kelly', NULL, N'Sturdy Toys', N'adventure-works\shu0', N'john22@adventure-works.com', N'330-555-0116')
,(388, N'Mr.', N'Victor', N'A.', N'Kelley', NULL, N'Road Way Sales and Rental', N'adventure-works\jos�1', N'victor0@adventure-works.com', N'112-555-0195')
,(389, N'Ms.', N'Dorothy', N'J.', N'Contreras', NULL, N'Sixth Bike Store', N'adventure-works\jos�1', N'dorothy0@adventure-works.com', N'428-555-0176')
,(390, N'Mr.', N'Mike', N'M.', N'Taylor', NULL, N'Plastic Parts Company', N'adventure-works\garrett1', N'mike6@adventure-works.com', N'204-555-0189')
,(394, N'Ms.', N'Bonnie', NULL, N'Kearney', NULL, N'Little Sports Center', N'adventure-works\jae0', N'bonnie1@adventure-works.com', N'1 (11) 500 555-0116')
,(395, N'Ms.', N'June', N'B.', N'Brunner', NULL, N'Online Bike Sellers', N'adventure-works\michael9', N'june0@adventure-works.com', N'249-555-0172')
,(397, N'Mr.', N'Sandeep', NULL, N'Katyal', NULL, N'Capable Sales and Service', N'adventure-works\pamela0', N'sandeep2@adventure-works.com', N'928-555-0117')
,(398, N'Ms.', N'Shirley', N'R.', N'Bruner', NULL, N'Commendable Bikes', N'adventure-works\david8', N'shirley0@adventure-works.com', N'383-555-0155')
,(399, N'Mr.', N'Chad', N'J.', N'Tedford', NULL, N'Big Cycle Mall', N'adventure-works\jillian0', N'chad1@adventure-works.com', N'588-555-0128')
,(400, N'Mr.', N'Peter', NULL, N'Houston', NULL, N'Local Sales and Rental', N'adventure-works\jillian0', N'peter3@adventure-works.com', N'632-555-0171')
,(401, N'Mr.', N'Tom', N'H', N'Johnston', NULL, N'Brightwork Company', N'adventure-works\shu0', N'tom1@adventure-works.com', N'883-555-0177')
,(402, N'Ms.', N'Marian', N'M.', N'Berch', NULL, N'Pro Sporting Goods', N'adventure-works\linda3', N'marian0@adventure-works.com', N'640-555-0198')
,(403, N'Ms.', N'Juanita', N'J.', N'Holman', NULL, N'Affordable Sports Equipment', N'adventure-works\shu0', N'juanita0@adventure-works.com', N'996-555-0196')
,(406, N'Mr.', N'Eddie', N'M.', N'Holmes', NULL, N'The Commissary', N'adventure-works\jos�1', N'eddie0@adventure-works.com', N'570-555-0199')
,(407, N'Mr.', N'Robert', N'A.', N'Avalos', NULL, N'Workout Emporium', N'adventure-works\jos�1', N'robert2@adventure-works.com', N'665-555-0198')
,(408, N'Mr.', N'Alexander', N'J.', N'Berger', N'II', N'Odometers and Accessories Company', N'adventure-works\garrett1', N'alexander0@adventure-works.com', N'519-555-0151')
,(412, N'Ms.', N'Jean', N'J.', N'Holloway', NULL, N'Leisure Clearing House', N'adventure-works\jae0', N'jean2@adventure-works.com', N'1 (11) 500 555-0181')
,(415, N'Mr.', N'Greg', NULL, N'Chapman', NULL, N'Imaginary Toys', N'adventure-works\pamela0', N'greg1@adventure-works.com', N'708-555-0169')
,(416, N'Ms.', N'Angela', NULL, N'Barbariol', NULL, N'Impromptu Trips', N'adventure-works\david8', N'angela1@adventure-works.com', N'134-555-0182')
,(417, N'Ms.', N'Ruth', N'A.', N'Choin', NULL, N'Genuine Bike Shop', N'adventure-works\jillian0', N'ruth1@adventure-works.com', N'273-555-0181')
,(418, N'Mr.', N'Lee', N'J.', N'Chapla', NULL, N'Good Bike Shop', N'adventure-works\jillian0', N'lee0@adventure-works.com', N'223-555-0184')
,(419, N'Mr.', N'Darrell', N'M.', N'Banks', NULL, N'Exertion Activities Club', N'adventure-works\shu0', N'darrell0@adventure-works.com', N'816-555-0118')
,(420, N'Mr.', N'Anthony', NULL, N'Chor', NULL, N'Extreme Riding Supplies', N'adventure-works\linda3', N'anthony0@adventure-works.com', N'429-555-0145')
,(421, N'Mr.', N'Forrest', N'J.', N'Chandler', NULL, N'Fitness Cycling', N'adventure-works\shu0', N'forrest0@adventure-works.com', N'448-555-0179')
,(424, N'Mr.', N'Eli', NULL, N'Bowen', NULL, N'Bikes for Two', N'adventure-works\jos�1', N'eli0@adventure-works.com', N'371-555-0143')
,(425, N'Mr.', N'Stephen', N'Yuan', N'Jiang', NULL, N'Bikes for Kids and Adults', N'adventure-works\jos�1', N'stephen3@adventure-works.com', N'910-555-0116')
,(426, N'Mr.', N'Dirk', N'J.', N'Bruno', NULL, N'Custom Accessories Company', N'adventure-works\garrett1', N'dirk0@adventure-works.com', N'817-555-0114')
,(430, N'Sr.', N'Gustavo', NULL, N'Camargo', NULL, N'Uttermost Bike Shop', N'adventure-works\jae0', N'gustavo1@adventure-works.com', N'1 (11) 500 555-0118')
,(431, N'Mr.', N'Douglas', N'A.', N'Baldwin', N'Jr.', N'Small Cycle Store', N'adventure-works\michael9', N'douglas1@adventure-works.com', N'583-555-0130')
,(433, N'Ms.', N'Lindsey', N'R.', N'Camacho', NULL, N'Thorough Parts and Repair Services', N'adventure-works\pamela0', N'lindsey0@adventure-works.com', N'827-555-0143')
,(434, N'Mr.', N'James', N'B.', N'Bailey', N'Jr.', N'Road-Way Mart', N'adventure-works\david8', N'james3@adventure-works.com', N'234-555-0112')
,(435, N'Ms.', N'Carol', N'B.', N'Elliott', NULL, N'Satin Finish Company', N'adventure-works\jillian0', N'carol2@adventure-works.com', N'847-555-0151')
,(436, N'Ms.', N'Barbara', N'J.', N'Calone', NULL, N'Sheet Metal Manufacturing', N'adventure-works\jillian0', N'barbara2@adventure-works.com', N'145-555-0152')
,(437, N'Ms.', N'Megan', N'E.', N'Burke', NULL, N'Professional Cycle Store', N'adventure-works\shu0', N'megan0@adventure-works.com', N'148-555-0149')
,(438, N'Mr.', N'Cory', N'K.', N'Booth', NULL, N'Remarkable Bike Store', N'adventure-works\linda3', N'cory0@adventure-works.com', N'121-555-0157')
,(439, N'Ms.', N'Shannon', N'P.', N'Elliott', NULL, N'Regional Manufacturing', N'adventure-works\shu0', N'shannon0@adventure-works.com', N'425-555-0158')
,(442, N'Ms.', N'Jauna', N'E.', N'Elson', NULL, N'Original Bicycle Supply Company', N'adventure-works\jos�1', N'jauna0@adventure-works.com', N'185-555-0190')
,(443, N'Sra.', N'Janaina Barreiro Gambaro', NULL, N'Bueno', NULL, N'Courteous Bicycle Specialists', N'adventure-works\jos�1', N'janainabarreirogambaro0@adventure-works.com', N'476-555-0184')
,(444, N'Mr.', N'Shaun', NULL, N'Beasley', NULL, N'Finer Cycle Shop', N'adventure-works\garrett1', N'shaun0@adventure-works.com', N'396-555-0187')
,(448, N'Mr.', N'Terry', NULL, N'Eminhizer', NULL, N'Action Bicycle Specialists', N'adventure-works\jae0', N'terry1@adventure-works.com', N'1 (11) 500 555-0176')
,(451, N'Mr.', N'John', NULL, N'Emory', NULL, N'Roadway Bike Emporium', N'adventure-works\pamela0', N'john16@adventure-works.com', N'691-555-0149')
,(452, N'Ms.', N'Olga', N'J.', N'Trau', NULL, N'A Cycle Shop', N'adventure-works\david8', N'olga0@adventure-works.com', N'398-555-0167')
,(453, N'Mr.', N'Jon', NULL, N'Ganio', NULL, N'Unique Bikes', N'adventure-works\jillian0', N'jon0@adventure-works.com', N'672-555-0112')
,(454, N'Ms.', N'Gail', NULL, N'Erickson', NULL, N'Sleek Bikes ', N'adventure-works\jillian0', N'gail1@adventure-works.com', N'834-555-0132')
,(455, N'Mr.', N'James', N'R.', N'Tran', NULL, N'Timely Shipping Service', N'adventure-works\shu0', N'james15@adventure-works.com', N'740-555-0159')
,(456, N'Mr.', N'Michael', NULL, N'Galos', NULL, N'Riding Excursions', N'adventure-works\linda3', N'michael15@adventure-works.com', N'912-555-0149')
,(457, N'Mr.', N'Mark', N'B', N'Erickson', NULL, N'Retail Sporting Equipment', N'adventure-works\shu0', N'mark2@adventure-works.com', N'962-555-0112')
,(460, N'Ms.', N'Martha', N'R.', N'Espinoza', NULL, N'Price-Cutter Discount Bikes', N'adventure-works\jos�1', N'martha0@adventure-works.com', N'753-555-0179')
,(461, N'Mr.', N'Glenn', N'J.', N'Track', N'II', N'Active Life Toys', N'adventure-works\jos�1', N'glenn0@adventure-works.com', N'907-555-0170')
,(462, N'Mr.', N'Bob', NULL, N'Gage', NULL, N'General Riding Supplies', N'adventure-works\garrett1', N'bob1@adventure-works.com', N'962-555-0175')
,(466, N'Sra.', N'Janeth', NULL, N'Esteves', NULL, N'Central Bicycle Specialists', N'adventure-works\jae0', N'janeth1@adventure-works.com', N'1 (11) 500 555-0136')
,(468, N'Mr.', N'Paul', N'J.', N'Fulton', NULL, N'Blue Bicycle Company', N'adventure-works\michael9', N'paul3@adventure-works.com', N'492-555-0146')
,(469, N'Ms.', N'Twanna', N'R.', N'Evans', NULL, N'Vast Bike Sales and Rental', N'adventure-works\pamela0', N'twanna0@adventure-works.com', N'554-555-0124')
,(470, N'Ms.', N'Delia', N'B.', N'Toone', NULL, N'Wingtip Toys', N'adventure-works\david8', N'delia0@adventure-works.com', N'328-555-0192')
,(471, N'Mr.', N'John', NULL, N'Ford', NULL, N'Social Activities Club', N'adventure-works\jillian0', N'john19@adventure-works.com', N'596-555-0153')
,(472, N'Ms.', N'Ann', N'R.', N'Evans', NULL, N'Summer Sports Place', N'adventure-works\jillian0', N'ann1@adventure-works.com', N'252-555-0127')
GO
print 'Processed 300 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(473, N'Ms.', N'Kay', N'E.', N'Krane', NULL, N'Racing Toys', N'adventure-works\shu0', N'kay0@adventure-works.com', N'731-555-0187')
,(474, N'Mr.', N'Mihail', NULL, N'Frintu', NULL, N'Retail Cycle Shop', N'adventure-works\linda3', N'mihail1@adventure-works.com', N'777-555-0163')
,(475, N'Mr.', N'John', NULL, N'Evans', NULL, N'Real Sporting Goods', N'adventure-works\shu0', N'john17@adventure-works.com', N'581-555-0172')
,(478, N'Ms.', N'Ruby Sue', N'R.', N'Styles', NULL, N'Major Cycling', N'adventure-works\jos�1', N'rubysue0@adventure-works.com', N'512-555-0122')
,(479, N'Ms.', N'Lori', NULL, N'Kane', NULL, N'General Supplies', N'adventure-works\jos�1', N'lori2@adventure-works.com', N'765-555-0141')
,(480, N'Ms.', N'Susan', N'E.', N'French', NULL, N'General Bike Corporation', N'adventure-works\garrett1', N'susan3@adventure-works.com', N'994-555-0194')
,(484, N'Mr.', N'Gary', N'J.', N'Suess', NULL, N'Downhill Bicycle Specialists', N'adventure-works\jae0', N'gary5@adventure-works.com', N'1 (11) 500 555-0199')
,(487, N'Ms.', N'Ruth', N'J.', N'Suffin', NULL, N'Bike Experts', N'adventure-works\pamela0', N'ruth2@adventure-works.com', N'924-555-0195')
,(488, N'Ms.', N'Margaret', N'J.', N'Smith', NULL, N'Bicycle Accessories and Kits', N'adventure-works\david8', N'margaret0@adventure-works.com', N'959-555-0151')
,(489, N'Ms.', N'Dorothy', N'J.', N'Fox', NULL, N'Cash & Carry Bikes', N'adventure-works\jillian0', N'dorothy1@adventure-works.com', N'191-555-0198')
,(490, N'Ms.', N'Elizabeth', N'J.', N'Sullivan', NULL, N'Extraordinary Bike Works', N'adventure-works\jillian0', N'elizabeth4@adventure-works.com', N'306-555-0112')
,(491, N'Ms.', N'Frances', N'B.', N'Adams', NULL, N'Area Bike Accessories', N'adventure-works\shu0', N'frances0@adventure-works.com', N'991-555-0183')
,(492, N'Mr.', N'Garth', NULL, N'Fort', NULL, N'Basic Sports Equipment', N'adventure-works\linda3', N'garth0@adventure-works.com', N'768-555-0125')
,(493, N'Mr.', N'Michael', NULL, N'Sullivan', NULL, N'Valley Bicycle Distributors', N'adventure-works\shu0', N'michael24@adventure-works.com', N'323-555-0113')
,(496, N'Ms.', N'Marcia', N'J.', N'Sultan', NULL, N'Top Sports Supply', N'adventure-works\jos�1', N'marcia0@adventure-works.com', N'613-555-0116')
,(497, N'Ms.', N'Amy', N'E.', N'Alberts', NULL, N'Valley Toy Store', N'adventure-works\jos�1', N'amy1@adventure-works.com', N'727-555-0115')
,(498, N'Ms.', N'Kelly', NULL, N'Focht', NULL, N'Quick Delivery Service', N'adventure-works\garrett1', N'kelly0@adventure-works.com', N'272-555-0123')
,(502, N'Mr.', N'Krishna', NULL, N'Sunkammurali', NULL, N'Metropolitan Bicycle Supply', N'adventure-works\jae0', N'krishna1@adventure-works.com', N'1 (11) 500 555-0177')
,(504, N'Ms.', N'Mae', N'M.', N'Black', NULL, N'Historic Bicycle Sales', N'adventure-works\michael9', N'mae1@adventure-works.com', N'264-555-0143')
,(505, N'Mr.', N'Brad', NULL, N'Sutton', NULL, N'Honest Repair Service', N'adventure-works\pamela0', N'brad0@adventure-works.com', N'688-555-0115')
,(506, N'Mr.', N'Fran�ois', NULL, N'Ferrier', NULL, N'Great Bikes ', N'adventure-works\david8', N'fran�ois1@adventure-works.com', N'571-555-0128')
,(507, N'Mr.', N'Mary', NULL, N'Bishop', NULL, N'Global Sporting Goods', N'adventure-works\jillian0', N'mary4@adventure-works.com', N'176-555-0136')
,(508, N'Mr.', N'Martin', N'J.', N'Svoboda', N'IV', N'Designer Department Stores', N'adventure-works\jillian0', N'martin1@adventure-works.com', N'132-555-0149')
,(509, N'Mr.', N'Robert', N'E.', N'Ahlering', NULL, N'Fun Toys and Bikes', N'adventure-works\shu0', N'robert1@adventure-works.com', N'678-555-0175')
,(510, N'Mr.', N'Jimmy', NULL, N'Bischoff', NULL, N'World Bike Discount Store', N'adventure-works\linda3', N'jimmy1@adventure-works.com', N'992-555-0111')
,(511, N'Mr.', N'Abraham', N'L.', N'Swearengin', NULL, N'Wheel Gallery', N'adventure-works\shu0', N'abraham0@adventure-works.com', N'926-555-0136')
,(514, N'Mr.', N'Ryan', NULL, N'Calafato', NULL, N'Retail Mall', N'adventure-works\jos�1', N'ryan1@adventure-works.com', N'726-555-0155')
,(515, N'Mr.', N'Dragan', NULL, N'Tomic', NULL, N'Rural Bicycle Supply', N'adventure-works\jos�1', N'dragan1@adventure-works.com', N'833-555-0167')
,(516, N'Mr.', N'Thomas', N'R.', N'Michaels', NULL, N'Seats and Saddles Company', N'adventure-works\garrett1', N'thomas2@adventure-works.com', N'162-555-0174')
,(520, N'Ms.', N'Mari', N'B.', N'Caldwell', NULL, N'Metro Metals Co.', N'adventure-works\jae0', N'mari0@adventure-works.com', N'1 (11) 500 555-0118')
,(523, N'Ms.', N'Mary', N'M.', N'Gimmi', NULL, N'Futuristic Sport Distributors', N'adventure-works\shu0', N'mary6@adventure-works.com', N'149-555-0196')
,(526, N'Mr.', N'David', N'L.', N'Givens', NULL, N'Finer Sales and Service', N'adventure-works\jos�1', N'david15@adventure-works.com', N'605-555-0111')
,(527, N'Ms.', N'Diane', NULL, N'Tibbott', NULL, N'Fun Times Club', N'adventure-works\shu0', N'diane5@adventure-works.com', N'847-555-0184')
,(528, N'Ms.', N'Helen', N'M.', N'Meyer', NULL, N'Alpine Ski House', N'adventure-works\linda3', N'helen2@adventure-works.com', N'519-555-0112')
,(529, N'Ms.', N'Jeanie', N'R.', N'Glenn', N'PhD', N'Big-Time Bike Store', N'adventure-works\shu0', N'jeanie0@adventure-works.com', N'669-555-0149')
,(532, N'Ms.', N'Diane', N'R.', N'Glimp', NULL, N'The Showroom', N'adventure-works\jos�1', N'diane3@adventure-works.com', N'898-555-0137')
,(533, N'Ms.', N'Yuping', NULL, N'Tian', NULL, N'Tenth Bike Store', N'adventure-works\jos�1', N'yuping0@adventure-works.com', N'744-555-0123')
,(534, N'Mr.', N'Stephen', N'A.', N'Mew', NULL, N'Recommended Bicycles', N'adventure-works\garrett1', N'stephen4@adventure-works.com', N'399-555-0114')
,(538, N'Mr.', N'John', N'R.', N'Brooks', NULL, N'Prosperous Tours', N'adventure-works\jae0', N'john12@adventure-works.com', N'1 (11) 500 555-0179')
,(541, N'Mr.', N'Willie', N'P.', N'Brooks', N'Jr.', N'Nonskid Tire Company', N'adventure-works\pamela0', N'willie0@adventure-works.com', N'525-555-0174')
,(542, N'Mr.', N'Andrew', N'P.', N'Kobylinski', NULL, N'Finer Parts Shop', N'adventure-works\david8', N'andrew5@adventure-works.com', N'129-555-0185')
,(543, N'Mr.', N'R. Morgan', N'L.', N'Mendoza', NULL, N'Friendly Neighborhood Bikes', N'adventure-works\jillian0', N'rmorgan0@adventure-works.com', N'963-555-0146')
,(544, N'Mr.', N'Jay', NULL, N'Adams', NULL, N'Valley Bicycle Specialists', N'adventure-works\jillian0', N'jay1@adventure-works.com', N'158-555-0142')
,(545, N'Mr.', N'Christian', NULL, N'Kleinerman', NULL, N'Finish and Sealant Products', N'adventure-works\shu0', N'christian1@adventure-works.com', N'362-555-0177')
,(546, N'Mr.', N'Anton', NULL, N'Kirilov', NULL, N'Field Trip Store', N'adventure-works\linda3', N'anton0@adventure-works.com', N'608-555-0162')
,(547, N'Ms.', N'Gladys', N'F.', N'Mendiola', NULL, N'Curbside Sporting Goods', N'adventure-works\shu0', N'gladys0@adventure-works.com', N'535-555-0189')
,(550, N'Ms.', N'Raquel', NULL, N'Mello', NULL, N'Remote Bicycle Specialists', N'adventure-works\jos�1', N'raquel0@adventure-works.com', N'723-555-0124')
,(551, N'Mr.', N'Samuel', N'N.', N'Agcaoili', NULL, N'Vinyl and Plastic Goods Corporation', N'adventure-works\jos�1', N'samuel0@adventure-works.com', N'554-555-0110')
,(552, N'Mr.', N'Tim', NULL, N'Kim', NULL, N'Consolidated Messenger', N'adventure-works\garrett1', N'tim0@adventure-works.com', N'244-555-0115')
,(556, N'Ms.', N'Nancy', N'A.', N'McPhearson', NULL, N'Variety Cycling', N'adventure-works\jae0', N'nancy3@adventure-works.com', N'1 (11) 500 555-0195')
,(559, N'Ms.', N'Nkenge', NULL, N'McLin', NULL, N'Some Discount Store', N'adventure-works\pamela0', N'nkenge0@adventure-works.com', N'158-555-0123')
,(560, N'Mr.', N'Paul', N'L.', N'Alcorn', NULL, N'Major Sport Suppliers', N'adventure-works\david8', N'paul2@adventure-works.com', N'331-555-0162')
,(561, N'Mr.', N'Marvin', N'N.', N'Allen', NULL, N'Mountain Toy Store', N'adventure-works\jillian0', N'marvin0@adventure-works.com', N'447-555-0110')
,(562, N'Ms.', N'Yvonne', NULL, N'McKay', NULL, N'Practical Bike Supply Company', N'adventure-works\jillian0', N'yvonne1@adventure-works.com', N'623-555-0144')
,(563, N'Mr.', N'Sean', N'P.', N'Jacobson', NULL, N'Systematic Sales', N'adventure-works\shu0', N'sean2@adventure-works.com', N'555-555-0162')
,(564, N'Ms.', N'Michelle', NULL, N'Alexander', NULL, N'Imported and Domestic Cycles', N'adventure-works\linda3', N'michelle0@adventure-works.com', N'115-555-0175')
,(565, N'Mr.', N'Richard', N'M.', N'Bentley', N'Jr.', N'Metallic Paint and Overcoat Co', N'adventure-works\shu0', N'richard0@adventure-works.com', N'911-555-0153')
,(568, N'Mr.', N'Curtis', N'P.', N'Howard', NULL, N'Economy Center', N'adventure-works\jos�1', N'curtis0@adventure-works.com', N'555-555-0162')
,(569, N'Mr.', N'Cecil', N'J.', N'Allison', NULL, N'Designated Distributors', N'adventure-works\jos�1', N'cecil0@adventure-works.com', N'699-555-0155')
,(570, N'Mr.', N'Gregory', N'F.', N'Alderson', NULL, N'Family''s Favorite Bike Shop', N'adventure-works\garrett1', N'gregory0@adventure-works.com', N'968-555-0153')
,(574, N'Ms.', N'Janice', N'K.', N'Hows', NULL, N'Area Sheet Metal Supply', N'adventure-works\jae0', N'janice1@adventure-works.com', N'1 (11) 500 555-0119')
,(577, N'Mr.', N'George', N'M.', N'Huckaby', NULL, N'Synthetic Materials Manufacturing', N'adventure-works\pamela0', N'george1@adventure-works.com', N'851-555-0127')
,(578, N'Ms.', N'Carolyn', NULL, N'Farino', NULL, N'The Bike Shop', N'adventure-works\david8', N'carolyn0@adventure-works.com', N'957-555-0125')
,(579, N'Ms.', N'Kim', NULL, N'Abercrombie', NULL, N'Riders Company', N'adventure-works\jillian0', N'kim2@adventure-works.com', N'334-555-0137')
,(580, N'Mr.', N'Joshua', N'J.', N'Huff', NULL, N'Rural Sales and Service', N'adventure-works\jillian0', N'joshua0@adventure-works.com', N'190-555-0186')
,(581, N'Ms.', N'Geri', N'P.', N'Farrell', NULL, N'Safe Toys', N'adventure-works\shu0', N'geri0@adventure-works.com', N'329-555-0183')
,(582, N'Ms.', N'Catherine', N'R.', N'Abel', NULL, N'Professional Sales and Service', N'adventure-works\linda3', N'catherine0@adventure-works.com', N'747-555-0171')
,(583, N'Ms.', N'Laura', N'C.', N'Steele', NULL, N'Professional Containers and Packaging Co.', N'adventure-works\shu0', N'laura3@adventure-works.com', N'741-555-0173')
,(586, N'Ms.', N'Shanay', N'B.', N'Steelman', NULL, N'One Bike Company', N'adventure-works\jos�1', N'shanay0@adventure-works.com', N'797-555-0118')
,(587, N'Ms.', N'Rhoda', N'J.', N'Finley', NULL, N'Our Sporting Goods Store', N'adventure-works\jos�1', N'rhoda0@adventure-works.com', N'920-555-0191')
,(588, N'Mr.', N'Pat', N'A.', N'Chambers', NULL, N'General Cycle Storehouse', N'adventure-works\garrett1', N'pat1@adventure-works.com', N'127-555-0124')
,(592, N'Mr.', N'Stefano', NULL, N'Stefani', NULL, N'Cycling Goods', N'adventure-works\jae0', N'stefano0@adventure-works.com', N'1 (11) 500 555-0115')
,(595, N'Mr.', N'Alan', NULL, N'Steiner', NULL, N'Cycle Clearance', N'adventure-works\pamela0', N'alan4@adventure-works.com', N'792-555-0194')
,(596, N'Ms.', N'Kathie', NULL, N'Flood', NULL, N'Coho Sports', N'adventure-works\david8', N'kathie1@adventure-works.com', N'627-555-0192')
,(597, N'Mr.', N'Bob', NULL, N'Hodges', NULL, N'All Seasons Sports Supply', N'adventure-works\jillian0', N'bob2@adventure-works.com', N'129-555-0120')
,(598, N'Mr.', N'Derik', NULL, N'Stenerson', NULL, N'Black Bicycle Company', N'adventure-works\jillian0', N'derik0@adventure-works.com', N'441-555-0144')
,(599, N'Mr.', N'Raul', N'E.', N'Casts', NULL, N'Westside Plaza', N'adventure-works\shu0', N'raul0@adventure-works.com', N'362-555-0162')
,(600, N'Ms.', N'Holly', N'J.', N'Holt', NULL, N'Strenuous Exercise Shop', N'adventure-works\linda3', N'holly1@adventure-works.com', N'654-555-0150')
,(601, N'Mr.', N'Vassar', N'J.', N'Stern', NULL, N'Transport Bikes', N'adventure-works\shu0', N'vassar0@adventure-works.com', N'328-555-0123')
,(604, N'Ms.', N'Wathalee', N'R.', N'Steuber', NULL, N'Sellers of Cycles', N'adventure-works\pamela0', N'wathalee0@adventure-works.com', N'517-555-0120')
,(605, N'Mr.', N'Matthew', N'J.', N'Cavallari', NULL, N'Outstanding Cycles', N'adventure-works\david8', N'matthew1@adventure-works.com', N'695-555-0161')
,(606, N'Ms.', N'Helge', NULL, N'Hoeing', NULL, N'Little Bicycle Supply Shop', N'adventure-works\jillian0', N'helge0@adventure-works.com', N'850-555-0198')
,(607, N'Ms.', N'Alice', N'M.', N'Steiner', NULL, N'Maintenance and Repair for Bicycles', N'adventure-works\jillian0', N'alice4@adventure-works.com', N'355-555-0180')
,(608, N'Mr.', N'Steven', N'B.', N'Brown', N'IV', N'Golf and Cycle Store', N'adventure-works\shu0', N'steven1@adventure-works.com', N'280-555-0124')
,(609, N'Mr.', N'David', NULL, N'Hodgson', NULL, N'Good Toys', N'adventure-works\linda3', N'david16@adventure-works.com', N'969-555-0117')
,(610, N'Ms.', N'Liza Marie', N'N.', N'Stevens', NULL, N'Fitness Department Stores', N'adventure-works\shu0', N'lizamarie0@adventure-works.com', N'366-555-0110')
,(613, N'Mr.', N'Jim', NULL, N'Stewart', NULL, N'Famous Bike Shop', N'adventure-works\garrett1', N'jim5@adventure-works.com', N'226-555-0110')
,(617, N'Ms.', N'Arlene', NULL, N'Huff', NULL, N'Tubeless Tire Company', N'adventure-works\jae0', N'arlene0@adventure-works.com', N'1 (11) 500 555-0146')
,(620, N'Mr.', N'Matthew', N'M.', N'Hunter', NULL, N'Tires and Tubes', N'adventure-works\pamela0', N'matthew4@adventure-works.com', N'482-555-0188')
,(621, N'Mr.', N'Matthew', NULL, N'Hink', NULL, N'Running and Cycling Gear', N'adventure-works\david8', N'matthew3@adventure-works.com', N'146-555-0176')
,(622, N'Mr.', N'Robert', N'B.', N'Stotka', NULL, N'Gift and Toy Store', N'adventure-works\jillian0', N'robert12@adventure-works.com', N'493-555-0185')
,(623, N'Ms.', N'Phyllis', N'R.', N'Huntsman', NULL, N'Hardware Components', N'adventure-works\jillian0', N'phyllis1@adventure-works.com', N'153-555-0195')
,(624, N'Mr.', N'Mike', NULL, N'Hines', NULL, N'First Cycle Store', N'adventure-works\shu0', N'mike3@adventure-works.com', N'454-555-0160')
,(625, N'Ms.', N'Kayla', N'M.', N'Stotler', NULL, N'Major Sporting Goods', N'adventure-works\linda3', N'kayla0@adventure-works.com', N'315-555-0131')
,(626, N'Mr.', N'Lawrence', N'E.', N'Hurkett', NULL, N'Retail Sporting Goods', N'adventure-works\shu0', N'lawrence0@adventure-works.com', N'129-555-0185')
,(629, N'Mr.', N'Ryan', NULL, N'Ihrig', NULL, N'Efficient Cycling', N'adventure-works\jos�1', N'ryan4@adventure-works.com', N'809-555-0152')
,(630, N'Mr.', N'Andrew', N'R.', N'Hill', NULL, N'Eastside Parts Shop', N'adventure-works\jos�1', N'andrew4@adventure-works.com', N'194-555-0149')
,(631, N'Mr.', N'Robert', N'P.', N'Lyeba', NULL, N'Tandem Sales and Service', N'adventure-works\garrett1', N'robert8@adventure-works.com', N'631-555-0155')
,(635, N'Mr.', N'Roger', NULL, N'Van Houten', NULL, N'Sports Store', N'adventure-works\jae0', N'roger2@adventure-works.com', N'1 (11) 500 555-0110')
,(637, N'Mr.', N'Robert', NULL, N'Lyon', NULL, N'Reliable Retail Center', N'adventure-works\garrett1', N'robert9@adventure-works.com', N'666-555-0143')
,(641, N'Ms.', N'Rose', N'M.', N'Vandenouer', NULL, N'Extended Tours', N'adventure-works\jae0', N'rose1@adventure-works.com', N'1 (11) 500 555-0140')
GO
print 'Processed 400 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(643, N'Ms.', N'Denise', N'R.', N'Maccietto', NULL, N'Friendly Bike Shop', N'adventure-works\michael9', N'denise1@adventure-works.com', N'537-555-0190')
,(644, N'Mr.', N'Gregory', N'T.', N'Vanderbout', N'Jr.', N'Convenient Sales and Service', N'adventure-works\pamela0', N'gregory1@adventure-works.com', N'684-555-0134')
,(645, N'Mr.', N'Ronald', N'K.', N'Heymsfield', NULL, N'Superior Hardware Distributors', N'adventure-works\david8', N'ronald1@adventure-works.com', N'784-555-0120')
,(646, N'Mr.', N'Scott', NULL, N'MacDonald', NULL, N'Yellow Bicycle Company', N'adventure-works\jillian0', N'scott7@adventure-works.com', N'470-555-0171')
,(647, N'Mr.', N'Michael', NULL, N'Vanderhyde', NULL, N'Solid Bike Parts', N'adventure-works\jillian0', N'michael25@adventure-works.com', N'918-555-0141')
,(648, N'Ms.', N'Cheryl', N'M.', N'Herring', NULL, N'Small Bike Shop', N'adventure-works\shu0', N'cheryl0@adventure-works.com', N'158-555-0154')
,(649, N'Mr.', N'Walter', N'J.', N'Mays', N'Sr.', N'Sports Products Store', N'adventure-works\linda3', N'walter1@adventure-works.com', N'245-555-0191')
,(650, N'Ms.', N'Margaret', N'J.', N'Vanderkamp', NULL, N'Permanent Finish Products', N'adventure-works\shu0', N'margaret2@adventure-works.com', N'265-555-0143')
,(653, N'Ms.', N'Kara', N'N.', N'Vanderlinden', NULL, N'Mercantile Outlet', N'adventure-works\jos�1', N'kara0@adventure-works.com', N'680-555-0160')
,(654, N'Mr.', N'J�sus', NULL, N'Hernandez', NULL, N'Online Bike Warehouse', N'adventure-works\jos�1', N'j�sus0@adventure-works.com', N'214-555-0145')
,(655, N'Ms.', N'Irene', N'J.', N'Hernandez', NULL, N'Operational Manufacturing', N'adventure-works\garrett1', N'irene0@adventure-works.com', N'790-555-0197')
,(659, N'Mr.', N'Ajay', NULL, N'Manchepalli', NULL, N'Shipping Specialists', N'adventure-works\jae0', N'ajay0@adventure-works.com', N'1 (11) 500 555-0174')
,(660, N'Mr.', N'Nieves', N'J.', N'Vargas', N'II', N'Exhilarating Cycles', N'adventure-works\michael9', N'nieves0@adventure-works.com', N'371-555-0184')
,(661, N'Mr.', N'Kari', NULL, N'Hensien', NULL, N'General Department Stores', N'adventure-works\garrett1', N'kari0@adventure-works.com', N'143-555-0129')
,(665, N'Mr.', N'Tomas', N'M.', N'Manzanares', N'II', N'Authentic Sales and Service', N'adventure-works\jae0', N'tomas0@adventure-works.com', N'1 (11) 500 555-0178')
,(668, N'Ms.', N'Kathy', N'R.', N'Marcovecchio', NULL, N'Official Parts Shop', N'adventure-works\pamela0', N'kathy0@adventure-works.com', N'942-555-0141')
,(669, N'Ms.', N'Patricia', NULL, N'Doyle', NULL, N'Racing Bike Outlet', N'adventure-works\david8', N'patricia0@adventure-works.com', N'899-555-0134')
,(670, N'Ms.', N'Valerie', N'M.', N'Hendricks', NULL, N'First Bike Store', N'adventure-works\jillian0', N'valerie0@adventure-works.com', N'859-555-0140')
,(671, N'Ms.', N'Jill', N'K.', N'Markwood', NULL, N'Contoso, Ltd.', N'adventure-works\jillian0', N'jill2@adventure-works.com', N'747-555-0113')
,(672, N'Mr.', N'Gerald', N'M.', N'Drury', NULL, N'Utilitarian Sporting Goods', N'adventure-works\shu0', N'gerald0@adventure-works.com', N'169-555-0178')
,(673, N'Mr.', N'John', NULL, N'Hanson', NULL, N'Countryside Company', N'adventure-works\linda3', N'john20@adventure-works.com', N'107-555-0117')
,(674, N'Ms.', N'Melissa', N'R.', N'Marple', NULL, N'Discount Tours', N'adventure-works\shu0', N'melissa0@adventure-works.com', N'685-555-0117')
,(677, N'Ms.', N'Cecelia', N'L.', N'Marshall', NULL, N'Tire Exchange', N'adventure-works\jos�1', N'cecelia0@adventure-works.com', N'394-555-0168')
,(678, N'Mr.', N'Reuben', NULL, N'D''sa', NULL, N'Vigorous Exercise Company', N'adventure-works\jos�1', N'reuben1@adventure-works.com', N'916-555-0137')
,(679, N'Ms.', N'Brenda', N'F.', N'Heaney', NULL, N'Superb Sales and Repair', N'adventure-works\garrett1', N'brenda3@adventure-works.com', N'393-555-0167')
,(683, N'Ms.', N'Linda', NULL, N'Martin', NULL, N'Oils and Fluids Warehouse', N'adventure-works\jae0', N'linda8@adventure-works.com', N'1 (11) 500 555-0137')
,(685, N'Mr.', N'James', N'B.', N'Haugh', N'Jr.', N'Family Cycle Store', N'adventure-works\garrett1', N'james8@adventure-works.com', N'763-555-0120')
,(689, N'Ms.', N'Sandra', N'I.', N'Martinez', NULL, N'Consumer Equipment', N'adventure-works\jae0', N'sandra3@adventure-works.com', N'1 (11) 500 555-0113')
,(692, N'Ms.', N'Bev', N'L.', N'Desalvo', NULL, N'Successful Sales Company', N'adventure-works\pamela0', N'bev0@adventure-works.com', N'143-555-0113')
,(693, N'Mr.', N'Bart', NULL, N'Duncan', NULL, N'Stock Parts and Supplies', N'adventure-works\david8', N'bart0@adventure-works.com', N'539-555-0121')
,(694, N'Ms.', N'Ann', N'T.', N'Hass', NULL, N'The Accessories Store', N'adventure-works\jillian0', N'ann2@adventure-works.com', N'713-555-0168')
,(695, N'Mr.', N'Rob', NULL, N'Caron', NULL, N'Responsible Bike Dealers', N'adventure-works\jillian0', N'rob2@adventure-works.com', N'620-555-0117')
,(696, N'Mr.', N'Maciej', NULL, N'Dusza', NULL, N'Roadway Supplies', N'adventure-works\shu0', N'maciej1@adventure-works.com', N'962-555-0144')
,(697, N'Mr.', N'Roger', NULL, N'Harui', NULL, N'Brakes and Gears', N'adventure-works\linda3', N'roger0@adventure-works.com', N'774-555-0133')
,(698, N'Mr.', N'Andy', NULL, N'Carothers', NULL, N'Western Bike Supplies', N'adventure-works\shu0', N'andy1@adventure-works.com', N'944-555-0148')
,(701, N'Ms.', N'Linda', N'R.', N'Ecoffey', NULL, N'Future Bikes', N'adventure-works\jos�1', N'linda5@adventure-works.com', N'674-555-0188')
,(29485, N'Ms.', N'Catherine', N'R.', N'Abel', NULL, N'Professional Sales and Service', N'adventure-works\linda3', N'catherine0@adventure-works.com', N'747-555-0171')
,(29486, N'Ms.', N'Kim', NULL, N'Abercrombie', NULL, N'Riders Company', N'adventure-works\jillian0', N'kim2@adventure-works.com', N'334-555-0137')
,(29489, N'Ms.', N'Frances', N'B.', N'Adams', NULL, N'Area Bike Accessories', N'adventure-works\shu0', N'frances0@adventure-works.com', N'991-555-0183')
,(29490, N'Ms.', N'Margaret', N'J.', N'Smith', NULL, N'Bicycle Accessories and Kits', N'adventure-works\david8', N'margaret0@adventure-works.com', N'959-555-0151')
,(29492, N'Mr.', N'Jay', NULL, N'Adams', NULL, N'Valley Bicycle Specialists', N'adventure-works\jillian0', N'jay1@adventure-works.com', N'158-555-0142')
,(29494, N'Mr.', N'Samuel', N'N.', N'Agcaoili', NULL, N'Vinyl and Plastic Goods Corporation', N'adventure-works\jos�1', N'samuel0@adventure-works.com', N'554-555-0110')
,(29496, N'Mr.', N'Robert', N'E.', N'Ahlering', NULL, N'Fun Toys and Bikes', N'adventure-works\shu0', N'robert1@adventure-works.com', N'678-555-0175')
,(29497, N'Mr.', N'Fran�ois', NULL, N'Ferrier', NULL, N'Great Bikes ', N'adventure-works\david8', N'fran�ois1@adventure-works.com', N'571-555-0128')
,(29499, N'Ms.', N'Amy', N'E.', N'Alberts', NULL, N'Valley Toy Store', N'adventure-works\jos�1', N'amy1@adventure-works.com', N'727-555-0115')
,(29502, N'Mr.', N'Paul', N'L.', N'Alcorn', NULL, N'Major Sport Suppliers', N'adventure-works\david8', N'paul2@adventure-works.com', N'331-555-0162')
,(29503, N'Mr.', N'Gregory', N'F.', N'Alderson', NULL, N'Family''s Favorite Bike Shop', N'adventure-works\garrett1', N'gregory0@adventure-works.com', N'968-555-0153')
,(29505, N'Ms.', N'Michelle', NULL, N'Alexander', NULL, N'Imported and Domestic Cycles', N'adventure-works\linda3', N'michelle0@adventure-works.com', N'115-555-0175')
,(29506, N'Mr.', N'Sean', N'P.', N'Jacobson', NULL, N'Systematic Sales', N'adventure-works\shu0', N'sean2@adventure-works.com', N'555-555-0162')
,(29508, N'Mr.', N'Marvin', N'N.', N'Allen', NULL, N'Mountain Toy Store', N'adventure-works\jillian0', N'marvin0@adventure-works.com', N'447-555-0110')
,(29510, N'Mr.', N'Cecil', N'J.', N'Allison', NULL, N'Designated Distributors', N'adventure-works\jos�1', N'cecil0@adventure-works.com', N'699-555-0155')
,(29511, N'Mr.', N'Oscar', N'L.', N'Alpuerto', NULL, N'Bold Bike Accessories', N'adventure-works\linda3', N'oscar0@adventure-works.com', N'855-555-0174')
,(29515, N'Mr.', N'Maxwell', N'J.', N'Amland', NULL, N'Serious Cycles', N'adventure-works\garrett1', N'maxwell0@adventure-works.com', N'614-555-0134')
,(29517, N'Ms.', N'Ramona', N'J.', N'Antrim', NULL, N'Novelty Bikes', N'adventure-works\michael9', N'ramona0@adventure-works.com', N'327-555-0148')
,(29521, N'Mr.', N'Tom', N'H', N'Johnston', NULL, N'Brightwork Company', N'adventure-works\shu0', N'tom1@adventure-works.com', N'883-555-0177')
,(29522, N'Mr.', N'Thomas', N'B.', N'Armstrong', N'Jr.', N'Resale Services', N'adventure-works\linda3', N'thomas1@adventure-works.com', N'226-555-0146')
,(29523, N'Mr.', N'John', NULL, N'Arthur', NULL, N'The Gear Store', N'adventure-works\jillian0', N'john6@adventure-works.com', N'149-555-0113')
,(29524, N'Mr.', N'Chris', NULL, N'Ashton', NULL, N'Immense Manufacturing Company', N'adventure-works\jillian0', N'chris3@adventure-works.com', N'556-555-0145')
,(29525, N'Ms.', N'Teresa', NULL, N'Atkinson', NULL, N'Extended Bike Sales', N'adventure-works\linda3', N'teresa0@adventure-works.com', N'129-555-0110')
,(29527, N'Mr.', N'Robert', N'A.', N'Avalos', NULL, N'Workout Emporium', N'adventure-works\jos�1', N'robert2@adventure-works.com', N'665-555-0198')
,(29528, N'Mr.', N'Stephen', N'M.', N'Ayers', NULL, N'Work and Play Association', N'adventure-works\michael9', N'stephen1@adventure-works.com', N'818-555-0171')
,(29530, N'Mr.', N'Daniel', NULL, N'Blanco', NULL, N'Nice Bikes', N'adventure-works\garrett1', N'daniel0@adventure-works.com', N'221-555-0167')
,(29531, N'Mr.', N'Cory', N'K.', N'Booth', NULL, N'Remarkable Bike Store', N'adventure-works\linda3', N'cory0@adventure-works.com', N'121-555-0157')
,(29532, N'Mr.', N'James', N'B.', N'Bailey', N'Jr.', N'Road-Way Mart', N'adventure-works\david8', N'james3@adventure-works.com', N'234-555-0112')
,(29533, N'Mr.', N'Douglas', N'A.', N'Baldwin', N'Jr.', N'Small Cycle Store', N'adventure-works\michael9', N'douglas1@adventure-works.com', N'583-555-0130')
,(29535, N'Mr.', N'Wayne', N'N.', N'Banack', NULL, N'Grand Bicycle Stores', N'adventure-works\jillian0', N'wayne0@adventure-works.com', N'640-555-0189')
,(29536, N'Mr.', N'Robert', N'L.', N'Barker', NULL, N'Kickstand Sellers', N'adventure-works\michael9', N'robert3@adventure-works.com', N'241-555-0112')
,(29539, N'Mr.', N'Josh', NULL, N'Barnhill', NULL, N'Gasless Cycle Shop', N'adventure-works\garrett1', N'josh0@adventure-works.com', N'584-555-0192')
,(29541, NULL, N'Gytis', N'M', N'Barzdukas', NULL, N'Transportation Options', N'adventure-works\jos�1', N'gytis0@adventure-works.com', N'257-555-0119')
,(29544, N'Mr.', N'Shaun', NULL, N'Beasley', NULL, N'Finer Cycle Shop', N'adventure-works\garrett1', N'shaun0@adventure-works.com', N'396-555-0187')
,(29545, N'Mr.', N'John', N'A.', N'Beaver', NULL, N'Center Cycle Shop', N'adventure-works\pamela0', N'john8@adventure-works.com', N'521-555-0195')
,(29546, N'Mr.', N'Christopher', N'R.', N'Beck', N'Jr.', N'Bulk Discount Store', N'adventure-works\jae0', N'christopher1@adventure-works.com', N'1 (11) 500 555-0132')
,(29548, N'Ms.', N'Ann', NULL, N'Beebe', NULL, N'First-Rate Outlet', N'adventure-works\garrett1', N'ann0@adventure-works.com', N'277-555-0169')
,(29550, N'Mr.', N'Stanley', N'A.', N'Alan', N'Jr.', N'Another Bicycle Company', N'adventure-works\david8', N'stanley0@adventure-works.com', N'156-555-0126')
,(29553, N'Ms.', N'Edna', N'J.', N'Benson', NULL, N'Unsurpassed Bikes', N'adventure-works\jillian0', N'edna0@adventure-works.com', N'789-555-0189')
,(29554, N'Mr.', N'Payton', N'P.', N'Benson', NULL, N'Field Trip Inc', N'adventure-works\michael9', N'payton0@adventure-works.com', N'528-555-0183')
,(29557, N'Mr.', N'Alexander', N'J.', N'Berger', N'II', N'Odometers and Accessories Company', N'adventure-works\garrett1', N'alexander0@adventure-works.com', N'519-555-0151')
,(29558, N'Mr.', N'John', N'M.', N'Berger', N'Jr.', N'Scratch-Resistant Finishes Company', N'adventure-works\jos�1', N'john10@adventure-works.com', N'156-555-0111')
,(29559, N'Mr.', N'Robert', N'M.', N'Bernacchi', NULL, N'Safe Cycles Shop', N'adventure-works\david8', N'robert4@adventure-works.com', N'449-555-0176')
,(29560, N'Mr.', N'Matthias', NULL, N'Berndt', NULL, N'Number 1 Supply', N'adventure-works\shu0', N'matthias1@adventure-works.com', N'384-555-0169')
,(29562, N'Mr.', N'Steven', N'B.', N'Brown', N'IV', N'Golf and Cycle Store', N'adventure-works\shu0', N'steven1@adventure-works.com', N'280-555-0124')
,(29565, N'Mr.', N'Jimmy', NULL, N'Bischoff', NULL, N'World Bike Discount Store', N'adventure-works\linda3', N'jimmy1@adventure-works.com', N'992-555-0111')
,(29566, N'Ms.', N'Mae', N'M.', N'Black', NULL, N'Historic Bicycle Sales', N'adventure-works\michael9', N'mae1@adventure-works.com', N'264-555-0143')
,(29567, N'Ms.', N'Jackie', N'E.', N'Blackwell', NULL, N'Commuter Bicycle Store', N'adventure-works\jos�1', N'jackie0@adventure-works.com', N'972-555-0163')
,(29568, N'Mr.', N'Donald', N'L.', N'Blanton', NULL, N'Coalition Bike Company', N'adventure-works\shu0', N'donald0@adventure-works.com', N'357-555-0161')
,(29569, N'Ms.', N'Linda', N'E.', N'Burnett', NULL, N'Travel Systems', N'adventure-works\jillian0', N'linda4@adventure-works.com', N'121-555-0121')
,(29570, N'Mr.', N'Michael', N'Greg', N'Blythe', NULL, N'Grease and Oil Products Company', N'adventure-works\jillian0', N'michael11@adventure-works.com', N'126-555-0172')
,(29571, N'Ms.', N'Gabriel', N'L.', N'Bockenkamp', NULL, N'Moderately-Priced Bikes Store', N'adventure-works\pamela0', N'gabriel0@adventure-works.com', N'763-555-0145')
,(29573, N'Sr.', N'Luis', NULL, N'Bonifaz', NULL, N'Economy Bikes Company', N'adventure-works\linda3', N'luis0@adventure-works.com', N'688-555-0113')
,(29574, N'Mr.', N'Randall', NULL, N'Boseman', NULL, N'Third Bike Store', N'adventure-works\jillian0', N'randall0@adventure-works.com', N'383-555-0117')
,(29576, N'Mr.', N'Eli', NULL, N'Bowen', NULL, N'Bikes for Two', N'adventure-works\jos�1', N'eli0@adventure-works.com', N'371-555-0143')
,(29577, N'Mr.', N'Lester', N'J.', N'Bowman', N'Sr.', N'Metal Processing Company', N'adventure-works\garrett1', N'lester0@adventure-works.com', N'844-555-0112')
,(29579, N'Mr.', N'Cornelius', N'L.', N'Brandon', NULL, N'Initial Bike Company', N'adventure-works\shu0', N'cornelius0@adventure-works.com', N'229-555-0114')
,(29580, N'Mr.', N'Richard', NULL, N'Bready', NULL, N'Latest Sports Equipment', N'adventure-works\david8', N'richard1@adventure-works.com', N'340-555-0131')
,(29582, N'Mr.', N'Ted', NULL, N'Bremer', NULL, N'Raw Materials Inc', N'adventure-works\pamela0', N'ted0@adventure-works.com', N'962-555-0166')
,(29583, N'Mr.', N'Alan', NULL, N'Brewer', NULL, N'Lots of Bikes Storehouse', N'adventure-works\jillian0', N'alan1@adventure-works.com', N'494-555-0134')
,(29584, N'Mr.', N'Walter', N'J.', N'Brian', N'IV', N'Futuristic Bikes', N'adventure-works\shu0', N'walter0@adventure-works.com', N'163-555-0155')
,(29585, N'Mr.', N'Christopher', N'M.', N'Bright', NULL, N'Parcel Express Delivery Service', N'adventure-works\david8', N'christopher2@adventure-works.com', N'162-555-0166')
,(29587, N'Mr.', N'John', N'R.', N'Brooks', NULL, N'Prosperous Tours', N'adventure-works\jae0', N'john12@adventure-works.com', N'1 (11) 500 555-0179')
,(29588, N'Mr.', N'Willie', N'P.', N'Brooks', N'Jr.', N'Nonskid Tire Company', N'adventure-works\pamela0', N'willie0@adventure-works.com', N'525-555-0174')
,(29590, N'Mr.', N'Jo', NULL, N'Brown', NULL, N'Metro Bike Works', N'adventure-works\michael9', N'jo2@adventure-works.com', N'689-555-0130')
GO
print 'Processed 500 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(29591, N'Mr.', N'Robert', NULL, N'Brown', NULL, N'Best o'' Bikes', N'adventure-works\jillian0', N'robert5@adventure-works.com', N'575-555-0189')
,(29593, N'Ms.', N'Mary', N'K.', N'Browning', NULL, N'Client Discount Store', N'adventure-works\jillian0', N'mary5@adventure-works.com', N'658-555-0146')
,(29596, N'Mr.', N'Eric', N'J.', N'Brumfield', NULL, N'Requisite Part Supply', N'adventure-works\jos�1', N'eric3@adventure-works.com', N'644-555-0114')
,(29598, N'Mr.', N'Michael', NULL, N'Brundage', NULL, N'Mechanical Products Ltd.', N'adventure-works\shu0', N'michael13@adventure-works.com', N'128-555-0148')
,(29599, N'Ms.', N'Shirley', N'R.', N'Bruner', NULL, N'Commendable Bikes', N'adventure-works\david8', N'shirley0@adventure-works.com', N'383-555-0155')
,(29600, N'Ms.', N'June', N'B.', N'Brunner', NULL, N'Online Bike Sellers', N'adventure-works\michael9', N'june0@adventure-works.com', N'249-555-0172')
,(29601, N'Mr.', N'Dirk', N'J.', N'Bruno', NULL, N'Custom Accessories Company', N'adventure-works\garrett1', N'dirk0@adventure-works.com', N'817-555-0114')
,(29603, N'Sra.', N'Janaina Barreiro Gambaro', NULL, N'Bueno', NULL, N'Courteous Bicycle Specialists', N'adventure-works\jos�1', N'janainabarreirogambaro0@adventure-works.com', N'476-555-0184')
,(29605, N'Ms.', N'Megan', N'E.', N'Burke', NULL, N'Professional Cycle Store', N'adventure-works\shu0', N'megan0@adventure-works.com', N'148-555-0149')
,(29606, N'Ms.', N'Karren', N'K.', N'Burkhardt', NULL, N'Fifth Bike Store', N'adventure-works\david8', N'karren0@adventure-works.com', N'652-555-0132')
,(29608, N'Mr.', N'Timothy', N'B.', N'Burnett', N'Jr.', N'Farthest Bike Store', N'adventure-works\jos�1', N'timothy0@adventure-works.com', N'251-555-0172')
,(29611, N'Mr.', N'Jared', N'L.', N'Bustamante', NULL, N'Alternative Vehicles', N'adventure-works\pamela0', N'jared0@adventure-works.com', N'164-555-0147')
,(29612, N'Mr.', N'Richard', N'A.', N'Byham', NULL, N'Channel Outlet', N'adventure-works\jae0', N'richard2@adventure-works.com', N'1 (11) 500 555-0138')
,(29614, N'Mr.', N'Ryan', NULL, N'Calafato', NULL, N'Retail Mall', N'adventure-works\jos�1', N'ryan1@adventure-works.com', N'726-555-0155')
,(29615, N'Ms.', N'Mari', N'B.', N'Caldwell', NULL, N'Metro Metals Co.', N'adventure-works\jae0', N'mari0@adventure-works.com', N'1 (11) 500 555-0118')
,(29616, N'Ms.', N'Barbara', N'J.', N'Calone', NULL, N'Sheet Metal Manufacturing', N'adventure-works\jillian0', N'barbara2@adventure-works.com', N'145-555-0152')
,(29617, N'Ms.', N'Lindsey', N'R.', N'Camacho', NULL, N'Thorough Parts and Repair Services', N'adventure-works\pamela0', N'lindsey0@adventure-works.com', N'827-555-0143')
,(29618, N'Sr.', N'Gustavo', NULL, N'Camargo', NULL, N'Uttermost Bike Shop', N'adventure-works\jae0', N'gustavo1@adventure-works.com', N'1 (11) 500 555-0118')
,(29620, N'Ms.', N'Joan', N'M.', N'Campbell', NULL, N'Two-Wheeled Transit Company', N'adventure-works\jos�1', N'joan0@adventure-works.com', N'700-555-0155')
,(29622, N'Mr.', N'Henry', N'L.', N'Campen', NULL, N'Metro Cycle Shop', N'adventure-works\david8', N'henry0@adventure-works.com', N'635-555-0126')
,(29623, N'Mr.', N'Chris', NULL, N'Cannon', NULL, N'Outdoor Sporting Goods', N'adventure-works\shu0', N'chris5@adventure-works.com', N'118-555-0131')
,(29625, N'Ms.', N'Suzana De Abreu', N'A.', N'Canuto', NULL, N'Petroleum Products Distributors', N'adventure-works\jos�1', N'suzanadeabreu0@adventure-works.com', N'990-555-0141')
,(29627, N'Mr.', N'Johnny', N'A.', N'Caprio', N'Jr.', N'Bikes and Motorbikes', N'adventure-works\garrett1', N'johnny0@adventure-works.com', N'112-555-0191')
,(29629, N'Mr.', N'Carlton', N'M.', N'Carlisle', NULL, N'Camping and Sports Store', N'adventure-works\jos�1', N'carlton0@adventure-works.com', N'193-555-0116')
,(29631, N'Ms.', N'Jane', N'N.', N'Carmichael', NULL, N'Rural Department Store', N'adventure-works\shu0', N'jane0@adventure-works.com', N'716-555-0167')
,(29632, N'Ms.', N'Jovita', N'A.', N'Carmody', NULL, N'Sports Commodities', N'adventure-works\david8', N'jovita0@adventure-works.com', N'646-555-0137')
,(29635, N'Mr.', N'Rob', NULL, N'Caron', NULL, N'Responsible Bike Dealers', N'adventure-works\jillian0', N'rob2@adventure-works.com', N'620-555-0117')
,(29636, N'Mr.', N'Andy', NULL, N'Carothers', NULL, N'Western Bike Supplies', N'adventure-works\shu0', N'andy1@adventure-works.com', N'944-555-0148')
,(29637, N'Ms.', N'Donna', N'F.', N'Carreras', NULL, N'Advanced Bike Components', N'adventure-works\jillian0', N'donna0@adventure-works.com', N'279-555-0130')
,(29638, N'Ms.', N'Rosmarie', N'J.', N'Carroll', NULL, N'Aerobic Exercise Company', N'adventure-works\linda3', N'rosmarie0@adventure-works.com', N'244-555-0112')
,(29639, N'Mr.', N'Joseph', N'N.', N'Castellucio', NULL, N'Corner Bicycle Supply', N'adventure-works\jos�1', N'joseph1@adventure-works.com', N'180-555-0114')
,(29641, N'Mr.', N'Raul', N'E.', N'Casts', NULL, N'Westside Plaza', N'adventure-works\shu0', N'raul0@adventure-works.com', N'362-555-0162')
,(29643, N'Mr.', N'Matthew', N'J.', N'Cavallari', NULL, N'Outstanding Cycles', N'adventure-works\david8', N'matthew1@adventure-works.com', N'695-555-0161')
,(29644, N'Ms.', N'Brigid', N'F.', N'Cavendish', NULL, N'Vigorous Sports Store', N'adventure-works\jae0', N'brigid0@adventure-works.com', N'1 (11) 500 555-0178')
,(29645, N'Mr.', N'Andrew', NULL, N'Cencini', NULL, N'Sports Merchandise', N'adventure-works\pamela0', N'andrew2@adventure-works.com', N'644-555-0111')
,(29646, N'Ms.', N'Stacey', N'M.', N'Cereghino', NULL, N'Fitness Toy Store', N'adventure-works\jillian0', N'stacey0@adventure-works.com', N'351-555-0131')
,(29649, N'Mr.', N'Pat', N'A.', N'Chambers', NULL, N'General Cycle Storehouse', N'adventure-works\garrett1', N'pat1@adventure-works.com', N'127-555-0124')
,(29650, N'Mr.', N'Forrest', N'J.', N'Chandler', NULL, N'Fitness Cycling', N'adventure-works\shu0', N'forrest0@adventure-works.com', N'448-555-0179')
,(29651, N'Mr.', N'Lee', N'J.', N'Chapla', NULL, N'Good Bike Shop', N'adventure-works\jillian0', N'lee0@adventure-works.com', N'223-555-0184')
,(29653, N'Mr.', N'Pei', NULL, N'Chow', NULL, N'Thrilling Bike Tours', N'adventure-works\linda3', N'pei0@adventure-works.com', N'789-555-0184')
,(29654, N'Mr.', N'Yao-Qiang', NULL, N'Cheng', NULL, N'This Area Sporting Goods', N'adventure-works\jillian0', N'yao-qiang0@adventure-works.com', N'344-555-0181')
,(29655, N'Ms.', N'Nicky', N'E.', N'Chesnut', NULL, N'Full-Service Bike Store', N'adventure-works\michael9', N'nicky0@adventure-works.com', N'264-555-0164')
,(29659, N'Ms.', N'Ruth', N'A.', N'Choin', NULL, N'Genuine Bike Shop', N'adventure-works\jillian0', N'ruth1@adventure-works.com', N'273-555-0181')
,(29660, N'Mr.', N'Anthony', NULL, N'Chor', NULL, N'Extreme Riding Supplies', N'adventure-works\linda3', N'anthony0@adventure-works.com', N'429-555-0145')
,(29662, N'Ms.', N'Jill', N'J.', N'Christie', NULL, N'Fleet Bikes', N'adventure-works\linda3', N'jill1@adventure-works.com', N'927-555-0198')
,(29663, N'Ms.', N'Alice', NULL, N'Clark', NULL, N'Local Hardware Factory', N'adventure-works\jillian0', N'alice1@adventure-works.com', N'221-555-0141')
,(29666, N'Ms.', N'Jane', NULL, N'Clayton', NULL, N'South Bike Company', N'adventure-works\garrett1', N'jane1@adventure-works.com', N'206-555-0195')
,(29668, N'Ms.', N'Connie', N'L.', N'Coffman', NULL, N'Discount Bicycle Specialists', N'adventure-works\jillian0', N'connie0@adventure-works.com', N'426-555-0181')
,(29671, N'Mr.', N'Pat', NULL, N'Coleman', NULL, N'Machines & Cycles Store', N'adventure-works\garrett1', N'pat2@adventure-works.com', N'292-555-0128')
,(29673, N'Mr.', N'John', N'L.', N'Colon', NULL, N'Two Wheels Cycle Store', N'adventure-works\linda3', N'john14@adventure-works.com', N'397-555-0144')
,(29674, N'Mr.', N'Scott', N'A.', N'Colvin', NULL, N'Westside Cycle Store', N'adventure-works\jillian0', N'scott1@adventure-works.com', N'119-555-0144')
,(29677, N'Mr.', N'William', N'J.', N'Conner', NULL, N'Urban Sports Emporium', N'adventure-works\jos�1', N'william1@adventure-works.com', N'383-555-0111')
,(29680, N'Ms.', N'Dorothy', N'J.', N'Contreras', NULL, N'Sixth Bike Store', N'adventure-works\jos�1', N'dorothy0@adventure-works.com', N'428-555-0176')
,(29682, N'Mr.', N'Scott', NULL, N'Cooper', NULL, N'Vehicle Shop', N'adventure-works\shu0', N'scott2@adventure-works.com', N'773-555-0182')
,(29683, N'Ms.', N'Eva', NULL, N'Corets', NULL, N'First Department Stores', N'adventure-works\david8', N'eva0@adventure-works.com', N'542-555-0164')
,(29684, N'Mr.', N'Marlin', N'M.', N'Coriell', NULL, N'Grand Sport Boutique', N'adventure-works\michael9', N'marlin0@adventure-works.com', N'941-555-0155')
,(29686, N'Mr.', N'Jack', NULL, N'Creasey', NULL, N'Distinctive Store', N'adventure-works\shu0', N'jack2@adventure-works.com', N'539-555-0182')
,(29688, N'Mr.', N'Grant', NULL, N'Culbertson', NULL, N'Handy Bike Services', N'adventure-works\michael9', N'grant1@adventure-works.com', N'859-555-0173')
,(29689, N'Mr.', N'Scott', NULL, N'Culp', NULL, N'Friendly Bike Shop', N'adventure-works\david8', N'scott3@adventure-works.com', N'119-555-0167')
,(29690, N'Mr.', N'Conor', NULL, N'Cunningham', NULL, N'Fashionable Bikes and Accessories', N'adventure-works\shu0', N'conor0@adventure-works.com', N'115-555-0113')
,(29692, N'Mr.', N'Thierry', NULL, N'D''Hers', NULL, N'Citywide Service and Repair', N'adventure-works\jos�1', N'thierry1@adventure-works.com', N'680-555-0192')
,(29695, N'Ms.', N'Megan', N'N.', N'Davis', NULL, N'Rugged Bikes', N'adventure-works\david8', N'megan1@adventure-works.com', N'839-555-0198')
,(29696, N'Sr.', N'Alvaro', NULL, N'De Matos Miranda Filho', NULL, N'Principal Bike Company', N'adventure-works\shu0', N'alvaro0@adventure-works.com', N'551-555-0155')
,(29698, N'Mr.', N'Jacob', N'N.', N'Dean', NULL, N'Finer Riding Supplies', N'adventure-works\jos�1', N'jacob0@adventure-works.com', N'767-555-0151')
,(29699, N'Mr.', N'Alexander', N'J.', N'Deborde', NULL, N'Neighborhood Store', N'adventure-works\garrett1', N'alexander1@adventure-works.com', N'394-555-0176')
,(29702, N'Ms.', N'Aidan', NULL, N'Delaney', NULL, N'Paint Supply', N'adventure-works\jillian0', N'aidan0@adventure-works.com', N'358-555-0188')
,(29703, N'Mr.', N'Stefan', NULL, N'Delmarco', NULL, N'Preferred Bikes', N'adventure-works\linda3', N'stefan0@adventure-works.com', N'819-555-0186')
,(29705, N'Ms.', N'Della', N'F.', N'Demott Jr', NULL, N'Rewarding Activities Company', N'adventure-works\garrett1', N'della0@adventure-works.com', N'752-555-0185')
,(29708, N'Mr.', N'Prashanth', NULL, N'Desai', NULL, N'Stationary Bikes and Stands', N'adventure-works\jillian0', N'prashanth0@adventure-works.com', N'138-555-0156')
,(29709, N'Ms.', N'Bev', N'L.', N'Desalvo', NULL, N'Successful Sales Company', N'adventure-works\pamela0', N'bev0@adventure-works.com', N'143-555-0113')
,(29710, N'Ms.', N'Brenda', NULL, N'Diaz', NULL, N'Downtown Hotel', N'adventure-works\shu0', N'brenda2@adventure-works.com', N'147-555-0192')
,(29711, N'Ms.', N'Gabriele', NULL, N'Dickmann', NULL, N'Certified Sports Supply', N'adventure-works\jos�1', N'gabriele0@adventure-works.com', N'835-555-0116')
,(29713, N'Mr.', N'Dick', NULL, N'Dievendorff', NULL, N'Rampart Amusement Company', N'adventure-works\jae0', N'dick1@adventure-works.com', N'1 (11) 500 555-0193')
,(29714, N'Mr.', N'Rudolph', N'J.', N'Dillon', N'Sr.', N'Sundry Sporting Goods', N'adventure-works\jos�1', N'rudolph0@adventure-works.com', N'722-555-0169')
,(29716, N'Mr.', N'Blaine', NULL, N'Dockter', NULL, N'Farthermost Bike Shop', N'adventure-works\shu0', N'blaine0@adventure-works.com', N'156-555-0187')
,(29717, N'Ms.', N'Cindy', N'M.', N'Dodd', NULL, N'Suburban Cycle Shop', N'adventure-works\david8', N'cindy0@adventure-works.com', N'706-555-0140')
,(29719, N'Ms.', N'Patricia', NULL, N'Doyle', NULL, N'Racing Bike Outlet', N'adventure-works\david8', N'patricia0@adventure-works.com', N'899-555-0134')
,(29720, N'Mr.', N'Gerald', N'M.', N'Drury', NULL, N'Utilitarian Sporting Goods', N'adventure-works\shu0', N'gerald0@adventure-works.com', N'169-555-0178')
,(29722, N'Mr.', N'Reuben', NULL, N'D''sa', NULL, N'Vigorous Exercise Company', N'adventure-works\jos�1', N'reuben1@adventure-works.com', N'916-555-0137')
,(29727, N'Mr.', N'Bart', NULL, N'Duncan', NULL, N'Stock Parts and Supplies', N'adventure-works\david8', N'bart0@adventure-works.com', N'539-555-0121')
,(29728, N'Mr.', N'Maciej', NULL, N'Dusza', NULL, N'Roadway Supplies', N'adventure-works\shu0', N'maciej1@adventure-works.com', N'962-555-0144')
,(29730, N'Ms.', N'Linda', N'R.', N'Ecoffey', NULL, N'Future Bikes', N'adventure-works\jos�1', N'linda5@adventure-works.com', N'674-555-0188')
,(29732, N'Ms.', N'Carol', N'B.', N'Elliott', NULL, N'Satin Finish Company', N'adventure-works\jillian0', N'carol2@adventure-works.com', N'847-555-0151')
,(29733, N'Ms.', N'Shannon', N'P.', N'Elliott', NULL, N'Regional Manufacturing', N'adventure-works\shu0', N'shannon0@adventure-works.com', N'425-555-0158')
,(29734, N'Ms.', N'Jauna', N'E.', N'Elson', NULL, N'Original Bicycle Supply Company', N'adventure-works\jos�1', N'jauna0@adventure-works.com', N'185-555-0190')
,(29736, N'Mr.', N'Terry', NULL, N'Eminhizer', NULL, N'Action Bicycle Specialists', N'adventure-works\jae0', N'terry1@adventure-works.com', N'1 (11) 500 555-0176')
,(29737, N'Mr.', N'John', NULL, N'Emory', NULL, N'Roadway Bike Emporium', N'adventure-works\pamela0', N'john16@adventure-works.com', N'691-555-0149')
,(29738, N'Ms.', N'Gail', NULL, N'Erickson', NULL, N'Sleek Bikes ', N'adventure-works\jillian0', N'gail1@adventure-works.com', N'834-555-0132')
,(29739, N'Mr.', N'Mark', N'B', N'Erickson', NULL, N'Retail Sporting Equipment', N'adventure-works\shu0', N'mark2@adventure-works.com', N'962-555-0112')
,(29740, N'Ms.', N'Martha', N'R.', N'Espinoza', NULL, N'Price-Cutter Discount Bikes', N'adventure-works\jos�1', N'martha0@adventure-works.com', N'753-555-0179')
,(29741, N'Sra.', N'Janeth', NULL, N'Esteves', NULL, N'Central Bicycle Specialists', N'adventure-works\jae0', N'janeth1@adventure-works.com', N'1 (11) 500 555-0136')
,(29742, N'Ms.', N'Twanna', N'R.', N'Evans', NULL, N'Vast Bike Sales and Rental', N'adventure-works\pamela0', N'twanna0@adventure-works.com', N'554-555-0124')
,(29743, N'Ms.', N'Ann', N'R.', N'Evans', NULL, N'Summer Sports Place', N'adventure-works\jillian0', N'ann1@adventure-works.com', N'252-555-0127')
,(29744, N'Mr.', N'John', NULL, N'Evans', NULL, N'Real Sporting Goods', N'adventure-works\shu0', N'john17@adventure-works.com', N'581-555-0172')
,(29747, N'Ms.', N'Carolyn', NULL, N'Farino', NULL, N'The Bike Shop', N'adventure-works\david8', N'carolyn0@adventure-works.com', N'957-555-0125')
,(29748, N'Ms.', N'Geri', N'P.', N'Farrell', NULL, N'Safe Toys', N'adventure-works\shu0', N'geri0@adventure-works.com', N'329-555-0183')
,(29750, N'Ms.', N'Rhoda', N'J.', N'Finley', NULL, N'Our Sporting Goods Store', N'adventure-works\jos�1', N'rhoda0@adventure-works.com', N'920-555-0191')
,(29753, N'Ms.', N'Kathie', NULL, N'Flood', NULL, N'Coho Sports', N'adventure-works\david8', N'kathie1@adventure-works.com', N'627-555-0192')
,(29755, N'Ms.', N'Kelly', NULL, N'Focht', NULL, N'Quick Delivery Service', N'adventure-works\garrett1', N'kelly0@adventure-works.com', N'272-555-0123')
,(29757, N'Mr.', N'Garth', NULL, N'Fort', NULL, N'Basic Sports Equipment', N'adventure-works\linda3', N'garth0@adventure-works.com', N'768-555-0125')
,(29758, N'Ms.', N'Dorothy', N'J.', N'Fox', NULL, N'Cash & Carry Bikes', N'adventure-works\jillian0', N'dorothy1@adventure-works.com', N'191-555-0198')
GO
print 'Processed 600 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(29761, N'Ms.', N'Susan', N'E.', N'French', NULL, N'General Bike Corporation', N'adventure-works\garrett1', N'susan3@adventure-works.com', N'994-555-0194')
,(29763, N'Mr.', N'Mihail', NULL, N'Frintu', NULL, N'Retail Cycle Shop', N'adventure-works\linda3', N'mihail1@adventure-works.com', N'777-555-0163')
,(29764, N'Mr.', N'John', NULL, N'Ford', NULL, N'Social Activities Club', N'adventure-works\jillian0', N'john19@adventure-works.com', N'596-555-0153')
,(29765, N'Mr.', N'Paul', N'J.', N'Fulton', NULL, N'Blue Bicycle Company', N'adventure-works\michael9', N'paul3@adventure-works.com', N'492-555-0146')
,(29766, N'Mr.', N'Bob', NULL, N'Gage', NULL, N'General Riding Supplies', N'adventure-works\garrett1', N'bob1@adventure-works.com', N'962-555-0175')
,(29768, N'Mr.', N'Michael', NULL, N'Galos', NULL, N'Riding Excursions', N'adventure-works\linda3', N'michael15@adventure-works.com', N'912-555-0149')
,(29769, N'Mr.', N'Jon', NULL, N'Ganio', NULL, N'Unique Bikes', N'adventure-works\jillian0', N'jon0@adventure-works.com', N'672-555-0112')
,(29770, N'Ms.', N'Kathleen', N'M.', N'Garza', NULL, N'Rural Cycle Emporium', N'adventure-works\jos�1', N'kathleen0@adventure-works.com', N'150-555-0127')
,(29771, N'Mr.', N'Dominic', N'P.', N'Gash', NULL, N'Associated Bikes', N'adventure-works\shu0', N'dominic0@adventure-works.com', N'192-555-0173')
,(29772, N'Ms.', N'Janet', N'M.', N'Gates', NULL, N'Modular Cycle Systems', N'adventure-works\jillian0', N'janet1@adventure-works.com', N'710-555-0173')
,(29773, N'Mr.', N'Orlando', N'N.', N'Gee', NULL, N'A Bike Store', N'adventure-works\pamela0', N'orlando0@adventure-works.com', N'245-555-0173')
,(29774, N'Mr.', N'Darren', NULL, N'Gehring', NULL, N'Journey Sporting Goods', N'adventure-works\jillian0', N'darren0@adventure-works.com', N'417-555-0182')
,(29775, N'Mr.', N'Jim', NULL, N'Geist', NULL, N'Two Bike Shops', N'adventure-works\pamela0', N'jim1@adventure-works.com', N'724-555-0161')
,(29776, N'Ms.', N'Barbara', N'J.', N'German', NULL, N'Cycles Wholesaler & Mfg.', N'adventure-works\jae0', N'barbara4@adventure-works.com', N'1 (11) 500 555-0181')
,(29778, N'Mr.', N'Leo', NULL, N'Giakoumakis', NULL, N'Number One Bike Co.', N'adventure-works\jae0', N'leo0@adventure-works.com', N'1 (11) 500 555-0169')
,(29780, N'Mr.', N'Frances', N'J.', N'Giglio', NULL, N'Standard Bikes', N'adventure-works\jos�1', N'frances1@adventure-works.com', N'692-555-0136')
,(29781, N'Mr.', N'Guy', NULL, N'Gilbert', NULL, N'The Bicycle Accessories Company', N'adventure-works\shu0', N'guy0@adventure-works.com', N'583-555-0198')
,(29782, N'Ms.', N'Janet', N'J.', N'Gilliat', NULL, N'Active Systems', N'adventure-works\jillian0', N'janet2@adventure-works.com', N'521-555-0183')
,(29783, N'Ms.', N'Mary', N'M.', N'Gimmi', NULL, N'Futuristic Sport Distributors', N'adventure-works\shu0', N'mary6@adventure-works.com', N'149-555-0196')
,(29784, N'Ms.', N'Jeanie', N'R.', N'Glenn', N'PhD', N'Big-Time Bike Store', N'adventure-works\shu0', N'jeanie0@adventure-works.com', N'669-555-0149')
,(29785, N'Ms.', N'Diane', N'R.', N'Glimp', NULL, N'The Showroom', N'adventure-works\jos�1', N'diane3@adventure-works.com', N'898-555-0137')
,(29787, N'Mr.', N'Scott', NULL, N'Gode', NULL, N'Year-Round Sports', N'adventure-works\david8', N'scott4@adventure-works.com', N'164-555-0145')
,(29788, N'Mr.', N'Mete', NULL, N'Goktepe', NULL, N'The New Bike Store', N'adventure-works\linda3', N'mete0@adventure-works.com', N'637-555-0120')
,(29789, N'Mr.', N'Brian', N'R', N'Goldstein', NULL, N'Primary Bike Distributors', N'adventure-works\garrett1', N'brian4@adventure-works.com', N'495-555-0161')
,(29792, N'Ms.', N'Abigail', N'J.', N'Gonzalez', NULL, N'Genial Bike Associates', N'adventure-works\jillian0', N'abigail0@adventure-works.com', N'121-555-0139')
,(29793, N'Mr.', N'Michael', NULL, N'Graff', NULL, N'Commercial Sporting Goods', N'adventure-works\shu0', N'michael16@adventure-works.com', N'132-555-0150')
,(29794, N'Mr.', N'Derek', NULL, N'Graham', NULL, N'Wholesale Parts', N'adventure-works\jos�1', N'derek0@adventure-works.com', N'674-555-0187')
,(29796, N'Mr.', N'Jon', NULL, N'Grande', NULL, N'Riding Cycles', N'adventure-works\jae0', N'jon1@adventure-works.com', N'1 (11) 500 555-0114')
,(29797, N'Ms.', N'Jane', N'P.', N'Greer', NULL, N'Metro Manufacturing', N'adventure-works\jos�1', N'jane2@adventure-works.com', N'737-555-0163')
,(29799, N'Mr.', N'Douglas', NULL, N'Groncki', NULL, N'Locks Company', N'adventure-works\shu0', N'douglas2@adventure-works.com', N'385-555-0140')
,(29800, N'Mr.', N'Brian', NULL, N'Groth', NULL, N'Latest Accessories Sales', N'adventure-works\david8', N'brian5@adventure-works.com', N'461-555-0118')
,(29803, N'Ms.', N'Hattie', N'J.', N'Haemon', NULL, N'Greater Bike Store', N'adventure-works\jos�1', N'hattie0@adventure-works.com', N'141-555-0172')
,(29805, N'Ms.', N'Erin', N'M.', N'Hagens', NULL, N'Distant Inn', N'adventure-works\shu0', N'erin1@adventure-works.com', N'244-555-0127')
,(29806, N'Ms.', N'Betty', N'M.', N'Haines', NULL, N'Finer Mart', N'adventure-works\david8', N'betty0@adventure-works.com', N'867-555-0114')
,(29807, N'Mr.', N'Bryan', NULL, N'Hamilton', NULL, N'Cross-Country Riding Supplies', N'adventure-works\jos�1', N'bryan2@adventure-works.com', N'344-555-0144')
,(29809, N'Mr.', N'Kerim', NULL, N'Hanif', NULL, N'Bike World', N'adventure-works\shu0', N'kerim0@adventure-works.com', N'216-555-0122')
,(29810, N'Ms.', N'Jean', N'P.', N'Handley', NULL, N'Central Discount Store', N'adventure-works\david8', N'jean1@adventure-works.com', N'582-555-0113')
,(29813, N'Ms.', N'Katherine', NULL, N'Harding', NULL, N'Sharp Bikes', N'adventure-works\jos�1', N'katherine0@adventure-works.com', N'926-555-0159')
,(29815, N'Mr.', N'Lucy', NULL, N'Harrington', NULL, N'Metropolitan Sports Supply', N'adventure-works\shu0', N'lucy0@adventure-works.com', N'828-555-0186')
,(29816, N'Mr.', N'Keith', NULL, N'Harris', NULL, N'Progressive Sports', N'adventure-works\david8', N'keith0@adventure-works.com', N'170-555-0127')
,(29818, N'Mr.', N'Roger', NULL, N'Harui', NULL, N'Brakes and Gears', N'adventure-works\linda3', N'roger0@adventure-works.com', N'774-555-0133')
,(29819, N'Ms.', N'Ann', N'T.', N'Hass', NULL, N'The Accessories Store', N'adventure-works\jillian0', N'ann2@adventure-works.com', N'713-555-0168')
,(29822, N'Mr.', N'James', N'B.', N'Haugh', N'Jr.', N'Family Cycle Store', N'adventure-works\garrett1', N'james8@adventure-works.com', N'763-555-0120')
,(29824, N'Ms.', N'Brenda', N'F.', N'Heaney', NULL, N'Superb Sales and Repair', N'adventure-works\garrett1', N'brenda3@adventure-works.com', N'393-555-0167')
,(29826, N'Mr.', N'John', NULL, N'Hanson', NULL, N'Countryside Company', N'adventure-works\linda3', N'john20@adventure-works.com', N'107-555-0117')
,(29827, N'Ms.', N'Valerie', N'M.', N'Hendricks', NULL, N'First Bike Store', N'adventure-works\jillian0', N'valerie0@adventure-works.com', N'859-555-0140')
,(29830, N'Mr.', N'Kari', NULL, N'Hensien', NULL, N'General Department Stores', N'adventure-works\garrett1', N'kari0@adventure-works.com', N'143-555-0129')
,(29831, N'Ms.', N'Irene', N'J.', N'Hernandez', NULL, N'Operational Manufacturing', N'adventure-works\garrett1', N'irene0@adventure-works.com', N'790-555-0197')
,(29832, N'Mr.', N'J�sus', NULL, N'Hernandez', NULL, N'Online Bike Warehouse', N'adventure-works\jos�1', N'j�sus0@adventure-works.com', N'214-555-0145')
,(29834, N'Ms.', N'Cheryl', N'M.', N'Herring', NULL, N'Small Bike Shop', N'adventure-works\shu0', N'cheryl0@adventure-works.com', N'158-555-0154')
,(29835, N'Mr.', N'Ronald', N'K.', N'Heymsfield', NULL, N'Superior Hardware Distributors', N'adventure-works\david8', N'ronald1@adventure-works.com', N'784-555-0120')
,(29840, N'Mr.', N'Andrew', N'R.', N'Hill', NULL, N'Eastside Parts Shop', N'adventure-works\jos�1', N'andrew4@adventure-works.com', N'194-555-0149')
,(29842, N'Mr.', N'Mike', NULL, N'Hines', NULL, N'First Cycle Store', N'adventure-works\shu0', N'mike3@adventure-works.com', N'454-555-0160')
,(29843, N'Mr.', N'Matthew', NULL, N'Hink', NULL, N'Running and Cycling Gear', N'adventure-works\david8', N'matthew3@adventure-works.com', N'146-555-0176')
,(29847, N'Mr.', N'David', NULL, N'Hodgson', NULL, N'Good Toys', N'adventure-works\linda3', N'david16@adventure-works.com', N'969-555-0117')
,(29848, N'Ms.', N'Helge', NULL, N'Hoeing', NULL, N'Little Bicycle Supply Shop', N'adventure-works\jillian0', N'helge0@adventure-works.com', N'850-555-0198')
,(29850, N'Mr.', N'Bob', NULL, N'Hodges', NULL, N'All Seasons Sports Supply', N'adventure-works\jillian0', N'bob2@adventure-works.com', N'129-555-0120')
,(29851, N'Ms.', N'Jean', N'J.', N'Holloway', NULL, N'Leisure Clearing House', N'adventure-works\jae0', N'jean2@adventure-works.com', N'1 (11) 500 555-0181')
,(29852, N'Mr.', N'Eddie', N'M.', N'Holmes', NULL, N'The Commissary', N'adventure-works\jos�1', N'eddie0@adventure-works.com', N'570-555-0199')
,(29853, N'Ms.', N'Juanita', N'J.', N'Holman', NULL, N'Affordable Sports Equipment', N'adventure-works\shu0', N'juanita0@adventure-works.com', N'996-555-0196')
,(29854, N'Mr.', N'Peter', NULL, N'Houston', NULL, N'Local Sales and Rental', N'adventure-works\jillian0', N'peter3@adventure-works.com', N'632-555-0171')
,(29855, N'Mr.', N'Curtis', N'P.', N'Howard', NULL, N'Economy Center', N'adventure-works\jos�1', N'curtis0@adventure-works.com', N'555-555-0162')
,(29857, N'Ms.', N'Janice', N'K.', N'Hows', NULL, N'Area Sheet Metal Supply', N'adventure-works\jae0', N'janice1@adventure-works.com', N'1 (11) 500 555-0119')
,(29858, N'Mr.', N'George', N'M.', N'Huckaby', NULL, N'Synthetic Materials Manufacturing', N'adventure-works\pamela0', N'george1@adventure-works.com', N'851-555-0127')
,(29859, N'Mr.', N'Joshua', N'J.', N'Huff', NULL, N'Rural Sales and Service', N'adventure-works\jillian0', N'joshua0@adventure-works.com', N'190-555-0186')
,(29860, N'Ms.', N'Arlene', NULL, N'Huff', NULL, N'Tubeless Tire Company', N'adventure-works\jae0', N'arlene0@adventure-works.com', N'1 (11) 500 555-0146')
,(29861, N'Ms.', N'Phyllis', N'R.', N'Huntsman', NULL, N'Hardware Components', N'adventure-works\jillian0', N'phyllis1@adventure-works.com', N'153-555-0195')
,(29862, N'Mr.', N'Lawrence', N'E.', N'Hurkett', NULL, N'Retail Sporting Goods', N'adventure-works\shu0', N'lawrence0@adventure-works.com', N'129-555-0185')
,(29863, N'Mr.', N'Ryan', NULL, N'Ihrig', NULL, N'Efficient Cycling', N'adventure-works\jos�1', N'ryan4@adventure-works.com', N'809-555-0152')
,(29864, N'Ms.', N'Beth', NULL, N'Inghram', NULL, N'General Industries', N'adventure-works\jos�1', N'beth0@adventure-works.com', N'718-555-0152')
,(29865, N'Mr.', N'Lucio', NULL, N'Iallo', NULL, N'Highway Bike Shop', N'adventure-works\shu0', N'lucio0@adventure-works.com', N'199-555-0135')
,(29866, N'Mr.', N'Richard', N'L.', N'Irwin', NULL, N'Rental Bikes', N'adventure-works\jillian0', N'richard4@adventure-works.com', N'367-555-0124')
,(29867, N'Mr.', N'Erik', NULL, N'Ismert', NULL, N'Roving Sports', N'adventure-works\pamela0', N'erik0@adventure-works.com', N'116-555-0163')
,(29868, N'Ms.', N'Denean', N'J.', N'Ison', NULL, N'Express Bike Services', N'adventure-works\jae0', N'denean0@adventure-works.com', N'1 (11) 500 555-0127')
,(29870, N'Mr.', N'Bronson', N'R.', N'Jacobs', NULL, N'Retail Discount Store', N'adventure-works\jos�1', N'bronson0@adventure-works.com', N'697-555-0131')
,(29871, N'Mr.', N'Eric', N'A.', N'Jacobsen', NULL, N'Vale Riding Supplies', N'adventure-works\shu0', N'eric5@adventure-works.com', N'703-555-0120')
,(29872, N'Ms.', N'Jodan', N'M.', N'Jacobson', NULL, N'A Great Bicycle Company', N'adventure-works\jillian0', N'jodan0@adventure-works.com', N'652-555-0189')
,(29873, N'Ms.', N'Mary', NULL, N'Alexander', NULL, N'Certified Bicycle Supply', N'adventure-works\pamela0', N'mary7@adventure-works.com', N'344-555-0133')
,(29874, N'Mr.', N'David', NULL, N'Jaffe', NULL, N'Exceptional Cycle Services', N'adventure-works\jae0', N'david17@adventure-works.com', N'1 (11) 500 555-0140')
,(29876, N'Ms.', N'Vance', N'P.', N'Johns', NULL, N'Leisure Activities', N'adventure-works\jos�1', N'vance0@adventure-works.com', N'103-555-0151')
,(29877, N'Ms.', N'Joyce', NULL, N'Jarvis', NULL, N'Paints and Solvents Company', N'adventure-works\shu0', N'joyce0@adventure-works.com', N'458-555-0179')
,(29879, N'Mr.', N'Stephen', N'Yuan', N'Jiang', NULL, N'Bikes for Kids and Adults', N'adventure-works\jos�1', N'stephen3@adventure-works.com', N'910-555-0116')
,(29881, N'Ms.', N'Danielle', N'B.', N'Johnson', NULL, N'Home Town Bike Store', N'adventure-works\garrett1', N'danielle1@adventure-works.com', N'356-555-0190')
,(29883, N'Mr.', N'Barry', NULL, N'Johnson', NULL, N'Sample Bike Store', N'adventure-works\linda3', N'barry1@adventure-works.com', N'858-555-0140')
,(29884, N'Mr.', N'Brian', NULL, N'Johnson', NULL, N'Extras Sporting Goods', N'adventure-works\jillian0', N'brian6@adventure-works.com', N'320-555-0134')
,(29885, N'Mr.', N'David', NULL, N'Johnson', NULL, N'Sure & Reliable Sporting Goods', N'adventure-works\david8', N'david18@adventure-works.com', N'476-555-0139')
,(29889, N'Ms.', N'Jean', NULL, N'Jordan', NULL, N'Separate Parts Corporation', N'adventure-works\shu0', N'jean3@adventure-works.com', N'207-555-0129')
,(29890, N'Ms.', N'Peggy', N'J.', N'Justice', NULL, N'Basic Bike Company', N'adventure-works\david8', N'peggy0@adventure-works.com', N'170-555-0189')
,(29891, N'Ms.', N'Diane', N'F.', N'Krane', NULL, N'Fabrikam Inc., West', N'adventure-works\michael9', N'diane4@adventure-works.com', N'224-555-0126')
,(29892, N'Ms.', N'Sandra', N'T.', N'Kitt', NULL, N'Non-Slip Pedal Company', N'adventure-works\jos�1', N'sandra2@adventure-works.com', N'303-555-0117')
,(29893, N'Mr.', N'Sandeep', NULL, N'Kaliyath', NULL, N'Weekend Bike Tours', N'adventure-works\shu0', N'sandeep1@adventure-works.com', N'495-555-0113')
,(29895, N'Ms.', N'Lori', NULL, N'Kane', NULL, N'General Supplies', N'adventure-works\jos�1', N'lori2@adventure-works.com', N'765-555-0141')
,(29897, N'Ms.', N'Kay', N'E.', N'Krane', NULL, N'Racing Toys', N'adventure-works\shu0', N'kay0@adventure-works.com', N'731-555-0187')
,(29898, N'Mr.', N'Sandeep', NULL, N'Katyal', NULL, N'Capable Sales and Service', N'adventure-works\pamela0', N'sandeep2@adventure-works.com', N'928-555-0117')
,(29900, N'Mr.', N'Victor', N'A.', N'Kelley', NULL, N'Road Way Sales and Rental', N'adventure-works\jos�1', N'victor0@adventure-works.com', N'112-555-0195')
,(29901, N'Mr.', N'John', NULL, N'Kelly', NULL, N'Sturdy Toys', N'adventure-works\shu0', N'john22@adventure-works.com', N'330-555-0116')
,(29902, N'Mr.', N'Robert', NULL, N'Kelly', NULL, N'Beneficial Exercises and Activities', N'adventure-works\jillian0', N'robert7@adventure-works.com', N'510-555-0123')
,(29903, N'Mr.', N'Kevin', NULL, N'Kennedy', NULL, N'Fad Outlet', N'adventure-works\pamela0', N'kevin4@adventure-works.com', N'275-555-0179')
,(29904, N'Ms.', N'Mary', N'R.', N'Kesslep', NULL, N'Commerce Bicycle Specialists', N'adventure-works\jae0', N'mary8@adventure-works.com', N'1 (11) 500 555-0146')
,(29905, N'Ms.', N'Elizabeth', NULL, N'Keyser', NULL, N'Acceptable Sales & Service', N'adventure-works\jos�1', N'elizabeth2@adventure-works.com', N'656-555-0173')
,(29906, N'Mr.', N'Imtiaz', NULL, N'Khan', NULL, N'District Mall', N'adventure-works\jillian0', N'imtiaz0@adventure-works.com', N'249-555-0179')
GO
print 'Processed 700 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(29907, N'Ms.', N'Karan', NULL, N'Khanna', NULL, N'Fitness Supplies', N'adventure-works\pamela0', N'karan1@adventure-works.com', N'390-555-0150')
,(29908, N'Mr.', N'Joe', NULL, N'Kim', NULL, N'Mail Market', N'adventure-works\jae0', N'joe1@adventure-works.com', N'1 (11) 500 555-0144')
,(29910, N'Mr.', N'Shane', N'S.', N'Kim', NULL, N'Twelfth Bike Store', N'adventure-works\jos�1', N'shane2@adventure-works.com', N'155-555-0149')
,(29911, N'Mr.', N'Tim', NULL, N'Kim', NULL, N'Consolidated Messenger', N'adventure-works\garrett1', N'tim0@adventure-works.com', N'244-555-0115')
,(29913, N'Mr.', N'Anton', NULL, N'Kirilov', NULL, N'Field Trip Store', N'adventure-works\linda3', N'anton0@adventure-works.com', N'608-555-0162')
,(29914, N'Mr.', N'Christian', NULL, N'Kleinerman', NULL, N'Finish and Sealant Products', N'adventure-works\shu0', N'christian1@adventure-works.com', N'362-555-0177')
,(29915, N'Mr.', N'Andrew', N'P.', N'Kobylinski', NULL, N'Finer Parts Shop', N'adventure-works\david8', N'andrew5@adventure-works.com', N'129-555-0185')
,(29918, N'Mr.', N'Kirk', N'T', N'King', NULL, N'Up-To-Date Sports', N'adventure-works\jos�1', N'kirk2@adventure-works.com', N'979-555-0163')
,(29919, N'Mr.', N'Eugene', NULL, N'Kogan', NULL, N'Mountain Bike Center', N'adventure-works\shu0', N'eugene2@adventure-works.com', N'136-555-0134')
,(29920, N'Mr.', N'Scott', NULL, N'Konersmann', NULL, N'Specialty Sports Store', N'adventure-works\jillian0', N'scott6@adventure-works.com', N'556-555-0192')
,(29921, N'Ms.', N'Joy', N'R.', N'Koski', NULL, N'Scooters and Bikes Store', N'adventure-works\pamela0', N'joy0@adventure-works.com', N'810-555-0198')
,(29922, N'Ms.', N'Pamala', N'M.', N'Kotc', NULL, N'Closest Bicycle Store', N'adventure-works\jae0', N'pamala0@adventure-works.com', N'1 (11) 500 555-0173')
,(29924, N'Mr.', N'Mitch', NULL, N'Kennedy', NULL, N'Reasonable Bicycle Sales', N'adventure-works\shu0', N'mitch0@adventure-works.com', N'996-555-0192')
,(29925, N'Ms.', N'Margaret', N'T.', N'Krupka', NULL, N'Outdoor Sports Supply', N'adventure-works\pamela0', N'margaret1@adventure-works.com', N'107-555-0132')
,(29926, N'Mr.', N'Deepak', NULL, N'Kumar', NULL, N'Outdoor Aerobic Systems Company', N'adventure-works\jae0', N'deepak0@adventure-works.com', N'1 (11) 500 555-0122')
,(29928, N'Mr.', N'Vamsi', NULL, N'Kuppa', NULL, N'Metal Clearing House', N'adventure-works\jos�1', N'vamsi1@adventure-works.com', N'290-555-0196')
,(29929, N'Mr.', N'Jeffrey', NULL, N'Kurtz', NULL, N'Many Bikes Store', N'adventure-works\shu0', N'jeffrey3@adventure-works.com', N'452-555-0179')
,(29930, N'Mr.', N'Peter', NULL, N'Kurniawan', NULL, N'Largest Bike Store', N'adventure-works\jillian0', N'peter4@adventure-works.com', N'436-555-0160')
,(29931, N'Mr.', N'Eric', NULL, N'Lang', NULL, N'Kickstands and Accessories Company', N'adventure-works\pamela0', N'eric6@adventure-works.com', N'932-555-0163')
,(29932, N'Ms.', N'Rebecca', NULL, N'Laszlo', NULL, N'Instruments and Parts Company', N'adventure-works\jae0', N'rebecca2@adventure-works.com', N'1 (11) 500 555-0155')
,(29934, N'Mr.', N'David', N'O', N'Lawrence', NULL, N'Gear-Shift Bikes Limited', N'adventure-works\jos�1', N'david19@adventure-works.com', N'653-555-0159')
,(29935, N'Ms.', N'Elsa', NULL, N'Leavitt', NULL, N'Frugal Bike Shop', N'adventure-works\shu0', N'elsa0@adventure-works.com', N'482-555-0174')
,(29936, N'Mr.', N'Michael', N'J.', N'Lee', NULL, N'Family Entertainment Center', N'adventure-works\pamela0', N'michael18@adventure-works.com', N'396-555-0139')
,(29937, N'Ms.', N'Marjorie', N'M.', N'Lee', NULL, N'Go-cart and Bike Specialists', N'adventure-works\jillian0', N'marjorie0@adventure-works.com', N'306-555-0166')
,(29938, N'Mr.', N'Frank', NULL, N'Campbell', NULL, N'Trailblazing Sports', N'adventure-works\shu0', N'frank4@adventure-works.com', N'491-555-0132')
,(29939, N'Mr.', N'Mark', NULL, N'Lee', NULL, N'Racing Partners', N'adventure-works\jos�1', N'mark5@adventure-works.com', N'371-555-0112')
,(29941, N'Ms.', N'Jolie', NULL, N'Lenehan', NULL, N'Exhibition Showroom', N'adventure-works\jae0', N'jolie0@adventure-works.com', N'1 (11) 500 555-0126')
,(29942, N'Mr.', N'Roger', NULL, N'Lengel', NULL, N'Authorized Bike Sales and Rental', N'adventure-works\pamela0', N'roger1@adventure-works.com', N'947-555-0143')
,(29943, NULL, N'A.', N'Francesca', N'Leonetti', NULL, N'Two-Seater Bikes', N'adventure-works\jillian0', N'a0@adventure-works.com', N'645-555-0193')
,(29944, N'Ms.', N'Bonnie', N'B.', N'Lepro', NULL, N'More Bikes!', N'adventure-works\linda3', N'bonnie2@adventure-works.com', N'354-555-0130')
,(29946, N'Ms.', N'Linda', NULL, N'Leste', NULL, N'National Manufacturing', N'adventure-works\garrett1', N'linda7@adventure-works.com', N'493-555-0134')
,(29948, N'Ms.', N'Elsie', N'L.', N'Lewin', NULL, N'Town Industries', N'adventure-works\jillian0', N'elsie0@adventure-works.com', N'803-555-0116')
,(29949, N'Mr.', N'George', N'Z.', N'Li', NULL, N'Security Racks and Locks Wholesalers', N'adventure-works\shu0', N'george3@adventure-works.com', N'699-555-0183')
,(29950, N'Mr.', N'Yale', NULL, N'Li', NULL, N'Rapid Bikes', N'adventure-works\jos�1', N'yale0@adventure-works.com', N'316-555-0138')
,(29952, N'Ms.', N'Yuhong', NULL, N'Li', NULL, N'Nearby Sporting Goods', N'adventure-works\jae0', N'yuhong1@adventure-works.com', N'1 (11) 500 555-0176')
,(29953, N'Mr.', N'Joseph', N'M.', N'Lique', NULL, N'Front Sporting Goods', N'adventure-works\pamela0', N'joseph2@adventure-works.com', N'119-555-0195')
,(29954, N'Mr.', N'Paulo', N'H.', N'Lisboa', NULL, N'Elite Bikes', N'adventure-works\jillian0', N'paulo0@adventure-works.com', N'380-555-0116')
,(29955, N'Mr.', N'David', N'J.', N'Liu', NULL, N'Catalog Store', N'adventure-works\michael9', N'david20@adventure-works.com', N'440-555-0132')
,(29956, NULL, N'Jinghao', NULL, N'Liu', NULL, N'Chic Department Stores', N'adventure-works\jillian0', N'jinghao1@adventure-works.com', N'928-555-0116')
,(29957, N'Mr.', N'Kevin', NULL, N'Liu', NULL, N'Eastside Department Store', N'adventure-works\linda3', N'kevin5@adventure-works.com', N'926-555-0164')
,(29959, N'Mr.', N'Todd', N'R.', N'Logan', NULL, N'Cycle Merchants', N'adventure-works\garrett1', N'todd0@adventure-works.com', N'783-555-0110')
,(29962, N'Ms.', N'Sharon', N'J.', N'Looney', NULL, N'Fitness Hotel', N'adventure-works\jillian0', N'sharon2@adventure-works.com', N'377-555-0132')
,(29964, N'Ms.', N'Anita', N'R.', N'Lucerne', NULL, N'Grand Industries', N'adventure-works\garrett1', N'anita0@adventure-works.com', N'164-555-0118')
,(29967, N'Ms.', N'Judy', N'R.', N'Lundahl', NULL, N'Leading Sales & Repair', N'adventure-works\jillian0', N'judy1@adventure-works.com', N'260-555-0130')
,(29969, N'Mr.', N'Robert', N'P.', N'Lyeba', NULL, N'Tandem Sales and Service', N'adventure-works\garrett1', N'robert8@adventure-works.com', N'631-555-0155')
,(29971, N'Mr.', N'Robert', NULL, N'Lyon', NULL, N'Reliable Retail Center', N'adventure-works\garrett1', N'robert9@adventure-works.com', N'666-555-0143')
,(29973, N'Ms.', N'Denise', N'R.', N'Maccietto', NULL, N'Friendly Bike Shop', N'adventure-works\michael9', N'denise1@adventure-works.com', N'537-555-0190')
,(29974, N'Mr.', N'Scott', NULL, N'MacDonald', NULL, N'Yellow Bicycle Company', N'adventure-works\jillian0', N'scott7@adventure-works.com', N'470-555-0171')
,(29975, N'Mr.', N'Walter', N'J.', N'Mays', N'Sr.', N'Sports Products Store', N'adventure-works\linda3', N'walter1@adventure-works.com', N'245-555-0191')
,(29978, N'Mr.', N'Ajay', NULL, N'Manchepalli', NULL, N'Shipping Specialists', N'adventure-works\jae0', N'ajay0@adventure-works.com', N'1 (11) 500 555-0174')
,(29980, N'Mr.', N'Tomas', N'M.', N'Manzanares', N'II', N'Authentic Sales and Service', N'adventure-works\jae0', N'tomas0@adventure-works.com', N'1 (11) 500 555-0178')
,(29981, N'Ms.', N'Kathy', N'R.', N'Marcovecchio', NULL, N'Official Parts Shop', N'adventure-works\pamela0', N'kathy0@adventure-works.com', N'942-555-0141')
,(29982, N'Ms.', N'Melissa', N'R.', N'Marple', NULL, N'Discount Tours', N'adventure-works\shu0', N'melissa0@adventure-works.com', N'685-555-0117')
,(29983, N'Ms.', N'Cecelia', N'L.', N'Marshall', NULL, N'Tire Exchange', N'adventure-works\jos�1', N'cecelia0@adventure-works.com', N'394-555-0168')
,(29985, N'Ms.', N'Linda', NULL, N'Martin', NULL, N'Oils and Fluids Warehouse', N'adventure-works\jae0', N'linda8@adventure-works.com', N'1 (11) 500 555-0137')
,(29987, N'Mr.', N'Frank', NULL, N'Mart�nez', NULL, N'Rally Master Company Inc', N'adventure-works\shu0', N'frank5@adventure-works.com', N'171-555-0147')
,(29988, N'Mr.', N'Steve', NULL, N'Masters', NULL, N'Professional Cyclists', N'adventure-works\jos�1', N'steve2@adventure-works.com', N'154-555-0115')
,(29990, N'Ms.', N'Jennifer', N'J.', N'Maxham', NULL, N'Exclusive Bicycle Mart', N'adventure-works\jae0', N'jennifer1@adventure-works.com', N'1 (11) 500 555-0175')
,(29991, N'Mr.', N'Chris', NULL, N'Maxwell', NULL, N'City Manufacturing', N'adventure-works\pamela0', N'chris6@adventure-works.com', N'642-555-0187')
,(29992, N'Ms.', N'Sandra', N'B.', N'Maynard', NULL, N'Bike Dealers Association', N'adventure-works\shu0', N'sandra4@adventure-works.com', N'993-555-0179')
,(29994, N'Ms.', N'Robin', N'M.', N'McGuigan', NULL, N'Health Spa, Limited', N'adventure-works\jos�1', N'robin0@adventure-works.com', N'431-555-0153')
,(29997, N'Ms.', N'Lola', N'M.', N'McCarthy', NULL, N'Closeout Boutique', N'adventure-works\david8', N'lola0@adventure-works.com', N'173-555-0151')
,(29998, N'Ms.', N'Jane', N'A.', N'McCarty', NULL, N'Bicycle Merchandise Warehouse', N'adventure-works\shu0', N'jane3@adventure-works.com', N'529-555-0195')
,(30000, N'Mr.', N'James', N'L.', N'McCoy', N'II', N'Leather Seat Factory', N'adventure-works\jos�1', N'james12@adventure-works.com', N'191-555-0151')
,(30003, N'Ms.', N'Yvonne', NULL, N'McKay', NULL, N'Practical Bike Supply Company', N'adventure-works\jillian0', N'yvonne1@adventure-works.com', N'623-555-0144')
,(30004, N'Ms.', N'Nkenge', NULL, N'McLin', NULL, N'Some Discount Store', N'adventure-works\pamela0', N'nkenge0@adventure-works.com', N'158-555-0123')
,(30005, N'Ms.', N'Nancy', N'A.', N'McPhearson', NULL, N'Variety Cycling', N'adventure-works\jae0', N'nancy3@adventure-works.com', N'1 (11) 500 555-0195')
,(30007, N'Ms.', N'Raquel', NULL, N'Mello', NULL, N'Remote Bicycle Specialists', N'adventure-works\jos�1', N'raquel0@adventure-works.com', N'723-555-0124')
,(30008, N'Mr.', N'R. Morgan', N'L.', N'Mendoza', NULL, N'Friendly Neighborhood Bikes', N'adventure-works\jillian0', N'rmorgan0@adventure-works.com', N'963-555-0146')
,(30010, N'Mr.', N'Stephen', N'A.', N'Mew', NULL, N'Recommended Bicycles', N'adventure-works\garrett1', N'stephen4@adventure-works.com', N'399-555-0114')
,(30012, N'Ms.', N'Helen', N'M.', N'Meyer', NULL, N'Alpine Ski House', N'adventure-works\linda3', N'helen2@adventure-works.com', N'519-555-0112')
,(30016, N'Mr.', N'Thomas', N'R.', N'Michaels', NULL, N'Seats and Saddles Company', N'adventure-works\garrett1', N'thomas2@adventure-works.com', N'162-555-0174')
,(30018, N'Ms.', N'Virginia', N'L.', N'Miller', NULL, N'All Cycle Shop', N'adventure-works\pamela0', N'virginia0@adventure-works.com', N'918-555-0127')
,(30019, N'Mr.', N'Matthew', N'J.', N'Miller', NULL, N'Tachometers and Accessories', N'adventure-works\jae0', N'matthew5@adventure-works.com', N'1 (11) 500 555-0176')
,(30021, N'Mr.', N'Ben', NULL, N'Miller', NULL, N'Low Price Cycles', N'adventure-works\jos�1', N'ben1@adventure-works.com', N'207-555-0167')
,(30022, N'Mr.', N'Dylan', NULL, N'Miller', NULL, N'Metropolitan Manufacturing', N'adventure-works\shu0', N'dylan1@adventure-works.com', N'140-555-0192')
,(30023, N'Mr.', N'Frank', NULL, N'Miller', NULL, N'Orange Bicycle Company', N'adventure-works\jillian0', N'frank6@adventure-works.com', N'118-555-0184')
,(30024, N'Ms.', N'Neva', N'M.', N'Mitchell', NULL, N'Riding Associates', N'adventure-works\pamela0', N'neva0@adventure-works.com', N'992-555-0134')
,(30025, N'Ms.', N'Linda', NULL, N'Mitchell', NULL, N'Essential Bike Works', N'adventure-works\jae0', N'linda9@adventure-works.com', N'1 (11) 500 555-0182')
,(30027, N'Mr.', N'Joseph', N'P.', N'Mitzner', N'Jr.', N'Engineered Bike Systems', N'adventure-works\shu0', N'joseph4@adventure-works.com', N'129-555-0164')
,(30028, N'Ms.', N'Laura', N'C.', N'Steele', NULL, N'Professional Containers and Packaging Co.', N'adventure-works\shu0', N'laura3@adventure-works.com', N'741-555-0173')
,(30029, N'Ms.', N'Shanay', N'B.', N'Steelman', NULL, N'One Bike Company', N'adventure-works\jos�1', N'shanay0@adventure-works.com', N'797-555-0118')
,(30030, N'Mr.', N'Stefano', NULL, N'Stefani', NULL, N'Cycling Goods', N'adventure-works\jae0', N'stefano0@adventure-works.com', N'1 (11) 500 555-0115')
,(30031, N'Mr.', N'Alan', NULL, N'Steiner', NULL, N'Cycle Clearance', N'adventure-works\pamela0', N'alan4@adventure-works.com', N'792-555-0194')
,(30032, N'Mr.', N'Derik', NULL, N'Stenerson', NULL, N'Black Bicycle Company', N'adventure-works\jillian0', N'derik0@adventure-works.com', N'441-555-0144')
,(30033, N'Mr.', N'Vassar', N'J.', N'Stern', NULL, N'Transport Bikes', N'adventure-works\shu0', N'vassar0@adventure-works.com', N'328-555-0123')
,(30034, N'Ms.', N'Wathalee', N'R.', N'Steuber', NULL, N'Sellers of Cycles', N'adventure-works\pamela0', N'wathalee0@adventure-works.com', N'517-555-0120')
,(30035, N'Ms.', N'Alice', N'M.', N'Steiner', NULL, N'Maintenance and Repair for Bicycles', N'adventure-works\jillian0', N'alice4@adventure-works.com', N'355-555-0180')
,(30036, N'Ms.', N'Liza Marie', N'N.', N'Stevens', NULL, N'Fitness Department Stores', N'adventure-works\shu0', N'lizamarie0@adventure-works.com', N'366-555-0110')
,(30037, N'Mr.', N'Jim', NULL, N'Stewart', NULL, N'Famous Bike Shop', N'adventure-works\garrett1', N'jim5@adventure-works.com', N'226-555-0110')
,(30039, N'Mr.', N'Robert', N'B.', N'Stotka', NULL, N'Gift and Toy Store', N'adventure-works\jillian0', N'robert12@adventure-works.com', N'493-555-0185')
,(30040, N'Ms.', N'Kayla', N'M.', N'Stotler', NULL, N'Major Sporting Goods', N'adventure-works\linda3', N'kayla0@adventure-works.com', N'315-555-0131')
,(30042, N'Ms.', N'Ruby Sue', N'R.', N'Styles', NULL, N'Major Cycling', N'adventure-works\jos�1', N'rubysue0@adventure-works.com', N'512-555-0122')
,(30044, N'Mr.', N'Gary', N'J.', N'Suess', NULL, N'Downhill Bicycle Specialists', N'adventure-works\jae0', N'gary5@adventure-works.com', N'1 (11) 500 555-0199')
,(30045, N'Ms.', N'Ruth', N'J.', N'Suffin', NULL, N'Bike Experts', N'adventure-works\pamela0', N'ruth2@adventure-works.com', N'924-555-0195')
,(30046, N'Ms.', N'Elizabeth', N'J.', N'Sullivan', NULL, N'Extraordinary Bike Works', N'adventure-works\jillian0', N'elizabeth4@adventure-works.com', N'306-555-0112')
,(30047, N'Mr.', N'Michael', NULL, N'Sullivan', NULL, N'Valley Bicycle Distributors', N'adventure-works\shu0', N'michael24@adventure-works.com', N'323-555-0113')
,(30048, N'Ms.', N'Marcia', N'J.', N'Sultan', NULL, N'Top Sports Supply', N'adventure-works\jos�1', N'marcia0@adventure-works.com', N'613-555-0116')
,(30050, N'Mr.', N'Krishna', NULL, N'Sunkammurali', NULL, N'Metropolitan Bicycle Supply', N'adventure-works\jae0', N'krishna1@adventure-works.com', N'1 (11) 500 555-0177')
,(30051, N'Mr.', N'Brad', NULL, N'Sutton', NULL, N'Honest Repair Service', N'adventure-works\pamela0', N'brad0@adventure-works.com', N'688-555-0115')
,(30052, N'Mr.', N'Abraham', N'L.', N'Swearengin', NULL, N'Wheel Gallery', N'adventure-works\shu0', N'abraham0@adventure-works.com', N'926-555-0136')
GO
print 'Processed 800 total records'
INSERT [dbo].[Customer] ([CustomerID], [Title], [FirstName], [MiddleName], [LastName], [Suffix], [CompanyName], [SalesPerson], [EmailAddress], [Phone]) VALUES 
(30053, N'Ms.', N'Katherine', N'K.', N'Swan', NULL, N'Top Bike Market', N'adventure-works\garrett1', N'katherine1@adventure-works.com', N'421-555-0192')
,(30055, N'Ms.', N'Julie', NULL, N'Taft-Rider', NULL, N'Bicycle Lines Distributors', N'adventure-works\jillian0', N'julie1@adventure-works.com', N'145-555-0194')
,(30056, N'Mr.', N'Clarence', N'R.', N'Tatman', NULL, N'Sparkling Paint and Finishes', N'adventure-works\linda3', N'clarence0@adventure-works.com', N'787-555-0128')
,(30058, N'Mr.', N'Mike', N'M.', N'Taylor', NULL, N'Plastic Parts Company', N'adventure-works\garrett1', N'mike6@adventure-works.com', N'204-555-0189')
,(30061, N'Mr.', N'Chad', N'J.', N'Tedford', NULL, N'Big Cycle Mall', N'adventure-works\jillian0', N'chad1@adventure-works.com', N'588-555-0128')
,(30063, N'Ms.', N'Vanessa', N'J.', N'Tench', NULL, N'Eighth Bike Store', N'adventure-works\shu0', N'vanessa0@adventure-works.com', N'785-555-0163')
,(30064, N'Ms.', N'Judy', N'J.', N'Thames', NULL, N'Demand Distributors', N'adventure-works\david8', N'judy3@adventure-works.com', N'799-555-0118')
,(30067, N'Ms.', N'Phyllis', N'A.', N'Thomas', NULL, N'Red Bicycle Company', N'adventure-works\jos�1', N'phyllis2@adventure-works.com', N'667-555-0112')
,(30069, N'Mr.', N'Donald', N'M.', N'Thompson', NULL, N'Trendy Department Stores', N'adventure-works\shu0', N'donald1@adventure-works.com', N'273-555-0111')
,(30070, N'Ms.', N'Kendra', N'N.', N'Thompson', NULL, N'Vintage Sport Boutique', N'adventure-works\david8', N'kendra0@adventure-works.com', N'464-555-0188')
,(30071, N'Mr.', N'Daniel', N'P.', N'Thompson', NULL, N'Travel Sports', N'adventure-works\pamela0', N'daniel2@adventure-works.com', N'247-555-0197')
,(30072, N'Ms.', N'Andrea', N'A.', N'Thomsen', NULL, N'West Side Mart', N'adventure-works\jae0', N'andrea1@adventure-works.com', N'1 (11) 500 555-0120')
,(30074, N'Ms.', N'Yuping', NULL, N'Tian', NULL, N'Tenth Bike Store', N'adventure-works\jos�1', N'yuping0@adventure-works.com', N'744-555-0123')
,(30076, N'Ms.', N'Diane', NULL, N'Tibbott', NULL, N'Fun Times Club', N'adventure-works\shu0', N'diane5@adventure-works.com', N'847-555-0184')
,(30080, N'Ms.', N'Delia', N'B.', N'Toone', NULL, N'Wingtip Toys', N'adventure-works\david8', N'delia0@adventure-works.com', N'328-555-0192')
,(30083, N'Mr.', N'Glenn', N'J.', N'Track', N'II', N'Active Life Toys', N'adventure-works\jos�1', N'glenn0@adventure-works.com', N'907-555-0170')
,(30087, N'Mr.', N'Billy', N'J.', N'Trent', NULL, N'Quick Parts and Service', N'adventure-works\garrett1', N'billy0@adventure-works.com', N'882-555-0115')
,(30089, N'Mr.', N'Michael John', N'R.', N'Troyer', NULL, N'Thrifty Parts and Sales', N'adventure-works\linda3', N'michaeljohn0@adventure-works.com', N'308-555-0175')
,(30090, N'Ms.', N'Christie', N'J.', N'Trujillo', NULL, N'A Typical Bike Shop', N'adventure-works\jillian0', N'christie0@adventure-works.com', N'686-555-0180')
,(30093, N'Ms.', N'Phyllis', N'B.', N'Tuffield', NULL, N'Fasteners & Bolts Outlet', N'adventure-works\garrett1', N'phyllis3@adventure-works.com', N'277-555-0182')
,(30094, N'Mr.', N'Sairaj', NULL, N'Uddin', NULL, N'Quantity Discounts', N'adventure-works\linda3', N'sairaj1@adventure-works.com', N'767-555-0193')
,(30095, N'Mr.', N'Sunil', NULL, N'Uppal', NULL, N'Swift Cycles', N'adventure-works\jillian0', N'sunil0@adventure-works.com', N'184-555-0187')
,(30098, N'Ms.', N'Esther', N'K.', N'Valle', NULL, N'Large Bike Shop', N'adventure-works\garrett1', N'esther0@adventure-works.com', N'481-555-0131')
,(30100, N'Mr.', N'Jessie', N'E.', N'Valerio', NULL, N'Wire Baskets and Parts', N'adventure-works\linda3', N'jessie0@adventure-works.com', N'103-555-0179')
,(30102, N'Mr.', N'Roger', NULL, N'Van Houten', NULL, N'Sports Store', N'adventure-works\jae0', N'roger2@adventure-works.com', N'1 (11) 500 555-0110')
,(30104, N'Ms.', N'Rose', N'M.', N'Vandenouer', NULL, N'Extended Tours', N'adventure-works\jae0', N'rose1@adventure-works.com', N'1 (11) 500 555-0140')
,(30105, N'Mr.', N'Gregory', N'T.', N'Vanderbout', N'Jr.', N'Convenient Sales and Service', N'adventure-works\pamela0', N'gregory1@adventure-works.com', N'684-555-0134')
,(30106, N'Mr.', N'Michael', NULL, N'Vanderhyde', NULL, N'Solid Bike Parts', N'adventure-works\jillian0', N'michael25@adventure-works.com', N'918-555-0141')
,(30107, N'Ms.', N'Margaret', N'J.', N'Vanderkamp', NULL, N'Permanent Finish Products', N'adventure-works\shu0', N'margaret2@adventure-works.com', N'265-555-0143')
,(30108, N'Ms.', N'Kara', N'N.', N'Vanderlinden', NULL, N'Mercantile Outlet', N'adventure-works\jos�1', N'kara0@adventure-works.com', N'680-555-0160')
,(30109, N'Mr.', N'Nieves', N'J.', N'Vargas', N'II', N'Exhilarating Cycles', N'adventure-works\michael9', N'nieves0@adventure-works.com', N'371-555-0184')
,(30110, N'Mr.', N'Gary', N'T', N'Vargas', NULL, N'Exercise Center', N'adventure-works\shu0', N'gary6@adventure-works.com', N'112-555-0176')
,(30111, N'Mr.', N'Ranjit', N'Rudra', N'Varkey Chudukatil', NULL, N'Great Bicycle Supply', N'adventure-works\jillian0', N'ranjit1@adventure-works.com', N'810-555-0160')
,(30112, N'Ms.', N'Patricia', N'M.', N'Vasquez', NULL, N'Mail-Order Outlet', N'adventure-works\pamela0', N'patricia2@adventure-works.com', N'490-555-0132')
,(30113, N'Mr.', N'Raja', N'D.', N'Venugopal', NULL, N'Nearby Cycle Shop', N'adventure-works\jae0', N'raja0@adventure-works.com', N'1 (11) 500 555-0195')
,(30115, N'Ms.', N'Dora', N'P.', N'Verdad', NULL, N'Retreat Inn', N'adventure-works\jos�1', N'dora0@adventure-works.com', N'155-555-0140')
,(30116, N'Ms.', N'Wanda', N'F.', N'Vernon', NULL, N'Technical Parts Manufacturing', N'adventure-works\shu0', N'wanda0@adventure-works.com', N'433-555-0168')
,(30117, N'Mr.', N'Robert', N'R.', N'Vessa', NULL, N'Totes & Baskets Company', N'adventure-works\jillian0', N'robert13@adventure-works.com', N'560-555-0171')
,(30118, N'Ms.', N'Caroline', N'A.', N'Vicknair', NULL, N'World of Bikes', N'adventure-works\jillian0', N'caroline0@adventure-works.com', N'695-555-0158')
GO
Print 'Insert into CustomerAddress table...'
INSERT [dbo].[CustomerAddress] ([AddressID], [CustomerID], [AddressType], [AddressLine1], [AddressLine2], [City], [StateProvince], [CountryRegion], [PostalCode]) VALUES 
(1086, 29485, N'Main Office', N'57251 Serene Blvd', NULL, N'Van Nuys', N'California', N'United States', N'91411')
,(621, 29486, N'Main Office', N'Tanger Factory', NULL, N'Branch', N'Minnesota', N'United States', N'55056')
,(1069, 29489, N'Main Office', N'6900 Sisk Road', NULL, N'Modesto', N'California', N'United States', N'95354')
,(887, 29490, N'Main Office', N'Lewiston Mall', NULL, N'Lewiston', N'Idaho', N'United States', N'83501')
,(618, 29492, N'Main Office', N'Blue Ridge Mall', NULL, N'Kansas City', N'Missouri', N'United States', N'64106')
,(537, 29494, N'Main Office', N'No. 25800-130 King Street West', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(1072, 29496, N'Main Office', N'6500 East Grant Road', NULL, N'Tucson', N'Arizona', N'United States', N'85701')
,(889, 29497, N'Main Office', N'Eastridge Mall', NULL, N'Casper', N'Wyoming', N'United States', N'82601')
,(527, 29499, N'Main Office', N'252851 Rowan Place', NULL, N'Richmond', N'British Columbia', N'Canada', N'V6B 3P7')
,(893, 29502, N'Main Office', N'White Mountain Mall', NULL, N'Rock Springs', N'Wyoming', N'United States', N'82901')
,(32, 29503, N'Shipping', N'26910 Indela Road', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H5')
,(541, 29503, N'Main Office', N'25981 College Street', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H5')
,(1083, 29505, N'Main Office', N'22589 West Craig Road', NULL, N'North Las Vegas', N'Nevada', N'United States', N'89030')
,(1082, 29506, N'Main Office', N'2551 East Warner Road', NULL, N'Gilbert', N'Arizona', N'United States', N'85233')
,(619, 29508, N'Main Office', N'First Colony Mall', NULL, N'Sugar Land', N'Texas', N'United States', N'77478')
,(540, 29510, N'Main Office', N'254 Colonnade Road', NULL, N'Nepean', N'Ontario', N'Canada', N'K2J 2W5')
,(1046, 29511, N'Main Office', N'Rocky Mountain Pines Outlet', NULL, N'Loveland', N'Colorado', N'United States', N'80537')
,(504, 29515, N'Main Office', N'Suite 99320 255 - 510th Avenue S.W.', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(794, 29517, N'Main Office', N'998 Forest Road', NULL, N'Saginaw', N'Michigan', N'United States', N'48601')
,(1054, 29521, N'Main Office', N'Belz Factory Outlet', NULL, N'Las Vegas', N'Nevada', N'United States', N'89106')
,(1040, 29522, N'Main Office', N'Fox Hills', NULL, N'Culver City', N'California', N'United States', N'90232')
,(593, 29523, N'Main Office', N'2345 North Freeway', NULL, N'Houston', N'Texas', N'United States', N'77003')
,(599, 29524, N'Main Office', N'70 N.W. Plaza', NULL, N'Saint Ann', N'Missouri', N'United States', N'63074')
,(1049, 29525, N'Main Office', N'The Citadel Commerce Plaza', NULL, N'City Of Commerce', N'California', N'United States', N'90040')
,(512, 29527, N'Main Office', N'700 Bureau Road', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H7')
,(788, 29528, N'Main Office', N'2533 Eureka Rd.', NULL, N'Southgate', N'Michigan', N'United States', N'48195')
,(495, 29530, N'Main Office', N'Suite 800 2530 Slater Street', NULL, N'Ottawa', N'Ontario', N'Canada', N'K4B 1T7')
,(1061, 29531, N'Main Office', N'Eastern Beltway Center', NULL, N'Las Vegas', N'Nevada', N'United States', N'89106')
,(881, 29532, N'Main Office', N'Southgate Mall', NULL, N'Missoula', N'Montana', N'United States', N'59801')
,(801, 29533, N'Main Office', N'Horizon Outlet Center', NULL, N'Holland', N'Michigan', N'United States', N'49423')
,(591, 29535, N'Main Office', N'48255 I-10 E. @ Eastpoint Blvd.', NULL, N'Baytown', N'Texas', N'United States', N'77520')
,(786, 29536, N'Main Office', N'6789 Warren Road', NULL, N'Westland', N'Michigan', N'United States', N'48185')
,(480, 29539, N'Main Office', N'25 First Canadian Place', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(467, 29541, N'Main Office', N'25900-700-9th Ave S.W.', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(519, 29544, N'Main Office', N'2500-622 5th Ave Sw', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(11, 29545, N'Shipping', N'1318 Lasalle Street', NULL, N'Bothell', N'Washington', N'United States', N'98011')
,(834, 29545, N'Main Office', N'99300 223rd Southeast', NULL, N'Bothell', N'Washington', N'United States', N'98011')
,(635, 29546, N'Main Office', N'93-2501, Blackfriars Road,', NULL, N'London', N'England', N'United Kingdom', N'SE1 8HL')
,(498, 29548, N'Main Office', N'25537 Hillside Avenue', NULL, N'Victoria', N'British Columbia', N'Canada', N'V8V')
,(853, 29550, N'Main Office', N'567 Sw Mcloughlin Blvd', NULL, N'Milwaukie', N'Oregon', N'United States', N'97222')
,(581, 29553, N'Main Office', N'Po Box 8035996', NULL, N'Dallas', N'Texas', N'United States', N'75201')
,(776, 29554, N'Main Office', N'997000 Telegraph Rd.', NULL, N'Southfield', N'Michigan', N'United States', N'48034')
,(513, 29557, N'Main Office', N'253711 Mayfield Place, Unit 150', NULL, N'Richmond', N'British Columbia', N'Canada', N'V6B 3P7')
,(500, 29558, N'Main Office', N'5700 Explorer Drive', NULL, N'Mississauga', N'Ontario', N'Canada', N'L4W 5J3')
,(185, 29559, N'Shipping', N'2681 Eagle Peak', NULL, N'Bellevue', N'Washington', N'United States', N'98004')
,(861, 29559, N'Main Office', N'25915 140th Ave Ne', NULL, N'Bellevue', N'Washington', N'United States', N'98004')
,(1030, 29560, N'Main Office', N'Escondido', NULL, N'Escondido', N'California', N'United States', N'92025')
,(1091, 29562, N'Main Office', N'5500 Grossmont Center Drive', NULL, N'La Mesa', N'California', N'United States', N'91941')
,(1073, 29565, N'Main Office', N'3065 Santa Margarita Parkway', NULL, N'Trabuco Canyon', N'California', N'United States', N'92679')
,(810, 29566, N'Main Office', N'Redford Plaza', NULL, N'Redford', N'Michigan', N'United States', N'48239')
,(448, 29567, N'Main Office', N'2575 Bloor Street East', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V6')
,(993, 29568, N'Main Office', N'Corporate Office', NULL, N'El Segundo', N'California', N'United States', N'90245')
,(562, 29569, N'Main Office', N'2505 Gateway Drive', NULL, N'North Sioux City', N'South Dakota', N'United States', N'57049')
,(592, 29570, N'Main Office', N'9903 Highway 6 South', NULL, N'Houston', N'Texas', N'United States', N'77003')
,(864, 29571, N'Main Office', N'67 Rainer Ave S', NULL, N'Renton', N'Washington', N'United States', N'98055')
,(1016, 29573, N'Main Office', N'72502 Eastern Ave.', NULL, N'Bell Gardens', N'California', N'United States', N'90201')
,(577, 29574, N'Main Office', N'2500 North Stemmons Freeway', NULL, N'Dallas', N'Texas', N'United States', N'75201')
,(514, 29576, N'Main Office', N'63 West Beaver Creek', NULL, N'Richmond Hill', N'Ontario', N'Canada', N'L4E 3M5')
,(471, 29577, N'Main Office', N'770 Notre Datme Quest Bureau 800', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H7')
,(1012, 29579, N'Main Office', N'789 West Alameda', NULL, N'Westminster', N'Colorado', N'United States', N'80030')
,(849, 29580, N'Main Office', N'4251 First Avenue', NULL, N'Seattle', N'Washington', N'United States', N'98104')
,(848, 29582, N'Main Office', N'Bldg. 9n/99298', NULL, N'Redmond', N'Washington', N'United States', N'98052')
,(576, 29583, N'Main Office', N'4255 East Lies Road', NULL, N'Carol Stream', N'Illinois', N'United States', N'60188')
,(1014, 29584, N'Main Office', N'25136 Jefferson Blvd.', NULL, N'Culver City', N'California', N'United States', N'90232')
,(841, 29585, N'Main Office', N'Washington Square', NULL, N'Portland', N'Oregon', N'United States', N'97205')
,(664, 29587, N'Main Office', N'99-3 Forest Works', NULL, N'London', N'England', N'United Kingdom', N'E17 6JF')
,(890, 29588, N'Main Office', N'Holiday Village Mall', NULL, N'Great Falls', N'Montana', N'United States', N'59401')
,(789, 29590, N'Main Office', N'250000 Eight Mile Road', NULL, N'Detroit', N'Michigan', N'United States', N'48226')
,(584, 29591, N'Main Office', N'250880 Baur Blvd', NULL, N'Saint Louis', N'Missouri', N'United States', N'63103')
,(585, 29593, N'Main Office', N'Noah Lane', NULL, N'Chicago', N'Illinois', N'United States', N'60610')
,(458, 29596, N'Main Office', N'600 Slater Street', NULL, N'Ottawa', N'Ontario', N'Canada', N'K4B 1S2')
,(1000, 29598, N'Main Office', N'22555 Paseo De Las Americas', NULL, N'San Diego', N'California', N'United States', N'92102')
,(877, 29599, N'Main Office', N'4781 Highway 95', NULL, N'Sandpoint', N'Idaho', N'United States', N'83864')
,(797, 29600, N'Main Office', N'678 Eastman Ave.', NULL, N'Midland', N'Michigan', N'United States', N'48640')
,(516, 29601, N'Main Office', N'251 Indell Lane', NULL, N'Brampton', N'Ontario', N'Canada', N'L6W 2T7')
,(518, 29603, N'Main Office', N'995 Crescent', NULL, N'Richmond Hill', N'Ontario', N'Canada', N'L4E 3M5')
,(1060, 29605, N'Main Office', N'Arcadia Crossing', NULL, N'Phoenix', N'Arizona', N'United States', N'85004')
,(871, 29606, N'Main Office', N'2502 Evergreen Ste E', NULL, N'Everett', N'Washington', N'United States', N'98201')
,(488, 29608, N'Main Office', N'45259 Canada Way', NULL, N'Burnaby', N'British Columbia', N'Canada', N'V5G 4S4')
,(862, 29611, N'Main Office', N'3307 Evergreen Blvd', N'Ste 1071', N'Washougal', N'Washington', N'United States', N'98671')
,(649, 29612, N'Main Office', N'Knaves Beech Ind.', NULL, N'High Wycombe', N'England', N'United Kingdom', N'HP10 9QY')
,(529, 29614, N'Main Office', N'254480 River Rd', NULL, N'Richmond', N'British Columbia', N'Canada', N'V6B 3P7')
,(663, 29615, N'Main Office', N'2524 Barlby Road', NULL, N'London', N'England', N'United Kingdom', N'W10 6BL')
,(608, 29616, N'Main Office', N'25306 Harvey Rd.', NULL, N'College Station', N'Texas', N'United States', N'77840')
,(880, 29617, N'Main Office', N'S Sound Ctr Suite 25300', NULL, N'Lacey', N'Washington', N'United States', N'98503')
,(658, 29618, N'Main Office', N'Ellesfield Ave', NULL, N'Bracknell', N'England', N'United Kingdom', N'RG12 8TB')
,(503, 29620, N'Main Office', N'P.O. Box 44000', NULL, N'Winnipeg', N'Manitoba', N'Canada', N'R3')
,(863, 29622, N'Main Office', N'2507 Pacific Ave S', NULL, N'Tacoma', N'Washington', N'United States', N'98403')
,(1033, 29623, N'Main Office', N'Lakewood Mall', NULL, N'Lakewood', N'California', N'United States', N'90712')
,(491, 29625, N'Main Office', N'20225 Lansing Ave', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H7')
,(447, 29627, N'Main Office', N'22580 Free Street', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(469, 29629, N'Main Office', N'400-25155 West Pender St', NULL, N'Vancouver', N'British Columbia', N'Canada', N'V7L 4J4')
,(1003, 29631, N'Main Office', N'5967 W Las Positas Blvd', NULL, N'Pleasanton', N'California', N'United States', N'94566')
,(843, 29632, N'Main Office', N'253950 N.E. 178th Place', NULL, N'Woodinville', N'Washington', N'United States', N'98072')
,(634, 29635, N'Main Office', N'Ward Parkway Center', NULL, N'Kansas City', N'Missouri', N'United States', N'64106')
,(1105, 29636, N'Main Office', N'566 S. Main', NULL, N'Cedar City', N'Utah', N'United States', N'84720')
,(559, 29637, N'Main Office', N'12345 Sterling Avenue', NULL, N'Irving', N'Texas', N'United States', N'75061')
,(989, 29638, N'Main Office', N'39933 Mission Oaks Blvd', NULL, N'Camarillo', N'California', N'United States', N'93010')
,(470, 29639, N'Main Office', N'2511 Baker Road', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(1088, 29641, N'Main Office', N'99040 California Avenue', NULL, N'Sand City', N'California', N'United States', N'93955')
,(899, 29643, N'Main Office', N'North 93270 Newport Highway', NULL, N'Spokane', N'Washington', N'United States', N'99202')
GO
print 'Processed 100 total records'
INSERT [dbo].[CustomerAddress] ([AddressID], [CustomerID], [AddressType], [AddressLine1], [AddressLine2], [City], [StateProvince], [CountryRegion], [PostalCode]) VALUES 
(643, 29644, N'Main Office', N'Banbury', NULL, N'Oxon', N'England', N'United Kingdom', N'OX16 8RS')
,(850, 29645, N'Main Office', N'558 S 6th St', NULL, N'Klamath Falls', N'Oregon', N'United States', N'97601')
,(578, 29646, N'Main Office', N'220 Mercy Drive', NULL, N'Garland', N'Texas', N'United States', N'75040')
,(544, 29649, N'Main Office', N'30025 Wayburne Drive, Suite 275', NULL, N'Burnaby', N'British Columbia', N'Canada', N'V5G 4W1')
,(1059, 29650, N'Main Office', N'The Quad @ WestView', NULL, N'Whittier', N'California', N'United States', N'90605')
,(606, 29651, N'Main Office', N'99433 S. Greenbay Rd.', NULL, N'Racine', N'Wisconsin', N'United States', N'53182')
,(1019, 29653, N'Main Office', N'4660 Rodeo Road', NULL, N'Santa Fe', N'New Mexico', N'United States', N'87501')
,(579, 29654, N'Main Office', N'25 N State St', NULL, N'Chicago', N'Illinois', N'United States', N'60610')
,(774, 29655, N'Main Office', N'9920 North Telegraph Rd.', NULL, N'Pontiac', N'Michigan', N'United States', N'48342')
,(605, 29659, N'Main Office', N'7760 N. Pan Am Expwy', NULL, N'San Antonio', N'Texas', N'United States', N'78204')
,(1058, 29660, N'Main Office', N'Riverside', NULL, N'Sherman Oaks', N'California', N'United States', N'91403')
,(1013, 29662, N'Main Office', N'54254 Pacific Ave.', NULL, N'Stockton', N'California', N'United States', N'95202')
,(575, 29663, N'Main Office', N'42500 W 76th St', NULL, N'Chicago', N'Illinois', N'United States', N'60610')
,(468, 29666, N'Main Office', N'Po Box 83270', NULL, N'Vancouver', N'British Columbia', N'Canada', N'V7L 4J4')
,(573, 29668, N'Main Office', N'25269 Wood Dale Rd.', NULL, N'Wood Dale', N'Illinois', N'United States', N'60191')
,(465, 29671, N'Main Office', N'25245 Rue Sherbrooke Ouest', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H5')
,(1007, 29673, N'Main Office', N'77 Beale Street', N'Room 99767c', N'San Francisco', N'California', N'United States', N'94109')
,(571, 29674, N'Main Office', N'25550 Executive Dr', NULL, N'Elgin', N'Illinois', N'United States', N'60120')
,(461, 29677, N'Main Office', N'2560 Bay Street', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(509, 29680, N'Main Office', N'Suite 25800 3401 - 10810th Avenue', NULL, N'Surrey', N'British Columbia', N'Canada', N'V3T 4W3')
,(1051, 29682, N'Main Office', N'Pavillion @ Redlands', NULL, N'Redlands', N'California', N'United States', N'92373')
,(875, 29683, N'Main Office', N'2540 Dell Range Blvd', NULL, N'Cheyenne', N'Wyoming', N'United States', N'82001')
,(795, 29684, N'Main Office', N'99800 Tittabawasee Rd.', NULL, N'Saginaw', N'Michigan', N'United States', N'48601')
,(1048, 29686, N'Main Office', N'Factory Merchants', NULL, N'Barstow', N'California', N'United States', N'92311')
,(785, 29688, N'Main Office', N'399700 John R. Rd.', NULL, N'Madison Heights', N'Michigan', N'United States', N'48071')
,(865, 29689, N'Main Office', N'750 Lakeway Dr', NULL, N'Bellingham', N'Washington', N'United States', N'98225')
,(1036, 29690, N'Main Office', N'Sports Store At Park City', NULL, N'Park City', N'Utah', N'United States', N'84098')
,(494, 29692, N'Main Office', N'Box 99354 300 Union Street', NULL, N'Saint John', N'Brunswick', N'Canada', N'E2P 1E3')
,(867, 29695, N'Main Office', N'48995 Evergreen Wy.', NULL, N'Everett', N'Washington', N'United States', N'98201')
,(1039, 29696, N'Main Office', N'Mountain Square', NULL, N'Upland', N'California', N'United States', N'91786')
,(497, 29698, N'Main Office', N'#9900 2700 Production Way', NULL, N'Burnaby', N'British Columbia', N'Canada', N'V5A 4X1')
,(456, 29699, N'Main Office', N'6777 Kingsway', NULL, N'Burnaby', N'British Columbia', N'Canada', N'V5H 3Z7')
,(567, 29702, N'Main Office', N'Corporate Office', NULL, N'Garland', N'Texas', N'United States', N'75040')
,(1001, 29703, N'Main Office', N'Incom Sports Center', NULL, N'Ontario', N'California', N'United States', N'91764')
,(459, 29705, N'Main Office', N'25575 The Queensway', NULL, N'Etobicoke', N'Ontario', N'Canada', N'M9W 3P3')
,(569, 29708, N'Main Office', N'Sapp Road West', NULL, N'Round Rock', N'Texas', N'United States', N'78664')
,(906, 29709, N'Main Office', N'7009 Sw Hall Blvd.', NULL, N'Tigard', N'Oregon', N'United States', N'97223')
,(1017, 29710, N'Main Office', N'2560 E. Newlands Dr', NULL, N'Fernley', N'Nevada', N'United States', N'89408')
,(472, 29711, N'Main Office', N'250551 Shellbridge Way', NULL, N'Richmond', N'British Columbia', N'Canada', N'V6B 3P7')
,(644, 29713, N'Main Office', N'Bradford', N'Raven House, Kingsgate', N'W. York', N'England', N'United Kingdom', N'BD1 4SJ')
,(473, 29714, N'Main Office', N'595 Burning Street', NULL, N'Vancouver', N'British Columbia', N'Canada', N'V7L 4J4')
,(1015, 29716, N'Main Office', N'99000 S. Avalon Blvd. Suite 750', NULL, N'Carson', N'California', N'United States', N'90746')
,(851, 29717, N'Main Office', N'994 Sw Cherry Park Rd', NULL, N'Troutdale', N'Oregon', N'United States', N'97060')
,(905, 29719, N'Main Office', N'225 South 314th Street', NULL, N'Federal Way', N'Washington', N'United States', N'98003')
,(1100, 29720, N'Main Office', N'4635 S. Harrison Blvd.', NULL, N'Ogden', N'Utah', N'United States', N'84401')
,(555, 29722, N'Main Office', N'9950 Ferrand Drive, 9th Floor', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V4')
,(907, 29727, N'Main Office', N'99295 S.e. Tualatin Valley_hwy.', NULL, N'Hillsboro', N'Oregon', N'United States', N'97123')
,(1103, 29728, N'Main Office', N'2564 S. Redwood Rd.', NULL, N'Riverton', N'Utah', N'United States', N'84065')
,(558, 29730, N'Main Office', N'67255 - 8th Street N.E., Suite 350', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(607, 29732, N'Main Office', N'25220 Airline Road', NULL, N'Corpus Christi', N'Texas', N'United States', N'78404')
,(1062, 29733, N'Main Office', N'Factory Stores/tucson', NULL, N'Tucson', N'Arizona', N'United States', N'85701')
,(517, 29734, N'Main Office', N'2573 Dufferin Street', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(659, 29736, N'Main Office', N'Warrington Ldc Unit 25/2', NULL, N'Woolston', N'England', N'United Kingdom', N'WA1 4SY')
,(882, 29737, N'Main Office', N'Medford', NULL, N'Medford', N'Oregon', N'United States', N'97504')
,(610, 29738, N'Main Office', N'44025 W. Empire', NULL, N'Denby', N'South Dakota', N'United States', N'57716')
,(1065, 29739, N'Main Office', N'Factory Stores Of America', NULL, N'Mesa', N'Arizona', N'United States', N'85201')
,(520, 29740, N'Main Office', N'6700 Boul Taschereau', NULL, N'Brossard', N'Quebec', N'Canada', N'J4Z 1C5')
,(660, 29741, N'Main Office', N'6 The Farm, Liberty Road', NULL, N'Maidenhead', N'England', N'United Kingdom', N'SL67RJ')
,(884, 29742, N'Main Office', N'Lewis County Mall', NULL, N'Chehalis', N'Washington', N'United States', N'98532')
,(612, 29743, N'Main Office', N'Ring Plaza', NULL, N'Norridge', N'Illinois', N'United States', N'60706')
,(1068, 29744, N'Main Office', N'7709 West Virginia Avenue', NULL, N'Phoenix', N'Arizona', N'United States', N'85004')
,(895, 29747, N'Main Office', N'3250 South Meridian', NULL, N'Puyallup', N'Washington', N'United States', N'98371')
,(1085, 29748, N'Main Office', N'49925 Crestview Drive N.E.', NULL, N'Rio Rancho', N'New Mexico', N'United States', N'87124')
,(543, 29750, N'Main Office', N'6030 Conroy Road', NULL, N'Ottawa', N'Ontario', N'Canada', N'K4B 1S3')
,(897, 29753, N'Main Office', N'705 SE Mall Parkway', NULL, N'Everett', N'Washington', N'United States', N'98201')
,(528, 29755, N'Main Office', N'5990 Avebury Road', NULL, N'Mississauga', N'Ontario', N'Canada', N'L5B 3V4')
,(1070, 29757, N'Main Office', N'3250 Baldwin Park Blvd', NULL, N'Baldwin Park', N'California', N'United States', N'91706')
,(613, 29758, N'Main Office', N'Lakeline Mall', NULL, N'Cedar Park', N'Texas', N'United States', N'78613')
,(525, 29761, N'Main Office', N'69251 Creditview Road', NULL, N'Mississauga', N'Ontario', N'Canada', N'L5B 3V4')
,(1067, 29763, N'Main Office', N'Bayshore Mall', NULL, N'Eureka', N'California', N'United States', N'95501')
,(611, 29764, N'Main Office', N'23025 S.W. Military Rd.', NULL, N'San Antonio', N'Texas', N'United States', N'78204')
,(806, 29765, N'Main Office', N'Horizon Outlet Center', NULL, N'Monroe', N'Michigan', N'United States', N'98272')
,(522, 29766, N'Main Office', N'43251 Viking Way, Unit 130', NULL, N'Richmond', N'British Columbia', N'Canada', N'V6B 3P7')
,(1064, 29768, N'Main Office', N'West Park Plaza', NULL, N'Irvine', N'California', N'United States', N'92614')
,(609, 29769, N'Main Office', N'3900 S. 997th St.', NULL, N'Milwaukee', N'Wisconsin', N'United States', N'53202')
,(445, 29770, N'Main Office', N'6388 Lake City Way', NULL, N'Burnaby', N'British Columbia', N'Canada', N'V5A 3A6')
,(990, 29771, N'Main Office', N'5420 West 22500 South', NULL, N'Salt Lake City', N'Utah', N'United States', N'84101')
,(560, 29772, N'Main Office', N'800 Interchange Blvd.', N'Suite 2501', N'Austin', N'Texas', N'United States', N'78701')
,(11380, 29772, N'Shipping', N'165 North Main', NULL, N'Austin', N'Texas', N'United States', N'78701')
,(832, 29773, N'Main Office', N'2251 Elliot Avenue', NULL, N'Seattle', N'Washington', N'United States', N'98104')
,(564, 29774, N'Main Office', N'509 Nafta Boulevard', NULL, N'Laredo', N'Texas', N'United States', N'78040')
,(836, 29775, N'Main Office', N'35525-9th Street Sw', NULL, N'Puyallup', N'Washington', N'United States', N'98371')
,(636, 29776, N'Main Office', N'Science Park South, Birchwood', N'Stanford House', N'Warrington', N'England', N'United Kingdom', N'WA3 7BH')
,(650, 29778, N'Main Office', N'Elmhurst Road, Goring', NULL, N'Reading', N'England', N'United Kingdom', N'RG7 5H7')
,(490, 29780, N'Main Office', N'9979 Bayview Drive', NULL, N'Barrie', N'Ontario', N'Canada', N'L4N')
,(1035, 29781, N'Main Office', N'Vista Marketplace', NULL, N'Alhambra', N'California', N'United States', N'91801')
,(590, 29782, N'Main Office', N'9995 West Central Entrance', NULL, N'Duluth', N'Minnesota', N'United States', N'55802')
,(1075, 29783, N'Main Office', N'5525 South Hover Road', NULL, N'Longmont', N'Colorado', N'United States', N'80501')
,(1078, 29784, N'Main Office', N'9909 W. Ventura Boulevard', NULL, N'Camarillo', N'California', N'United States', N'93010')
,(533, 29785, N'Main Office', N'4400 March Road', NULL, N'Kanata', N'Ontario', N'Canada', N'K2L 1H5')
,(869, 29787, N'Main Office', N'2583 Se 272nd St', NULL, N'Kent', N'Washington', N'United States', N'98031')
,(1043, 29788, N'Main Office', N'Hanford Mall', NULL, N'Hanford', N'California', N'United States', N'93230')
,(501, 29789, N'Main Office', N'965 De La Gauchetiere West', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H8')
,(597, 29792, N'Main Office', N'99450 Highway 59 North', NULL, N'Humble', N'Texas', N'United States', N'77338')
,(1011, 29793, N'Main Office', N'9700 Sisk Road', NULL, N'Modesto', N'California', N'United States', N'95354')
,(466, 29794, N'Main Office', N'655-4th Ave S.W.', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(642, 29796, N'Main Office', N'Galashiels', NULL, N'Liverpool', N'England', N'United Kingdom', N'L4 4HB')
,(455, 29797, N'Main Office', N'2550 Signet Drive', NULL, N'Weston', N'Ontario', N'Canada', N'M9V 4W3')
,(997, 29799, N'Main Office', N'70259 West Sunnyview Ave', NULL, N'Visalia', N'California', N'United States', N'93291')
,(839, 29800, N'Main Office', N'Gateway', NULL, N'Portland', N'Oregon', N'United States', N'97205')
,(452, 29803, N'Main Office', N'55 Lakeshore Blvd East', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V6')
GO
print 'Processed 200 total records'
INSERT [dbo].[CustomerAddress] ([AddressID], [CustomerID], [AddressType], [AddressLine1], [AddressLine2], [City], [StateProvince], [CountryRegion], [PostalCode]) VALUES 
(994, 29805, N'Main Office', N'25001 Montague Expressway', NULL, N'Milpitas', N'California', N'United States', N'95035')
,(837, 29806, N'Main Office', N'640 South 994th St. W.', NULL, N'Billings', N'Montana', N'United States', N'59101')
,(449, 29807, N'Main Office', N'Station E', NULL, N'Chalk Riber', N'Ontario', N'Canada', N'K0J 1J0')
,(991, 29809, N'Main Office', N'60025 Bollinger Canyon Road', NULL, N'San Ramon', N'California', N'United States', N'94583')
,(835, 29810, N'Main Office', N'259826 Russell Rd. South', NULL, N'Kent', N'Washington', N'United States', N'98031')
,(446, 29813, N'Main Office', N'52560 Free Street', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(988, 29815, N'Main Office', N'482505 Warm Springs Blvd.', NULL, N'Fremont', N'California', N'United States', N'94536')
,(297, 29816, N'Shipping', N'7943 Walnut Ave', NULL, N'Renton', N'Washington', N'United States', N'98055')
,(833, 29816, N'Main Office', N'3207 S Grady Way', NULL, N'Renton', N'Washington', N'United States', N'98055')
,(1104, 29818, N'Main Office', N'9927 N. Main St.', NULL, N'Tooele', N'Utah', N'United States', N'84074')
,(633, 29819, N'Main Office', N'Medford Outlet Center', NULL, N'Medford', N'Minnesota', N'United States', N'55049')
,(557, 29822, N'Main Office', N'660 Saint-Jacques, Bureau 400', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H8')
,(556, 29824, N'Main Office', N'990th Floor 700 De La GauchetiSre Ou', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H3')
,(1101, 29826, N'Main Office', N'825 W 500 S', NULL, N'Bountiful', N'Utah', N'United States', N'84010')
,(631, 29827, N'Main Office', N'Kansas City Factory Outlet', NULL, N'Odessa', N'Missouri', N'United States', N'64076')
,(553, 29830, N'Main Office', N'253131 Lake Frasier Drive, Office No. 2', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(552, 29831, N'Main Office', N'25730, boul. St-R�gis', NULL, N'Dorval', N'Quebec', N'Canada', N'H9P 1H1')
,(551, 29832, N'Main Office', N'32605 West 252 Mile Road, Suite 250', NULL, N'Aurora', N'Ontario', N'Canada', N'L4G 7N6')
,(1097, 29834, N'Main Office', N'Corp Ofc Accts Payable', NULL, N'El Segundo', N'California', N'United States', N'90245')
,(903, 29835, N'Main Office', N'250775 SW Hillsdale Hwy', NULL, N'Beaverton', N'Oregon', N'United States', N'97005')
,(547, 29840, N'Main Office', N'7000 Victoria Park Avenue', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V4')
,(1094, 29842, N'Main Office', N'25250 N 90th St', NULL, N'Scottsdale', N'Arizona', N'United States', N'85257')
,(901, 29843, N'Main Office', N'No. 60 Bellis Fair Parkway', NULL, N'Bellingham', N'Washington', N'United States', N'98225')
,(1092, 29847, N'Main Office', N'99700 Bell Road', NULL, N'Auburn', N'California', N'United States', N'95603')
,(625, 29848, N'Main Office', N'Cedar Creek Stores', NULL, N'Mosinee', N'Wisconsin', N'United States', N'54455')
,(623, 29850, N'Main Office', N'Ohms Road', NULL, N'Houston', N'Texas', N'United States', N'77003')
,(657, 29851, N'Main Office', N'Unit 99a Battery Retail Pk', NULL, N'Birmingham', N'England', N'United Kingdom', N'B29 6SL')
,(511, 29852, N'Main Office', N'Bureau 9900 825, Avenue Querbes', NULL, N'Outremont', N'Quebec', N'Canada', N'H1Y 2G5')
,(1056, 29853, N'Main Office', N'Lake Elisnor Place', NULL, N'Lake Elsinore', N'California', N'United States', N'92530')
,(604, 29854, N'Main Office', N'1200 First Ave.', NULL, N'Joliet', N'Illinois', N'United States', N'60433')
,(539, 29855, N'Main Office', N'6th Floor, 25st Canadian Place', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(666, 29857, N'Main Office', N'399 Clearing Green', NULL, N'London', N'England', N'United Kingdom', N'EC1R 0DU')
,(894, 29858, N'Main Office', N'3390 South 23rd St.', NULL, N'Tacoma', N'Washington', N'United States', N'98403')
,(622, 29859, N'Main Office', N'Management Mall', NULL, N'San Antonio', N'Texas', N'United States', N'78204')
,(668, 29860, N'Main Office', N'2574 Milton Park', NULL, N'Oxford', N'England', N'United Kingdom', N'OX14 4SE')
,(628, 29861, N'Main Office', N'City Center', NULL, N'Minneapolis', N'Minnesota', N'United States', N'55402')
,(11382, 29861, N'Shipping', N'99 Front Street', NULL, N'Minneapolis', N'Minnesota', N'United States', N'55402')
,(1096, 29862, N'Main Office', N'6753 Howard Hughes Parkway', NULL, N'Las Vegas', N'Nevada', N'United States', N'89106')
,(546, 29863, N'Main Office', N'250333 Southport Road, S.W.', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(487, 29864, N'Main Office', N'9259 - 1110th Avenue Sw', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(1032, 29865, N'Main Office', N'Simi @ The Plaza', NULL, N'Simi Valley', N'California', N'United States', N'93065')
,(588, 29866, N'Main Office', N'99828 Routh Street, Suite 825', NULL, N'Dallas', N'Texas', N'United States', N'75201')
,(860, 29867, N'Main Office', N'4927 S Meridian Ave Ste D', NULL, N'Puyallup', N'Washington', N'United States', N'98371')
,(648, 29868, N'Main Office', N'586 Fulham Road,', NULL, N'London', N'England', N'United Kingdom', N'SW6 SBY')
,(484, 29870, N'Main Office', N'2510 Crew Court', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H8')
,(1029, 29871, N'Main Office', N'Topanga Plaza', NULL, N'Canoga Park', N'California', N'United States', N'91303')
,(586, 29872, N'Main Office', N'6030 Robinson Road', NULL, N'Jefferson City', N'Missouri', N'United States', N'65101')
,(858, 29873, N'Main Office', N'2345 West Spencer Road', NULL, N'Lynnwood', N'Washington', N'United States', N'98036')
,(647, 29874, N'Main Office', N'Wade Road', NULL, N'Basingstoke Hants', N'England', N'United Kingdom', N'RG24 8PL')
,(481, 29876, N'Main Office', N'65 Gamelin Street', NULL, N'Hull', N'Quebec', N'Canada', N'8Y')
,(1026, 29877, N'Main Office', N'955 E. County Line Rd.', NULL, N'Englewood', N'Colorado', N'United States', N'80110')
,(515, 29879, N'Main Office', N'9900 Ronson Drive', NULL, N'Etobicoke', N'Ontario', N'Canada', N'M9W 3P3')
,(483, 29881, N'Main Office', N'955 Green Valley Crescent', NULL, N'Ottawa', N'Ontario', N'Canada', N'K4B 1S1')
,(1025, 29883, N'Main Office', N'2530 South Colorado Blvd.', NULL, N'Denver', N'Colorado', N'United States', N'80203')
,(11381, 29883, N'Shipping', N'2000 300th Street', NULL, N'Denver', N'Colorado', N'United States', N'80203')
,(583, 29884, N'Main Office', N'625 W Jackson Blvd. Unit 2502', NULL, N'Chicago', N'Illinois', N'United States', N'60610')
,(857, 29885, N'Main Office', N'7990 Ocean Beach Hwy.', NULL, N'Longview', N'Washington', N'United States', N'98632')
,(1021, 29889, N'Main Office', N'440 West Huntington Dr.', NULL, N'Monrovia', N'California', N'United States', N'91016')
,(855, 29890, N'Main Office', N'15 East Main', NULL, N'Port Orchard', N'Washington', N'United States', N'98366')
,(775, 29891, N'Main Office', N'46460 West Oaks Drive', NULL, N'Novi', N'Michigan', N'United States', N'48375')
,(476, 29892, N'Main Office', N'258 King Street East', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(1018, 29893, N'Main Office', N'630 N. Capitol Ave.', NULL, N'San Jose', N'California', N'United States', N'95112')
,(524, 29895, N'Main Office', N'9693 Louis H Lafontaine', NULL, N'Ville De''anjou', N'Quebec', N'Canada', N'J1G 2R3')
,(28, 29897, N'Shipping', N'9228 Via Del Sol', NULL, N'Phoenix', N'Arizona', N'United States', N'85004')
,(1066, 29897, N'Main Office', N'Prime Outlets', NULL, N'Phoenix', N'Arizona', N'United States', N'85004')
,(876, 29898, N'Main Office', N'765 Delridge Way Sw', NULL, N'Seattle', N'Washington', N'United States', N'98104')
,(508, 29900, N'Main Office', N'2900 - 25055 Dunning Street', NULL, N'Vancouver', N'British Columbia', N'Canada', N'V7L 4J4')
,(1053, 29901, N'Main Office', N'Pacific West Outlet', NULL, N'Gilroy', N'California', N'United States', N'95020')
,(602, 29902, N'Main Office', N'6425 Nw Loop 410', NULL, N'San Antonio', N'Texas', N'United States', N'78204')
,(874, 29903, N'Main Office', N'2550 Ne Sandy Blvd', NULL, N'Portland', N'Oregon', N'United States', N'97205')
,(655, 29904, N'Main Office', N'Wharfdale Road', NULL, N'Berkshire', N'England', N'United Kingdom', N'RG11 5TP')
,(505, 29905, N'Main Office', N'6400, 888 - 3rd Avenue', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(600, 29906, N'Main Office', N'25095 W. Florissant', NULL, N'Ferguson', N'Missouri', N'United States', N'63135')
,(872, 29907, N'Main Office', N'755 W Washington Ave Ste D', NULL, N'Sequim', N'Washington', N'United States', N'98382')
,(654, 29908, N'Main Office', N'308-3250 Casting Road', NULL, N'York', N'England', N'United Kingdom', N'Y024 1GF')
,(502, 29910, N'Main Office', N'No. 25400 10665 Jasper Avenue', NULL, N'Edmonton', N'Alberta', N'Canada', N'T5')
,(538, 29911, N'Main Office', N'25 Danger Street West', N'Floor 7', N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(1080, 29913, N'Main Office', N'2575 Rocky Mountain Ave.', NULL, N'Loveland', N'Colorado', N'United States', N'80537')
,(1079, 29914, N'Main Office', N'25150 El Camino Real', NULL, N'San Bruno', N'California', N'United States', N'94066')
,(891, 29915, N'Main Office', N'2526a Tri-Lake Blvd Ne', NULL, N'Kirkland', N'Washington', N'United States', N'98033')
,(460, 29918, N'Main Office', N'2521 McPherson Street', NULL, N'Markham', N'Ontario', N'Canada', N'L3S 3K2')
,(1005, 29919, N'Main Office', N'6756 Mowry', NULL, N'Newark', N'California', N'United States', N'94560')
,(570, 29920, N'Main Office', N'52500 Liberty Way', NULL, N'Fort Worth', N'Texas', N'United States', N'76102')
,(842, 29921, N'Main Office', N'258101 Nw Evergreen Parkway', NULL, N'Beaverton', N'Oregon', N'United States', N'97005')
,(639, 29922, N'Main Office', N'Garamonde Drive, Wymbush', N'PO Box 4023', N'Milton Keynes', N'England', N'United Kingdom', N'MK8 8ZD')
,(1002, 29924, N'Main Office', N'C/O Starpak, Inc.', NULL, N'Greeley', N'Colorado', N'United States', N'80631')
,(840, 29925, N'Main Office', N'Great Northwestern', NULL, N'North Bend', N'Washington', N'United States', N'98045')
,(638, 29926, N'Main Office', N'255 Irving Street', NULL, N'London', N'England', N'United Kingdom', N'C2H 7AU')
,(454, 29928, N'Main Office', N'3255 Front Street West', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V6')
,(999, 29929, N'Main Office', N'Receiving', NULL, N'Fullerton', N'California', N'United States', N'92831')
,(566, 29930, N'Main Office', N'63 W Monroe', NULL, N'Chicago', N'Illinois', N'United States', N'60610')
,(838, 29931, N'Main Office', N'25300 Biddle Road', NULL, N'Medford', N'Oregon', N'United States', N'97504')
,(637, 29932, N'Main Office', N'Phoenix Way, Cirencester', NULL, N'Gloucestershire', N'England', N'United Kingdom', N'GL7 1RY')
,(451, 29934, N'Main Office', N'2512-4th Ave Sw', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(996, 29935, N'Main Office', N'2575 West 2700 South', NULL, N'Salt Lake City', N'Utah', N'United States', N'84101')
,(852, 29936, N'Main Office', N'25718 Se Sunnyside Rd', NULL, N'Clackamas', N'Oregon', N'United States', N'97015-6403')
,(580, 29937, N'Main Office', N'2509 W. Frankford', NULL, N'Carrollton', N'Texas', N'United States', N'75006')
,(1020, 29938, N'Main Office', N'251340 E. South St.', NULL, N'Cerritos', N'California', N'United States', N'90703')
,(475, 29939, N'Main Office', N'2512-410th Avenue S.W.', NULL, N'Calgary', N'Alberta', N'Canada', N'T2P 2G8')
,(645, 29941, N'Main Office', N'Garamonde Drive, Wymbush', N'P.O. Box 803', N'Milton Keynes', N'England', N'United Kingdom', N'MK8 8ZD')
,(854, 29942, N'Main Office', N'490 Ne 4th St', NULL, N'Renton', N'Washington', N'United States', N'98055')
GO
print 'Processed 300 total records'
INSERT [dbo].[CustomerAddress] ([AddressID], [CustomerID], [AddressType], [AddressLine1], [AddressLine2], [City], [StateProvince], [CountryRegion], [PostalCode]) VALUES 
(582, 29943, N'Main Office', N'5700 Legacy Dr', NULL, N'Plano', N'Texas', N'United States', N'75074')
,(1004, 29944, N'Main Office', N'25600 E St Andrews Pl', NULL, N'Santa Ana', N'California', N'United States', N'92701')
,(462, 29946, N'Main Office', N'630 University Avenue', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(572, 29948, N'Main Office', N'P.O. Box 6256916', NULL, N'Dallas', N'Texas', N'United States', N'75201')
,(1008, 29949, N'Main Office', N'910 Main Street.', NULL, N'Sparks', N'Nevada', N'United States', N'89431')
,(463, 29950, N'Main Office', N'992 St Clair Ave East', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(641, 29952, N'Main Office', N'Bradford', NULL, N'W. York', N'England', N'United Kingdom', N'BD1 4SJ')
,(846, 29953, N'Main Office', N'257700 Ne 76th Street', NULL, N'Redmond', N'Washington', N'United States', N'98052')
,(25, 29954, N'Shipping', N'9178 Jumping St.', NULL, N'Dallas', N'Texas', N'United States', N'75201')
,(574, 29954, N'Main Office', N'Po Box 8259024', NULL, N'Dallas', N'Texas', N'United States', N'75201')
,(756, 29955, N'Main Office', N'855 East Main Avenue', NULL, N'Zeeland', N'Michigan', N'United States', N'49464')
,(561, 29956, N'Main Office', N'90025 Sterling St', NULL, N'Irving', N'Texas', N'United States', N'75061')
,(992, 29957, N'Main Office', N'9992 Whipple Rd', NULL, N'Union City', N'California', N'United States', N'94587')
,(450, 29959, N'Main Office', N'575 Rue St Amable', NULL, N'Quebec', N'Quebec', N'Canada', N'G1R')
,(563, 29962, N'Main Office', N'74400 France Avenue South', NULL, N'Edina', N'Minnesota', N'United States', N'55436')
,(453, 29964, N'Main Office', N'6333 Cote Vertu', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H7')
,(565, 29967, N'Main Office', N'25149 Howard Dr', NULL, N'West Chicago', N'Illinois', N'United States', N'60185')
,(548, 29969, N'Main Office', N'63 Free St.', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V4')
,(549, 29971, N'Main Office', N'609 Evans Avenue', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V4')
,(825, 29973, N'Main Office', N'Port Huron', NULL, N'Port Huron', N'Michigan', N'United States', N'48060')
,(629, 29974, N'Main Office', N'St. Louis Marketplace', NULL, N'Saint Louis', N'Missouri', N'United States', N'63103')
,(1098, 29975, N'Main Office', N'Po Box 252525', NULL, N'Santa Ana', N'California', N'United States', N'92701')
,(671, 29978, N'Main Office', N'25 Hartfield Road, Wimbledon', NULL, N'London', N'England', N'United Kingdom', N'SW19 3RU')
,(672, 29980, N'Main Office', N'99 Dean Street, Soho', NULL, N'London', N'England', N'United Kingdom', N'W1V 5RN')
,(904, 29981, N'Main Office', N'9905 Three Rivers Drive', NULL, N'Kelso', N'Washington', N'United States', N'98626')
,(1102, 29982, N'Main Office', N'603 Gellert Blvd', NULL, N'Daly City', N'California', N'United States', N'94015')
,(554, 29983, N'Main Office', N'9984 Wellington Street', NULL, N'Ottawa', N'Ontario', N'Canada', N'K4B 1S2')
,(673, 29985, N'Main Office', N'Park House-4th Floor, 2516 Park St.', NULL, N'London', N'England', N'United Kingdom', N'W1Y 3RA')
,(1023, 29987, N'Main Office', N'870 N. 54th Ave.', NULL, N'Chandler', N'Arizona', N'United States', N'85225')
,(478, 29988, N'Main Office', N'2545 King Street West', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V7')
,(646, 29990, N'Main Office', N'Butterfield Hse, 7-251 Chapel St', NULL, N'Lancaster', N'England', N'United Kingdom', N'LA1 1LN')
,(856, 29991, N'Main Office', N'3025 E Waterway Blvd', NULL, N'Shelton', N'Washington', N'United States', N'98584')
,(1024, 29992, N'Main Office', N'9952 E. Lohman Ave.', NULL, N'Las Cruces', N'New Mexico', N'United States', N'88001')
,(482, 29994, N'Main Office', N'2500 University Avenue', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(859, 29997, N'Main Office', N'1050 Oak Street', NULL, N'Seattle', N'Washington', N'United States', N'98104')
,(1027, 29998, N'Main Office', N'409 Santa Monica Blvd.', NULL, N'Santa Monica', N'California', N'United States', N'90401')
,(485, 30000, N'Main Office', N'9900-6400 Boul, Taschereau', NULL, N'Brossard', N'Quebec', N'Canada', N'J4Z 1R4')
,(620, 30003, N'Main Office', N'Horizon Outlet', NULL, N'Woodbury', N'Minnesota', N'United States', N'55125')
,(892, 30004, N'Main Office', N'Frontier Mall', NULL, N'Cheyenne', N'Wyoming', N'United States', N'82001')
,(665, 30005, N'Main Office', N'46-44 Albemarle Street', NULL, N'London', N'England', N'United Kingdom', N'W1X3SE')
,(536, 30007, N'Main Office', N'No. 2000-25080 Beaver Hall Hill', NULL, N'Quebec', N'Quebec', N'Canada', N'G1R')
,(617, 30008, N'Main Office', N'Johnson Creek', NULL, N'Johnson Creek', N'Wisconsin', N'United States', N'53038')
,(535, 30010, N'Main Office', N'250 Kingsbridge Garden Circle', NULL, N'Mississauga', N'Ontario', N'Canada', N'L5B 3V4')
,(1077, 30012, N'Main Office', N'7505 Laguna Boulevard', NULL, N'Elk Grove', N'California', N'United States', N'95624')
,(531, 30016, N'Main Office', N'5th Floor, 79 Place D''armes', NULL, N'Kingston', N'Ontario', N'Canada', N'7L')
,(9, 30018, N'Shipping', N'8713 Yosemite Ct.', NULL, N'Bothell', N'Washington', N'United States', N'98011')
,(868, 30018, N'Main Office', N'25111 228th St Sw', NULL, N'Bothell', N'Washington', N'United States', N'98011')
,(652, 30019, N'Main Office', N'Wymbush', NULL, N'Milton Keynes', N'England', N'United Kingdom', N'MK8 8DF')
,(496, 30021, N'Main Office', N'Suite 500 995 W. 11th Avenue', NULL, N'Mississauga', N'Ontario', N'Canada', N'L5A 1H6')
,(1041, 30022, N'Main Office', N'Parkway Plaza', NULL, N'El Cajon', N'California', N'United States', N'92020')
,(594, 30023, N'Main Office', N'123 W. Lake Ave.', NULL, N'Peoria', N'Illinois', N'United States', N'61606')
,(866, 30024, N'Main Office', N'2528 Meridian E', NULL, N'Puyallup', N'Washington', N'United States', N'98371')
,(651, 30025, N'Main Office', N'New Millhouse, 2583 Milton Park', NULL, N'Abingdon', N'England', N'United Kingdom', N'OX14 4SE')
,(1038, 30027, N'Main Office', N'123 Camelia Avenue', NULL, N'Oxnard', N'California', N'United States', N'93030')
,(1087, 30028, N'Main Office', N'253731 West Bell Road', NULL, N'Surprise', N'Arizona', N'United States', N'85374')
,(542, 30029, N'Main Office', N'5 place Ville-Marie', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H7')
,(667, 30030, N'Main Office', N'997b Tradescant Road', NULL, N'London', N'England', N'United Kingdom', N'SW8 1XD')
,(896, 30031, N'Main Office', N'2255 254th Avenue Se', NULL, N'Albany', N'Oregon', N'United States', N'97321')
,(624, 30032, N'Main Office', N'Factory Merchants', NULL, N'Branson', N'Missouri', N'United States', N'65616')
,(1090, 30033, N'Main Office', N'25130 South State Street', NULL, N'Sandy', N'Utah', N'United States', N'84070')
,(898, 30034, N'Main Office', N'700 Se Sunnyside Road', NULL, N'Clackamas', N'Oregon', N'United States', N'97015')
,(626, 30035, N'Main Office', N'Lone Star Factory', NULL, N'La Marque', N'Texas', N'United States', N'77568')
,(1093, 30036, N'Main Office', N'7750 E Marching Rd', NULL, N'Scottsdale', N'Arizona', N'United States', N'85257')
,(545, 30037, N'Main Office', N'999 West Georgia St.', NULL, N'Vancouver', N'Ontario', N'Canada', N'V5T 1Y9')
,(627, 30039, N'Main Office', N'Sports Stores @ Tuscola', NULL, N'Tuscola', N'Illinois', N'United States', N'61953')
,(1095, 30040, N'Main Office', N'9980 S Alma School Road', NULL, N'Chandler', N'Arizona', N'United States', N'85225')
,(523, 30042, N'Main Office', N'46990 Viking Way', NULL, N'Richmond', N'British Columbia', N'Canada', N'V6B 3P7')
,(661, 30044, N'Main Office', N'725a The Arches', NULL, N'Berks', N'England', N'United Kingdom', N'SL4 1RH')
,(886, 30045, N'Main Office', N'Lancaster Mall', NULL, N'Salem', N'Oregon', N'United States', N'97301')
,(614, 30046, N'Main Office', N'Town East Center', NULL, N'Mesquite', N'Texas', N'United States', N'75149')
,(1071, 30047, N'Main Office', N'5867 Sunrise Boulevard', NULL, N'Citrus Heights', N'California', N'United States', N'95610')
,(526, 30048, N'Main Office', N'251420a 170th Street', NULL, N'Edmonton', N'Alberta', N'Canada', N'T5')
,(662, 30050, N'Main Office', N'Paramount House', NULL, N'London', N'England', N'United Kingdom', N'W1N 9FA')
,(888, 30051, N'Main Office', N'Three Rivers Mall', NULL, N'Kelso', N'Washington', N'United States', N'98626')
,(1074, 30052, N'Main Office', N'9920 Bridgepointe Parkway', NULL, N'San Mateo', N'California', N'United States', N'94404')
,(507, 30053, N'Main Office', N'975 Princess Street', NULL, N'Kingston', N'Ontario', N'Canada', N'7L')
,(601, 30055, N'Main Office', N'6996 South Lindbergh', NULL, N'Saint Louis', N'Missouri', N'United States', N'63103')
,(1052, 30056, N'Main Office', N'San Diego Factory', NULL, N'San Ysidro', N'California', N'United States', N'92173')
,(510, 30058, N'Main Office', N'750 Philip Street', NULL, N'Waterloo', N'Ontario', N'Canada', N'N2V')
,(603, 30061, N'Main Office', N'9500b E. Central Texas Expressway', NULL, N'Killeen', N'Texas', N'United States', N'76541')
,(1009, 30063, N'Main Office', N'2500 N Serene Blvd', N'19th Floor', N'El Segundo', N'California', N'United States', N'90245')
,(847, 30064, N'Main Office', N'25102 Springwater', NULL, N'Wenatchee', N'Washington', N'United States', N'98801')
,(464, 30067, N'Main Office', N'99, Rue Saint-pierre', NULL, N'Pnot-Rouge', N'Quebec', N'Canada', N'J1E 2T7')
,(1006, 30069, N'Main Office', N'25472 Marlay Ave', NULL, N'Fontana', N'California', N'United States', N'92335')
,(845, 30070, N'Main Office', N'22571 South 2500 East', NULL, N'Idaho Falls', N'Idaho', N'United States', N'83402')
,(844, 30071, N'Main Office', N'755 Nw Grandstand', NULL, N'Issaquah', N'Washington', N'United States', N'98027')
,(640, 30072, N'Main Office', N'251 The Metro Center', NULL, N'Wokingham', N'England', N'United Kingdom', N'RG41 1QW')
,(534, 30074, N'Main Office', N'Depot 80', NULL, N'Sillery', N'Quebec', N'Canada', N'G1T')
,(1076, 30076, N'Main Office', N'8525 South Parker Road', NULL, N'Parker', N'Colorado', N'United States', N'80138')
,(885, 30080, N'Main Office', N'755 Columbia Ctr Blvd', NULL, N'Kennewick', N'Washington', N'United States', N'99337')
,(521, 30083, N'Main Office', N'55 Standish Court', NULL, N'Mississauga', N'Ontario', N'Canada', N'L5B 3V4')
,(492, 30087, N'Main Office', N'99954 Boul. Laurier, Local 060, Place', NULL, N'Sainte-Foy', N'Quebec', N'Canada', N'G1W')
,(1034, 30089, N'Main Office', N'Oxnard Outlet', NULL, N'Oxnard', N'California', N'United States', N'93030')
,(589, 30090, N'Main Office', N'One Dancing, Rr No. 25', N'Box 8033', N'Round Rock', N'Texas', N'United States', N'78664')
,(489, 30093, N'Main Office', N'9960 King Street E.', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V5')
,(1031, 30094, N'Main Office', N'Natomas Marketplace', NULL, N'Sacramento', N'California', N'United States', N'95814')
,(587, 30095, N'Main Office', N'25500 Old Spanish Trail', NULL, N'Houston', N'Texas', N'United States', N'77003')
,(486, 30098, N'Main Office', N'600 Boul. Rene-levesque Ouest', NULL, N'Montreal', N'Quebec', N'Canada', N'H1Y 2H7')
,(1028, 30100, N'Main Office', N'Mall Of Orange', NULL, N'Orange', N'California', N'United States', N'92867')
,(669, 30102, N'Main Office', N'Internet House, 3399 Science Park', NULL, N'Cambridge', N'England', N'United Kingdom', N'CB4 4BZ')
,(670, 30104, N'Main Office', N'7 Garden House Cloisters, 8 Batters', NULL, N'London', N'England', N'United Kingdom', N'SW8 4BG')
GO
print 'Processed 400 total records'
INSERT [dbo].[CustomerAddress] ([AddressID], [CustomerID], [AddressType], [AddressLine1], [AddressLine2], [City], [StateProvince], [CountryRegion], [PostalCode]) VALUES 
(902, 30105, N'Main Office', N'950 Gateway Street', NULL, N'Springfield', N'Oregon', N'United States', N'97477')
,(630, 30106, N'Main Office', N'Lincoln Square', NULL, N'Arlington', N'Texas', N'United States', N'76010')
,(1099, 30107, N'Main Office', N'62500 Neil Road', NULL, N'Reno', N'Nevada', N'United States', N'89502')
,(550, 30108, N'Main Office', N'2520 Flanders Road', NULL, N'Toronto', N'Ontario', N'Canada', N'M4B 1V4')
,(826, 30109, N'Main Office', N'Kensington Valley Shops', NULL, N'Howell', N'Michigan', N'United States', N'48843')
,(1047, 30110, N'Main Office', N'Stevens Creek Shopping Center', NULL, N'San Jose', N'California', N'United States', N'95112')
,(598, 30111, N'Main Office', N'455 256th St.', NULL, N'Moline', N'Illinois', N'United States', N'61265')
,(870, 30112, N'Main Office', N'409 S. Main Ste. 25', NULL, N'Ellensburg', N'Washington', N'United States', N'98926')
,(653, 30113, N'Main Office', N'Burgess Hill', N'Edward Way', N'West Sussex', N'England', N'United Kingdom', N'RH15 9UD')
,(499, 30115, N'Main Office', N'Suite 2502 410 Albert Street', NULL, N'Waterloo', N'Ontario', N'Canada', N'N2V')
,(1044, 30116, N'Main Office', N'Ontario Mills', NULL, N'Ontario', N'California', N'United States', N'91764')
,(596, 30117, N'Main Office', N'72540 Blanco Rd.', NULL, N'San Antonio', N'Texas', N'United States', N'78204')
,(595, 30118, N'Main Office', N'660 Lindbergh', NULL, N'Saint Louis', N'Missouri', N'United States', N'63103')
GO

--<<<<<<<<<<<<<<<<<<<<< Task 8 – Query Federation Members >>>>>>>>>>>>>>>>>>>>>
-- Route connection to the Federation Root
USE FEDERATION ROOT WITH RESET
GO
SELECT db_name() [db_name], db_id() [db_id]
SELECT * FROM sys.federations
SELECT * FROM sys.federation_member_distributions 
ORDER BY federation_id, range_low;
SELECT * FROM sys.databases;
GO
-- Federated tables/columns
SELECT * FROM sys.federated_table_columns
GO

-- Note: Can't query the customer table from federation root
SELECT * FROM dbo.Customer

-- Route connection to the 1 Federation Member (aka shard)
USE FEDERATION CustomerFederation(cid=100) WITH RESET, FILTERING=OFF
GO
SELECT db_name() [db_name], db_id() [db_id]
SELECT * FROM sys.federation_member_distributions
-- Federatation ranges
SELECT f.name, fmc.federation_id, fmc.member_id, fmc.range_low, fmc.range_high 
FROM sys.federations f
JOIN sys.federation_member_distributions fmc
ON f.federation_id=fmc.federation_id
ORDER BY fmc.federation_id, fmc.range_low;

-- User tables count (federated & reference)
SELECT fmc.member_id,fmc.range_low,fmc.range_high,'[' + s.name + '].[' + t.name + ']' [name],
p.row_count FROM sys.tables t 
JOIN sys.schemas s ON t.schema_id=s.schema_id 
JOIN sys.dm_db_partition_stats p ON t.object_id=p.object_id  
JOIN sys.federation_member_distributions fmc ON 1=1 
WHERE p.index_id=1 ORDER BY s.name, t.name
GO
-- Federated tables/columns
SELECT * FROM sys.federated_table_columns
GO

-- Can query Customer table from federation member
SELECT * FROM Customer

-- Query customer table for high/low Federated Keys
SELECT MIN(CustomerID) [CustomerID Low], MAX(CustomerID) [CustomerID High] FROM Customer
GO

--<<<<<<<<<<<<<<<<<<<<< Perform Federations Split Operation >>>>>>>>>>>>>>>>>>>>>
USE FEDERATION ROOT WITH RESET
GO
ALTER FEDERATION CustomerFederation SPLIT AT (cid=100)
GO

-- see how long a repartitioning operation has been active
SELECT datediff(ss,start_date,getutcdate()) as total_seconds, 
       percent_complete, *
FROM sys.dm_federation_operations
-- which members affected
SELECT * FROM sys.dm_federation_operation_members
GO

-- repartitioning errors?
select * from sys.dm_federation_operation_errors
select * from sys.dm_federation_operation_error_members
GO

--<<<<<<<<<<<<<<<<<<<<< Query Federation Members (again) >>>>>>>>>>>>>>>>>>>>>
-- Route connection to the Federation Root
USE FEDERATION ROOT WITH RESET
GO
SELECT db_name() [db_name], db_id() [db_id]
SELECT * FROM sys.federations
SELECT * FROM sys.federation_member_distributions ORDER BY federation_id, range_low;
SELECT * FROM sys.databases;
GO

-- Route connection to the 1 Federation Member (aka shard)
--USE FEDERATION CustomerFederation(cid=0) WITH RESET, FILTERING=OFF
USE FEDERATION CustomerFederation(cid=100) WITH RESET, FILTERING=OFF
GO
SELECT db_name() [db_name], db_id() [db_id]
SELECT * FROM sys.federation_member_distributions
-- Federatation ranges
SELECT f.name, fmc.federation_id, fmc.member_id, fmc.range_low, fmc.range_high 
FROM sys.federations f
JOIN sys.federation_member_distributions fmc
ON f.federation_id=fmc.federation_id
ORDER BY fmc.federation_id, fmc.range_low;
-- User tables count (federated & reference)
SELECT fmc.member_id,fmc.range_low,fmc.range_high,'[' + s.name + '].[' + t.name + ']' [name],
p.row_count FROM sys.tables t 
JOIN sys.schemas s ON t.schema_id=s.schema_id 
JOIN sys.dm_db_partition_stats p ON t.object_id=p.object_id  
JOIN sys.federation_member_distributions fmc ON 1=1 
WHERE p.index_id=1 ORDER BY s.name, t.name
GO
-- Query customer table for high/low Federated Keys
SELECT MIN(CustomerID) [CustomerID Low], MAX(CustomerID) [CustomerID High] FROM Customer
GO

DROP TABLE dbo.Customer

DROP FEDERATION CustomerFederation

DROP DATABASE MyFedDB